#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 833
#define LARGE_STATE_COUNT 9
#define SYMBOL_COUNT 151
#define ALIAS_COUNT 4
#define TOKEN_COUNT 79
#define EXTERNAL_TOKEN_COUNT 2
#define FIELD_COUNT 17
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 19

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_module = 2,
  anon_sym_EQ = 3,
  anon_sym_import = 4,
  anon_sym_provider = 5,
  anon_sym_as = 6,
  anon_sym_with = 7,
  anon_sym_LBRACE = 8,
  anon_sym_COMMA = 9,
  anon_sym_RBRACE = 10,
  anon_sym_STAR = 11,
  anon_sym_from = 12,
  anon_sym_using = 13,
  anon_sym_targetScope = 14,
  anon_sym_metadata = 15,
  anon_sym_output = 16,
  anon_sym_param = 17,
  anon_sym_resource = 18,
  anon_sym_existing = 19,
  anon_sym_type = 20,
  anon_sym_var = 21,
  anon_sym_BANG = 22,
  anon_sym_func = 23,
  anon_sym_EQ_GT = 24,
  anon_sym_test = 25,
  anon_sym_assert = 26,
  anon_sym_LPAREN = 27,
  anon_sym_RPAREN = 28,
  anon_sym_AT = 29,
  anon_sym_LBRACK = 30,
  anon_sym_RBRACK = 31,
  anon_sym_COLON = 32,
  anon_sym_if = 33,
  anon_sym_for = 34,
  anon_sym_in = 35,
  anon_sym_DOT = 36,
  anon_sym_DOT_QMARK = 37,
  anon_sym_QMARK = 38,
  anon_sym_COLON_COLON = 39,
  anon_sym_PLUS = 40,
  anon_sym_DASH = 41,
  anon_sym_SLASH = 42,
  anon_sym_PERCENT = 43,
  anon_sym_PIPE_PIPE = 44,
  anon_sym_AMP_AMP = 45,
  anon_sym_PIPE = 46,
  anon_sym_EQ_EQ = 47,
  anon_sym_BANG_EQ = 48,
  anon_sym_EQ_TILDE = 49,
  anon_sym_BANG_TILDE = 50,
  anon_sym_GT = 51,
  anon_sym_GT_EQ = 52,
  anon_sym_LT_EQ = 53,
  anon_sym_LT = 54,
  anon_sym_QMARK_QMARK = 55,
  sym_number = 56,
  anon_sym_true = 57,
  anon_sym_false = 58,
  sym_null = 59,
  anon_sym_SQUOTE = 60,
  anon_sym_DOLLAR = 61,
  anon_sym_POUND = 62,
  sym_string_content = 63,
  anon_sym_SQUOTE_SQUOTE_SQUOTE = 64,
  aux_sym__escape_sequence_token1 = 65,
  sym_escape_sequence = 66,
  anon_sym_DOLLAR_LBRACE = 67,
  anon_sym_array = 68,
  anon_sym_bool = 69,
  anon_sym_int = 70,
  anon_sym_object = 71,
  anon_sym_secureObject = 72,
  anon_sym_secureString = 73,
  anon_sym_string = 74,
  sym_comment = 75,
  sym_diagnostic_comment = 76,
  sym__external_asterisk = 77,
  sym__multiline_string_content = 78,
  sym_infrastructure = 79,
  sym_statement = 80,
  sym_declaration = 81,
  sym_module_declaration = 82,
  sym_import_statement = 83,
  sym_import_with_statement = 84,
  sym_import_functionality = 85,
  sym_using_statement = 86,
  sym_target_scope_assignment = 87,
  sym_metadata_declaration = 88,
  sym_output_declaration = 89,
  sym_parameter_declaration = 90,
  sym_resource_declaration = 91,
  sym_type_declaration = 92,
  sym_variable_declaration = 93,
  sym_user_defined_function = 94,
  sym_test_block = 95,
  sym_assert_statement = 96,
  sym_parameters = 97,
  sym_parameter = 98,
  sym_expression = 99,
  sym_primary_expression = 100,
  sym_call_expression = 101,
  sym_lambda_expression = 102,
  sym_arguments = 103,
  sym_parenthesized_expression = 104,
  sym_decorator = 105,
  sym_decorators = 106,
  sym_array = 107,
  sym_object = 108,
  sym_object_property = 109,
  sym_if_statement = 110,
  sym__lhs_expression = 111,
  sym_assignment_expression = 112,
  sym_for_statement = 113,
  sym_for_loop_parameters = 114,
  sym_member_expression = 115,
  sym_subscript_expression = 116,
  sym_resource_expression = 117,
  sym_ternary_expression = 118,
  sym_binary_expression = 119,
  sym_unary_expression = 120,
  sym__literal = 121,
  sym_boolean = 122,
  sym_string = 123,
  sym__string_literal = 124,
  sym__multiline_string_literal = 125,
  sym_multiline_string_content = 126,
  sym__escape_sequence = 127,
  sym_interpolation = 128,
  sym_compatible_identifier = 129,
  sym_type = 130,
  sym__type_not_union = 131,
  sym_primitive_type = 132,
  sym_array_type = 133,
  sym_nullable_type = 134,
  sym_negated_type = 135,
  sym_union_type = 136,
  sym_parenthesized_type = 137,
  sym_parameterized_type = 138,
  sym_type_arguments = 139,
  aux_sym_infrastructure_repeat1 = 140,
  aux_sym_import_functionality_repeat1 = 141,
  aux_sym_parameters_repeat1 = 142,
  aux_sym_arguments_repeat1 = 143,
  aux_sym_decorators_repeat1 = 144,
  aux_sym_array_repeat1 = 145,
  aux_sym_object_repeat1 = 146,
  aux_sym__string_literal_repeat1 = 147,
  aux_sym_multiline_string_content_repeat1 = 148,
  aux_sym_union_type_repeat1 = 149,
  aux_sym_type_arguments_repeat1 = 150,
  alias_sym_loop_enumerator = 151,
  alias_sym_loop_variable = 152,
  alias_sym_nullable_return_type = 153,
  alias_sym_property_identifier = 154,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_module] = "module",
  [anon_sym_EQ] = "=",
  [anon_sym_import] = "import",
  [anon_sym_provider] = "provider",
  [anon_sym_as] = "as",
  [anon_sym_with] = "with",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_RBRACE] = "}",
  [anon_sym_STAR] = "*",
  [anon_sym_from] = "from",
  [anon_sym_using] = "using",
  [anon_sym_targetScope] = "targetScope",
  [anon_sym_metadata] = "metadata",
  [anon_sym_output] = "output",
  [anon_sym_param] = "param",
  [anon_sym_resource] = "resource",
  [anon_sym_existing] = "existing",
  [anon_sym_type] = "type",
  [anon_sym_var] = "var",
  [anon_sym_BANG] = "!",
  [anon_sym_func] = "func",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_test] = "test",
  [anon_sym_assert] = "assert",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_AT] = "@",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_COLON] = ":",
  [anon_sym_if] = "if",
  [anon_sym_for] = "for",
  [anon_sym_in] = "in",
  [anon_sym_DOT] = ".",
  [anon_sym_DOT_QMARK] = ".\?",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE] = "|",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_EQ_TILDE] = "=~",
  [anon_sym_BANG_TILDE] = "!~",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_QMARK_QMARK] = "\?\?",
  [sym_number] = "number",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [sym_null] = "null",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_DOLLAR] = "string_content",
  [anon_sym_POUND] = "string_content",
  [sym_string_content] = "string_content",
  [anon_sym_SQUOTE_SQUOTE_SQUOTE] = "'''",
  [aux_sym__escape_sequence_token1] = "_escape_sequence_token1",
  [sym_escape_sequence] = "escape_sequence",
  [anon_sym_DOLLAR_LBRACE] = "${",
  [anon_sym_array] = "array",
  [anon_sym_bool] = "bool",
  [anon_sym_int] = "int",
  [anon_sym_object] = "object",
  [anon_sym_secureObject] = "secureObject",
  [anon_sym_secureString] = "secureString",
  [anon_sym_string] = "string",
  [sym_comment] = "comment",
  [sym_diagnostic_comment] = "diagnostic_comment",
  [sym__external_asterisk] = "*",
  [sym__multiline_string_content] = "_multiline_string_content",
  [sym_infrastructure] = "infrastructure",
  [sym_statement] = "statement",
  [sym_declaration] = "declaration",
  [sym_module_declaration] = "module_declaration",
  [sym_import_statement] = "import_statement",
  [sym_import_with_statement] = "import_with_statement",
  [sym_import_functionality] = "import_functionality",
  [sym_using_statement] = "using_statement",
  [sym_target_scope_assignment] = "target_scope_assignment",
  [sym_metadata_declaration] = "metadata_declaration",
  [sym_output_declaration] = "output_declaration",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym_resource_declaration] = "resource_declaration",
  [sym_type_declaration] = "type_declaration",
  [sym_variable_declaration] = "variable_declaration",
  [sym_user_defined_function] = "user_defined_function",
  [sym_test_block] = "test_block",
  [sym_assert_statement] = "assert_statement",
  [sym_parameters] = "parameters",
  [sym_parameter] = "parameter",
  [sym_expression] = "expression",
  [sym_primary_expression] = "primary_expression",
  [sym_call_expression] = "call_expression",
  [sym_lambda_expression] = "lambda_expression",
  [sym_arguments] = "arguments",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_decorator] = "decorator",
  [sym_decorators] = "decorators",
  [sym_array] = "array",
  [sym_object] = "object",
  [sym_object_property] = "object_property",
  [sym_if_statement] = "if_statement",
  [sym__lhs_expression] = "_lhs_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_for_statement] = "for_statement",
  [sym_for_loop_parameters] = "for_loop_parameters",
  [sym_member_expression] = "member_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_resource_expression] = "resource_expression",
  [sym_ternary_expression] = "ternary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym__literal] = "_literal",
  [sym_boolean] = "boolean",
  [sym_string] = "string",
  [sym__string_literal] = "_string_literal",
  [sym__multiline_string_literal] = "_multiline_string_literal",
  [sym_multiline_string_content] = "string_content",
  [sym__escape_sequence] = "_escape_sequence",
  [sym_interpolation] = "interpolation",
  [sym_compatible_identifier] = "compatible_identifier",
  [sym_type] = "type",
  [sym__type_not_union] = "_type_not_union",
  [sym_primitive_type] = "primitive_type",
  [sym_array_type] = "array_type",
  [sym_nullable_type] = "nullable_type",
  [sym_negated_type] = "negated_type",
  [sym_union_type] = "union_type",
  [sym_parenthesized_type] = "parenthesized_type",
  [sym_parameterized_type] = "parameterized_type",
  [sym_type_arguments] = "type_arguments",
  [aux_sym_infrastructure_repeat1] = "infrastructure_repeat1",
  [aux_sym_import_functionality_repeat1] = "import_functionality_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_decorators_repeat1] = "decorators_repeat1",
  [aux_sym_array_repeat1] = "array_repeat1",
  [aux_sym_object_repeat1] = "object_repeat1",
  [aux_sym__string_literal_repeat1] = "_string_literal_repeat1",
  [aux_sym_multiline_string_content_repeat1] = "multiline_string_content_repeat1",
  [aux_sym_union_type_repeat1] = "union_type_repeat1",
  [aux_sym_type_arguments_repeat1] = "type_arguments_repeat1",
  [alias_sym_loop_enumerator] = "loop_enumerator",
  [alias_sym_loop_variable] = "loop_variable",
  [alias_sym_nullable_return_type] = "nullable_return_type",
  [alias_sym_property_identifier] = "property_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_provider] = anon_sym_provider,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_from] = anon_sym_from,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_targetScope] = anon_sym_targetScope,
  [anon_sym_metadata] = anon_sym_metadata,
  [anon_sym_output] = anon_sym_output,
  [anon_sym_param] = anon_sym_param,
  [anon_sym_resource] = anon_sym_resource,
  [anon_sym_existing] = anon_sym_existing,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_func] = anon_sym_func,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_test] = anon_sym_test,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_DOT_QMARK] = anon_sym_DOT_QMARK,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_EQ_TILDE] = anon_sym_EQ_TILDE,
  [anon_sym_BANG_TILDE] = anon_sym_BANG_TILDE,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_QMARK_QMARK] = anon_sym_QMARK_QMARK,
  [sym_number] = sym_number,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [sym_null] = sym_null,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_DOLLAR] = sym_string_content,
  [anon_sym_POUND] = sym_string_content,
  [sym_string_content] = sym_string_content,
  [anon_sym_SQUOTE_SQUOTE_SQUOTE] = anon_sym_SQUOTE_SQUOTE_SQUOTE,
  [aux_sym__escape_sequence_token1] = aux_sym__escape_sequence_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [anon_sym_DOLLAR_LBRACE] = anon_sym_DOLLAR_LBRACE,
  [anon_sym_array] = anon_sym_array,
  [anon_sym_bool] = anon_sym_bool,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_object] = anon_sym_object,
  [anon_sym_secureObject] = anon_sym_secureObject,
  [anon_sym_secureString] = anon_sym_secureString,
  [anon_sym_string] = anon_sym_string,
  [sym_comment] = sym_comment,
  [sym_diagnostic_comment] = sym_diagnostic_comment,
  [sym__external_asterisk] = anon_sym_STAR,
  [sym__multiline_string_content] = sym__multiline_string_content,
  [sym_infrastructure] = sym_infrastructure,
  [sym_statement] = sym_statement,
  [sym_declaration] = sym_declaration,
  [sym_module_declaration] = sym_module_declaration,
  [sym_import_statement] = sym_import_statement,
  [sym_import_with_statement] = sym_import_with_statement,
  [sym_import_functionality] = sym_import_functionality,
  [sym_using_statement] = sym_using_statement,
  [sym_target_scope_assignment] = sym_target_scope_assignment,
  [sym_metadata_declaration] = sym_metadata_declaration,
  [sym_output_declaration] = sym_output_declaration,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym_resource_declaration] = sym_resource_declaration,
  [sym_type_declaration] = sym_type_declaration,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_user_defined_function] = sym_user_defined_function,
  [sym_test_block] = sym_test_block,
  [sym_assert_statement] = sym_assert_statement,
  [sym_parameters] = sym_parameters,
  [sym_parameter] = sym_parameter,
  [sym_expression] = sym_expression,
  [sym_primary_expression] = sym_primary_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym_arguments] = sym_arguments,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_decorator] = sym_decorator,
  [sym_decorators] = sym_decorators,
  [sym_array] = sym_array,
  [sym_object] = sym_object,
  [sym_object_property] = sym_object_property,
  [sym_if_statement] = sym_if_statement,
  [sym__lhs_expression] = sym__lhs_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_for_statement] = sym_for_statement,
  [sym_for_loop_parameters] = sym_for_loop_parameters,
  [sym_member_expression] = sym_member_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_resource_expression] = sym_resource_expression,
  [sym_ternary_expression] = sym_ternary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym__literal] = sym__literal,
  [sym_boolean] = sym_boolean,
  [sym_string] = sym_string,
  [sym__string_literal] = sym__string_literal,
  [sym__multiline_string_literal] = sym__multiline_string_literal,
  [sym_multiline_string_content] = sym_string_content,
  [sym__escape_sequence] = sym__escape_sequence,
  [sym_interpolation] = sym_interpolation,
  [sym_compatible_identifier] = sym_compatible_identifier,
  [sym_type] = sym_type,
  [sym__type_not_union] = sym__type_not_union,
  [sym_primitive_type] = sym_primitive_type,
  [sym_array_type] = sym_array_type,
  [sym_nullable_type] = sym_nullable_type,
  [sym_negated_type] = sym_negated_type,
  [sym_union_type] = sym_union_type,
  [sym_parenthesized_type] = sym_parenthesized_type,
  [sym_parameterized_type] = sym_parameterized_type,
  [sym_type_arguments] = sym_type_arguments,
  [aux_sym_infrastructure_repeat1] = aux_sym_infrastructure_repeat1,
  [aux_sym_import_functionality_repeat1] = aux_sym_import_functionality_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_decorators_repeat1] = aux_sym_decorators_repeat1,
  [aux_sym_array_repeat1] = aux_sym_array_repeat1,
  [aux_sym_object_repeat1] = aux_sym_object_repeat1,
  [aux_sym__string_literal_repeat1] = aux_sym__string_literal_repeat1,
  [aux_sym_multiline_string_content_repeat1] = aux_sym_multiline_string_content_repeat1,
  [aux_sym_union_type_repeat1] = aux_sym_union_type_repeat1,
  [aux_sym_type_arguments_repeat1] = aux_sym_type_arguments_repeat1,
  [alias_sym_loop_enumerator] = alias_sym_loop_enumerator,
  [alias_sym_loop_variable] = alias_sym_loop_variable,
  [alias_sym_nullable_return_type] = alias_sym_nullable_return_type,
  [alias_sym_property_identifier] = alias_sym_property_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_provider] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_targetScope] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_metadata] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_output] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_param] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_resource] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_existing] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_func] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_test] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_QMARK] = {
    .visible = true,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE_SQUOTE_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__escape_sequence_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOLLAR_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_array] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_object] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_secureObject] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_secureString] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_diagnostic_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__external_asterisk] = {
    .visible = true,
    .named = false,
  },
  [sym__multiline_string_content] = {
    .visible = false,
    .named = true,
  },
  [sym_infrastructure] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_declaration] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_module_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_import_with_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_import_functionality] = {
    .visible = true,
    .named = true,
  },
  [sym_using_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_target_scope_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_metadata_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_output_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_resource_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_user_defined_function] = {
    .visible = true,
    .named = true,
  },
  [sym_test_block] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_primary_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator] = {
    .visible = true,
    .named = true,
  },
  [sym_decorators] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym_object_property] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__lhs_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_loop_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_resource_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ternary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym__string_literal] = {
    .visible = false,
    .named = true,
  },
  [sym__multiline_string_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_multiline_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__escape_sequence] = {
    .visible = false,
    .named = true,
  },
  [sym_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym_compatible_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym__type_not_union] = {
    .visible = false,
    .named = true,
  },
  [sym_primitive_type] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_nullable_type] = {
    .visible = true,
    .named = true,
  },
  [sym_negated_type] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parameterized_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_infrastructure_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_functionality_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_decorators_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multiline_string_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_union_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_loop_enumerator] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_loop_variable] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_nullable_return_type] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_property_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_argument = 2,
  field_arguments = 3,
  field_body = 4,
  field_condition = 5,
  field_consequence = 6,
  field_function = 7,
  field_index = 8,
  field_initializer = 9,
  field_left = 10,
  field_name = 11,
  field_object = 12,
  field_operator = 13,
  field_property = 14,
  field_resource = 15,
  field_returns = 16,
  field_right = 17,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_function] = "function",
  [field_index] = "index",
  [field_initializer] = "initializer",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operator] = "operator",
  [field_property] = "property",
  [field_resource] = "resource",
  [field_returns] = "returns",
  [field_right] = "right",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 2},
  [3] = {.index = 2, .length = 2},
  [4] = {.index = 4, .length = 1},
  [5] = {.index = 5, .length = 3},
  [6] = {.index = 8, .length = 2},
  [7] = {.index = 10, .length = 2},
  [8] = {.index = 2, .length = 2},
  [9] = {.index = 12, .length = 2},
  [10] = {.index = 14, .length = 2},
  [11] = {.index = 16, .length = 2},
  [12] = {.index = 18, .length = 2},
  [13] = {.index = 20, .length = 2},
  [14] = {.index = 22, .length = 3},
  [16] = {.index = 25, .length = 1},
  [17] = {.index = 26, .length = 2},
  [18] = {.index = 28, .length = 1},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_argument, 1},
    {field_operator, 0},
  [2] =
    {field_arguments, 1},
    {field_function, 0},
  [4] =
    {field_name, 1},
  [5] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [8] =
    {field_object, 0},
    {field_property, 2},
  [10] =
    {field_object, 0},
    {field_resource, 2},
  [12] =
    {field_left, 0},
    {field_right, 2},
  [14] =
    {field_object, 0},
    {field_property, 3},
  [16] =
    {field_index, 2},
    {field_object, 0},
  [18] =
    {field_name, 1},
    {field_returns, 3},
  [20] =
    {field_index, 3},
    {field_object, 0},
  [22] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [25] =
    {field_body, 5},
  [26] =
    {field_body, 6},
    {field_initializer, 2},
  [28] =
    {field_body, 6},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_identifier,
  },
  [6] = {
    [2] = alias_sym_property_identifier,
  },
  [8] = {
    [2] = alias_sym_nullable_return_type,
  },
  [10] = {
    [3] = alias_sym_property_identifier,
  },
  [15] = {
    [1] = alias_sym_loop_variable,
    [3] = alias_sym_loop_enumerator,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 2,
  [5] = 5,
  [6] = 3,
  [7] = 2,
  [8] = 3,
  [9] = 9,
  [10] = 9,
  [11] = 9,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 14,
  [17] = 13,
  [18] = 18,
  [19] = 19,
  [20] = 15,
  [21] = 13,
  [22] = 13,
  [23] = 13,
  [24] = 13,
  [25] = 15,
  [26] = 15,
  [27] = 14,
  [28] = 13,
  [29] = 13,
  [30] = 30,
  [31] = 15,
  [32] = 32,
  [33] = 14,
  [34] = 34,
  [35] = 13,
  [36] = 36,
  [37] = 13,
  [38] = 15,
  [39] = 14,
  [40] = 15,
  [41] = 14,
  [42] = 15,
  [43] = 14,
  [44] = 15,
  [45] = 15,
  [46] = 15,
  [47] = 15,
  [48] = 14,
  [49] = 15,
  [50] = 13,
  [51] = 15,
  [52] = 15,
  [53] = 13,
  [54] = 54,
  [55] = 54,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 58,
  [61] = 58,
  [62] = 57,
  [63] = 57,
  [64] = 64,
  [65] = 64,
  [66] = 64,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 67,
  [71] = 68,
  [72] = 54,
  [73] = 68,
  [74] = 54,
  [75] = 69,
  [76] = 67,
  [77] = 69,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 111,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 54,
  [138] = 111,
  [139] = 133,
  [140] = 134,
  [141] = 141,
  [142] = 142,
  [143] = 111,
  [144] = 133,
  [145] = 134,
  [146] = 146,
  [147] = 133,
  [148] = 134,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 153,
  [156] = 156,
  [157] = 154,
  [158] = 153,
  [159] = 156,
  [160] = 156,
  [161] = 154,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 163,
  [170] = 164,
  [171] = 166,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 172,
  [178] = 165,
  [179] = 173,
  [180] = 180,
  [181] = 181,
  [182] = 174,
  [183] = 183,
  [184] = 184,
  [185] = 175,
  [186] = 186,
  [187] = 176,
  [188] = 163,
  [189] = 189,
  [190] = 190,
  [191] = 164,
  [192] = 166,
  [193] = 172,
  [194] = 173,
  [195] = 174,
  [196] = 175,
  [197] = 165,
  [198] = 176,
  [199] = 190,
  [200] = 183,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 184,
  [210] = 210,
  [211] = 211,
  [212] = 167,
  [213] = 165,
  [214] = 168,
  [215] = 215,
  [216] = 216,
  [217] = 184,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 184,
  [224] = 211,
  [225] = 225,
  [226] = 218,
  [227] = 162,
  [228] = 219,
  [229] = 167,
  [230] = 168,
  [231] = 163,
  [232] = 164,
  [233] = 211,
  [234] = 166,
  [235] = 218,
  [236] = 219,
  [237] = 172,
  [238] = 173,
  [239] = 174,
  [240] = 218,
  [241] = 175,
  [242] = 176,
  [243] = 167,
  [244] = 168,
  [245] = 208,
  [246] = 186,
  [247] = 208,
  [248] = 162,
  [249] = 186,
  [250] = 208,
  [251] = 162,
  [252] = 186,
  [253] = 183,
  [254] = 100,
  [255] = 255,
  [256] = 118,
  [257] = 257,
  [258] = 95,
  [259] = 96,
  [260] = 83,
  [261] = 255,
  [262] = 90,
  [263] = 255,
  [264] = 257,
  [265] = 91,
  [266] = 92,
  [267] = 81,
  [268] = 101,
  [269] = 126,
  [270] = 89,
  [271] = 104,
  [272] = 105,
  [273] = 106,
  [274] = 107,
  [275] = 136,
  [276] = 108,
  [277] = 98,
  [278] = 109,
  [279] = 99,
  [280] = 80,
  [281] = 82,
  [282] = 79,
  [283] = 102,
  [284] = 110,
  [285] = 89,
  [286] = 125,
  [287] = 103,
  [288] = 130,
  [289] = 98,
  [290] = 128,
  [291] = 99,
  [292] = 136,
  [293] = 141,
  [294] = 149,
  [295] = 113,
  [296] = 114,
  [297] = 116,
  [298] = 118,
  [299] = 299,
  [300] = 300,
  [301] = 121,
  [302] = 123,
  [303] = 124,
  [304] = 122,
  [305] = 126,
  [306] = 129,
  [307] = 131,
  [308] = 142,
  [309] = 150,
  [310] = 132,
  [311] = 151,
  [312] = 119,
  [313] = 135,
  [314] = 146,
  [315] = 112,
  [316] = 115,
  [317] = 117,
  [318] = 318,
  [319] = 110,
  [320] = 95,
  [321] = 96,
  [322] = 299,
  [323] = 300,
  [324] = 318,
  [325] = 89,
  [326] = 125,
  [327] = 115,
  [328] = 141,
  [329] = 103,
  [330] = 131,
  [331] = 129,
  [332] = 108,
  [333] = 109,
  [334] = 104,
  [335] = 142,
  [336] = 80,
  [337] = 150,
  [338] = 105,
  [339] = 121,
  [340] = 132,
  [341] = 100,
  [342] = 123,
  [343] = 106,
  [344] = 122,
  [345] = 81,
  [346] = 128,
  [347] = 101,
  [348] = 82,
  [349] = 151,
  [350] = 102,
  [351] = 119,
  [352] = 149,
  [353] = 90,
  [354] = 130,
  [355] = 83,
  [356] = 79,
  [357] = 135,
  [358] = 113,
  [359] = 146,
  [360] = 112,
  [361] = 117,
  [362] = 114,
  [363] = 91,
  [364] = 116,
  [365] = 92,
  [366] = 124,
  [367] = 107,
  [368] = 225,
  [369] = 190,
  [370] = 180,
  [371] = 190,
  [372] = 300,
  [373] = 257,
  [374] = 318,
  [375] = 255,
  [376] = 181,
  [377] = 180,
  [378] = 318,
  [379] = 300,
  [380] = 180,
  [381] = 299,
  [382] = 299,
  [383] = 255,
  [384] = 318,
  [385] = 257,
  [386] = 103,
  [387] = 105,
  [388] = 100,
  [389] = 104,
  [390] = 106,
  [391] = 107,
  [392] = 108,
  [393] = 109,
  [394] = 190,
  [395] = 80,
  [396] = 396,
  [397] = 79,
  [398] = 398,
  [399] = 181,
  [400] = 90,
  [401] = 257,
  [402] = 402,
  [403] = 91,
  [404] = 257,
  [405] = 255,
  [406] = 406,
  [407] = 92,
  [408] = 255,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 257,
  [413] = 413,
  [414] = 255,
  [415] = 225,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 418,
  [421] = 421,
  [422] = 419,
  [423] = 423,
  [424] = 418,
  [425] = 421,
  [426] = 419,
  [427] = 423,
  [428] = 421,
  [429] = 429,
  [430] = 418,
  [431] = 423,
  [432] = 421,
  [433] = 423,
  [434] = 419,
  [435] = 435,
  [436] = 436,
  [437] = 435,
  [438] = 438,
  [439] = 439,
  [440] = 438,
  [441] = 441,
  [442] = 435,
  [443] = 443,
  [444] = 438,
  [445] = 441,
  [446] = 443,
  [447] = 443,
  [448] = 441,
  [449] = 441,
  [450] = 435,
  [451] = 443,
  [452] = 438,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 454,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 459,
  [462] = 462,
  [463] = 463,
  [464] = 459,
  [465] = 465,
  [466] = 466,
  [467] = 190,
  [468] = 465,
  [469] = 181,
  [470] = 465,
  [471] = 471,
  [472] = 180,
  [473] = 473,
  [474] = 474,
  [475] = 190,
  [476] = 476,
  [477] = 257,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 255,
  [482] = 482,
  [483] = 255,
  [484] = 484,
  [485] = 190,
  [486] = 486,
  [487] = 257,
  [488] = 181,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 491,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 500,
  [506] = 491,
  [507] = 507,
  [508] = 497,
  [509] = 498,
  [510] = 497,
  [511] = 498,
  [512] = 501,
  [513] = 499,
  [514] = 502,
  [515] = 500,
  [516] = 501,
  [517] = 502,
  [518] = 491,
  [519] = 181,
  [520] = 498,
  [521] = 181,
  [522] = 500,
  [523] = 501,
  [524] = 502,
  [525] = 299,
  [526] = 300,
  [527] = 499,
  [528] = 507,
  [529] = 529,
  [530] = 318,
  [531] = 507,
  [532] = 532,
  [533] = 533,
  [534] = 507,
  [535] = 190,
  [536] = 503,
  [537] = 494,
  [538] = 495,
  [539] = 503,
  [540] = 494,
  [541] = 495,
  [542] = 503,
  [543] = 494,
  [544] = 495,
  [545] = 545,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 257,
  [550] = 550,
  [551] = 551,
  [552] = 546,
  [553] = 553,
  [554] = 255,
  [555] = 546,
  [556] = 556,
  [557] = 299,
  [558] = 300,
  [559] = 474,
  [560] = 476,
  [561] = 561,
  [562] = 471,
  [563] = 473,
  [564] = 564,
  [565] = 318,
  [566] = 466,
  [567] = 479,
  [568] = 135,
  [569] = 480,
  [570] = 570,
  [571] = 150,
  [572] = 572,
  [573] = 436,
  [574] = 574,
  [575] = 112,
  [576] = 576,
  [577] = 115,
  [578] = 117,
  [579] = 579,
  [580] = 151,
  [581] = 482,
  [582] = 439,
  [583] = 486,
  [584] = 584,
  [585] = 121,
  [586] = 129,
  [587] = 532,
  [588] = 553,
  [589] = 550,
  [590] = 556,
  [591] = 551,
  [592] = 592,
  [593] = 504,
  [594] = 492,
  [595] = 533,
  [596] = 492,
  [597] = 545,
  [598] = 598,
  [599] = 533,
  [600] = 504,
  [601] = 545,
  [602] = 492,
  [603] = 603,
  [604] = 439,
  [605] = 605,
  [606] = 606,
  [607] = 436,
  [608] = 608,
  [609] = 609,
  [610] = 570,
  [611] = 611,
  [612] = 612,
  [613] = 576,
  [614] = 614,
  [615] = 615,
  [616] = 616,
  [617] = 617,
  [618] = 618,
  [619] = 584,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 625,
  [626] = 626,
  [627] = 626,
  [628] = 626,
  [629] = 629,
  [630] = 629,
  [631] = 629,
  [632] = 626,
  [633] = 629,
  [634] = 634,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 638,
  [639] = 638,
  [640] = 636,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 642,
  [649] = 649,
  [650] = 650,
  [651] = 533,
  [652] = 492,
  [653] = 653,
  [654] = 504,
  [655] = 545,
  [656] = 656,
  [657] = 474,
  [658] = 644,
  [659] = 492,
  [660] = 660,
  [661] = 661,
  [662] = 661,
  [663] = 492,
  [664] = 492,
  [665] = 533,
  [666] = 492,
  [667] = 533,
  [668] = 504,
  [669] = 545,
  [670] = 670,
  [671] = 492,
  [672] = 486,
  [673] = 533,
  [674] = 504,
  [675] = 504,
  [676] = 545,
  [677] = 492,
  [678] = 545,
  [679] = 492,
  [680] = 661,
  [681] = 661,
  [682] = 682,
  [683] = 683,
  [684] = 545,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 533,
  [690] = 685,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 686,
  [696] = 696,
  [697] = 492,
  [698] = 694,
  [699] = 492,
  [700] = 492,
  [701] = 701,
  [702] = 685,
  [703] = 691,
  [704] = 687,
  [705] = 686,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 685,
  [710] = 710,
  [711] = 711,
  [712] = 504,
  [713] = 696,
  [714] = 694,
  [715] = 715,
  [716] = 691,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 125,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 126,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 727,
  [738] = 736,
  [739] = 733,
  [740] = 733,
  [741] = 722,
  [742] = 136,
  [743] = 723,
  [744] = 744,
  [745] = 118,
  [746] = 731,
  [747] = 747,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 754,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 751,
  [762] = 762,
  [763] = 763,
  [764] = 750,
  [765] = 765,
  [766] = 754,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 773,
  [782] = 782,
  [783] = 783,
  [784] = 772,
  [785] = 785,
  [786] = 786,
  [787] = 777,
  [788] = 788,
  [789] = 749,
  [790] = 777,
  [791] = 791,
  [792] = 749,
  [793] = 785,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 768,
  [802] = 802,
  [803] = 785,
  [804] = 804,
  [805] = 765,
  [806] = 768,
  [807] = 772,
  [808] = 772,
  [809] = 809,
  [810] = 776,
  [811] = 811,
  [812] = 812,
  [813] = 768,
  [814] = 750,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 776,
  [819] = 756,
  [820] = 820,
  [821] = 776,
  [822] = 785,
  [823] = 779,
  [824] = 783,
  [825] = 748,
  [826] = 777,
  [827] = 779,
  [828] = 783,
  [829] = 829,
  [830] = 779,
  [831] = 783,
  [832] = 832,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(95);
      ADVANCE_MAP(
        '!', 130,
        '#', 173,
        '$', 172,
        '%', 154,
        '&', 8,
        '\'', 171,
        '(', 138,
        ')', 139,
        '*', 112,
        '+', 150,
        ',', 109,
        '-', 152,
        '.', 145,
        '/', 153,
        ':', 144,
        '<', 167,
        '=', 99,
        '>', 164,
        '?', 148,
        '@', 140,
        '[', 141,
        '\\', 76,
        ']', 142,
        'a', 232,
        'f', 246,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 190,
        'u', 233,
        'v', 191,
        '{', 108,
        '|', 158,
        '}', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(89);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 1:
      if (lookahead == '\r') ADVANCE(257);
      if (lookahead != 0) ADVANCE(256);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 130,
        '#', 258,
        '%', 154,
        '&', 8,
        '\'', 171,
        '(', 138,
        '*', 112,
        '+', 150,
        ',', 109,
        '-', 152,
        '.', 145,
        '/', 153,
        ':', 13,
        '<', 167,
        '=', 99,
        '>', 164,
        '?', 148,
        '@', 140,
        '[', 141,
        ']', 142,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 252,
        'v', 191,
        '{', 108,
        '|', 158,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 130,
        '#', 258,
        '%', 154,
        '&', 8,
        '\'', 171,
        '(', 138,
        '*', 112,
        '+', 150,
        ',', 109,
        '-', 151,
        '.', 145,
        '/', 153,
        ':', 13,
        '<', 167,
        '=', 99,
        '>', 164,
        '?', 148,
        '@', 140,
        '[', 141,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 252,
        'v', 191,
        '|', 158,
        '}', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 129,
        '#', 258,
        '\'', 171,
        '(', 138,
        ')', 139,
        ',', 109,
        '-', 152,
        '.', 145,
        '/', 10,
        '=', 100,
        '>', 163,
        '?', 147,
        '@', 140,
        '[', 141,
        ']', 142,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 252,
        'v', 191,
        '{', 108,
        '|', 157,
        '}', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (lookahead == '*' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 5:
      if (lookahead == '#') ADVANCE(173);
      if (lookahead == '$') ADVANCE(172);
      if (lookahead == '\'') ADVANCE(170);
      if (lookahead == '/') ADVANCE(175);
      if (lookahead == '\\') ADVANCE(76);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(174);
      if (lookahead != 0) ADVANCE(178);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '#', 258,
        '(', 138,
        ')', 139,
        '/', 10,
        ':', 143,
        '=', 98,
        '?', 147,
        '[', 141,
        '{', 108,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (lookahead == '*' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 7:
      if (lookahead == '#') ADVANCE(258);
      if (lookahead == ',') ADVANCE(109);
      if (lookahead == '/') ADVANCE(10);
      if (lookahead == 'a') ADVANCE(63);
      if (lookahead == '}') ADVANCE(110);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      END_STATE();
    case 8:
      if (lookahead == '&') ADVANCE(156);
      END_STATE();
    case 9:
      if (lookahead == '\'') ADVANCE(179);
      END_STATE();
    case 10:
      if (lookahead == '*') ADVANCE(12);
      if (lookahead == '/') ADVANCE(256);
      END_STATE();
    case 11:
      if (lookahead == '*') ADVANCE(11);
      if (lookahead == '/') ADVANCE(254);
      if (lookahead != 0) ADVANCE(12);
      END_STATE();
    case 12:
      if (lookahead == '*') ADVANCE(11);
      if (lookahead != 0) ADVANCE(12);
      END_STATE();
    case 13:
      if (lookahead == ':') ADVANCE(149);
      END_STATE();
    case 14:
      if (lookahead == 'S') ADVANCE(23);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(58);
      if (lookahead == 'r') ADVANCE(46);
      END_STATE();
    case 16:
      if (lookahead == 'a') ADVANCE(117);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(43);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(26);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(54);
      if (lookahead == 'e') ADVANCE(65);
      if (lookahead == 'y') ADVANCE(51);
      END_STATE();
    case 20:
      if (lookahead == 'a') ADVANCE(55);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(75);
      END_STATE();
    case 22:
      if (lookahead == 'c') ADVANCE(131);
      END_STATE();
    case 23:
      if (lookahead == 'c') ADVANCE(49);
      END_STATE();
    case 24:
      if (lookahead == 'c') ADVANCE(31);
      END_STATE();
    case 25:
      if (lookahead == 'd') ADVANCE(78);
      END_STATE();
    case 26:
      if (lookahead == 'd') ADVANCE(21);
      END_STATE();
    case 27:
      if (lookahead == 'd') ADVANCE(36);
      END_STATE();
    case 28:
      if (lookahead == 'e') ADVANCE(73);
      if (lookahead == 'o') ADVANCE(25);
      END_STATE();
    case 29:
      if (lookahead == 'e') ADVANCE(125);
      END_STATE();
    case 30:
      if (lookahead == 'e') ADVANCE(96);
      END_STATE();
    case 31:
      if (lookahead == 'e') ADVANCE(123);
      END_STATE();
    case 32:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 33:
      if (lookahead == 'e') ADVANCE(66);
      END_STATE();
    case 34:
      if (lookahead == 'e') ADVANCE(59);
      END_STATE();
    case 35:
      if (lookahead == 'e') ADVANCE(72);
      END_STATE();
    case 36:
      if (lookahead == 'e') ADVANCE(56);
      END_STATE();
    case 37:
      if (lookahead == 'g') ADVANCE(113);
      END_STATE();
    case 38:
      if (lookahead == 'g') ADVANCE(35);
      END_STATE();
    case 39:
      if (lookahead == 'i') ADVANCE(45);
      END_STATE();
    case 40:
      if (lookahead == 'i') ADVANCE(27);
      END_STATE();
    case 41:
      if (lookahead == 'l') ADVANCE(30);
      END_STATE();
    case 42:
      if (lookahead == 'm') ADVANCE(50);
      END_STATE();
    case 43:
      if (lookahead == 'm') ADVANCE(121);
      END_STATE();
    case 44:
      if (lookahead == 'n') ADVANCE(22);
      END_STATE();
    case 45:
      if (lookahead == 'n') ADVANCE(37);
      END_STATE();
    case 46:
      if (lookahead == 'o') ADVANCE(82);
      END_STATE();
    case 47:
      if (lookahead == 'o') ADVANCE(81);
      END_STATE();
    case 48:
      if (lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 49:
      if (lookahead == 'o') ADVANCE(52);
      END_STATE();
    case 50:
      if (lookahead == 'p') ADVANCE(48);
      END_STATE();
    case 51:
      if (lookahead == 'p') ADVANCE(29);
      END_STATE();
    case 52:
      if (lookahead == 'p') ADVANCE(32);
      END_STATE();
    case 53:
      if (lookahead == 'p') ADVANCE(80);
      END_STATE();
    case 54:
      if (lookahead == 'r') ADVANCE(38);
      END_STATE();
    case 55:
      if (lookahead == 'r') ADVANCE(127);
      END_STATE();
    case 56:
      if (lookahead == 'r') ADVANCE(103);
      END_STATE();
    case 57:
      if (lookahead == 'r') ADVANCE(24);
      END_STATE();
    case 58:
      if (lookahead == 'r') ADVANCE(17);
      END_STATE();
    case 59:
      if (lookahead == 'r') ADVANCE(69);
      END_STATE();
    case 60:
      if (lookahead == 'r') ADVANCE(70);
      END_STATE();
    case 61:
      if (lookahead == 's') ADVANCE(107);
      END_STATE();
    case 62:
      if (lookahead == 's') ADVANCE(39);
      END_STATE();
    case 63:
      if (lookahead == 's') ADVANCE(105);
      END_STATE();
    case 64:
      if (lookahead == 's') ADVANCE(34);
      END_STATE();
    case 65:
      if (lookahead == 's') ADVANCE(68);
      END_STATE();
    case 66:
      if (lookahead == 's') ADVANCE(47);
      END_STATE();
    case 67:
      if (lookahead == 's') ADVANCE(64);
      END_STATE();
    case 68:
      if (lookahead == 't') ADVANCE(134);
      END_STATE();
    case 69:
      if (lookahead == 't') ADVANCE(136);
      END_STATE();
    case 70:
      if (lookahead == 't') ADVANCE(101);
      END_STATE();
    case 71:
      if (lookahead == 't') ADVANCE(119);
      END_STATE();
    case 72:
      if (lookahead == 't') ADVANCE(14);
      END_STATE();
    case 73:
      if (lookahead == 't') ADVANCE(18);
      END_STATE();
    case 74:
      if (lookahead == 't') ADVANCE(53);
      END_STATE();
    case 75:
      if (lookahead == 't') ADVANCE(16);
      END_STATE();
    case 76:
      if (lookahead == 'u') ADVANCE(83);
      if (lookahead == 'x') ADVANCE(88);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(181);
      if (lookahead == '"' ||
          lookahead == '\'' ||
          lookahead == '?' ||
          lookahead == '\\' ||
          lookahead == 'a' ||
          lookahead == 'b' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          lookahead == 'r' ||
          ('t' <= lookahead && lookahead <= 'v')) ADVANCE(182);
      if (lookahead != 0) ADVANCE(180);
      END_STATE();
    case 77:
      if (lookahead == 'u') ADVANCE(44);
      END_STATE();
    case 78:
      if (lookahead == 'u') ADVANCE(41);
      END_STATE();
    case 79:
      if (lookahead == 'u') ADVANCE(74);
      END_STATE();
    case 80:
      if (lookahead == 'u') ADVANCE(71);
      END_STATE();
    case 81:
      if (lookahead == 'u') ADVANCE(57);
      END_STATE();
    case 82:
      if (lookahead == 'v') ADVANCE(40);
      END_STATE();
    case 83:
      if (lookahead == '{') ADVANCE(87);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(85);
      END_STATE();
    case 84:
      if (lookahead == '}') ADVANCE(182);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(84);
      END_STATE();
    case 85:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(88);
      END_STATE();
    case 86:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(182);
      END_STATE();
    case 87:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(84);
      END_STATE();
    case 88:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      END_STATE();
    case 89:
      if (eof) ADVANCE(95);
      ADVANCE_MAP(
        '!', 130,
        '#', 173,
        '$', 172,
        '%', 154,
        '&', 8,
        '\'', 171,
        '(', 138,
        ')', 139,
        '*', 112,
        '+', 150,
        ',', 109,
        '-', 152,
        '.', 145,
        '/', 153,
        ':', 144,
        '<', 167,
        '=', 99,
        '>', 164,
        '?', 148,
        '@', 140,
        '[', 141,
        ']', 142,
        'a', 232,
        'f', 246,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 190,
        'u', 233,
        'v', 191,
        '{', 108,
        '|', 158,
        '}', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(89);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 90:
      if (eof) ADVANCE(95);
      ADVANCE_MAP(
        '!', 130,
        '#', 258,
        '%', 154,
        '&', 8,
        '\'', 171,
        '(', 138,
        ')', 139,
        '*', 111,
        '+', 150,
        ',', 109,
        '-', 151,
        '.', 145,
        '/', 153,
        ':', 144,
        '<', 167,
        '=', 99,
        '>', 164,
        '?', 148,
        '@', 140,
        '[', 141,
        ']', 142,
        'a', 61,
        'f', 77,
        'i', 42,
        'm', 28,
        'o', 79,
        'p', 15,
        'r', 33,
        't', 19,
        'u', 62,
        'v', 20,
        '{', 108,
        '|', 158,
        '}', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(90);
      END_STATE();
    case 91:
      if (eof) ADVANCE(95);
      ADVANCE_MAP(
        '!', 130,
        '#', 258,
        '%', 154,
        '&', 8,
        '(', 138,
        ')', 139,
        '*', 112,
        '+', 150,
        ',', 109,
        '-', 151,
        '.', 145,
        '/', 153,
        ':', 144,
        '<', 167,
        '=', 99,
        '>', 164,
        '?', 148,
        '@', 140,
        '[', 141,
        ']', 142,
        'a', 232,
        'f', 246,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 190,
        'u', 233,
        'v', 191,
        '|', 158,
        '}', 110,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(91);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 92:
      if (eof) ADVANCE(95);
      ADVANCE_MAP(
        '!', 129,
        '#', 258,
        '\'', 171,
        '(', 138,
        '-', 152,
        '/', 10,
        '=', 98,
        '@', 140,
        '[', 141,
        'a', 237,
        'f', 246,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 190,
        'u', 233,
        'v', 191,
        '{', 108,
        '|', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(92);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      if (lookahead == '*' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 93:
      if (eof) ADVANCE(95);
      ADVANCE_MAP(
        '!', 129,
        '#', 258,
        ')', 139,
        ',', 109,
        '.', 145,
        '/', 10,
        '=', 100,
        '?', 147,
        '@', 140,
        '[', 141,
        'a', 67,
        'f', 77,
        'i', 42,
        'm', 28,
        'o', 79,
        'p', 15,
        'r', 33,
        't', 19,
        'u', 62,
        'v', 20,
        '|', 157,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(93);
      END_STATE();
    case 94:
      if (eof) ADVANCE(95);
      ADVANCE_MAP(
        '#', 258,
        '/', 10,
        '@', 140,
        'a', 232,
        'f', 246,
        'i', 213,
        'm', 199,
        'o', 248,
        'p', 186,
        'r', 204,
        't', 190,
        'u', 233,
        'v', 191,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(94);
      if (lookahead == '*' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_module);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(159);
      if (lookahead == '>') ADVANCE(133);
      if (lookahead == '~') ADVANCE(161);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(133);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_import);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_provider);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_provider);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_as);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(205);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(34);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_using);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_targetScope);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_targetScope);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_metadata);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_metadata);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_output);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_output);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_param);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_param);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_resource);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_resource);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_type);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_var);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(160);
      if (lookahead == '~') ADVANCE(162);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_func);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_func);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_test);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_test);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_assert);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(149);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '?') ADVANCE(146);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_DOT_QMARK);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '?') ADVANCE(168);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(12);
      if (lookahead == '/') ADVANCE(256);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(155);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_EQ_TILDE);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_BANG_TILDE);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(166);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(sym_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(169);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '\'') ADVANCE(9);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '{') ADVANCE(184);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '#') ADVANCE(173);
      if (lookahead == '$') ADVANCE(172);
      if (lookahead == '\'') ADVANCE(170);
      if (lookahead == '/') ADVANCE(175);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(174);
      if (lookahead != 0 &&
          lookahead != '\\') ADVANCE(178);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '*') ADVANCE(177);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead != 0 &&
          lookahead != '$' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(178);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '*') ADVANCE(176);
      if (lookahead == '/') ADVANCE(254);
      if (lookahead == '$' ||
          lookahead == '\'' ||
          lookahead == '\\') ADVANCE(12);
      if (lookahead != 0) ADVANCE(177);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead == '*') ADVANCE(176);
      if (lookahead == '$' ||
          lookahead == '\'' ||
          lookahead == '\\') ADVANCE(12);
      if (lookahead != 0) ADVANCE(177);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_string_content);
      if (lookahead != 0 &&
          lookahead != '$' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(178);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_SQUOTE_SQUOTE_SQUOTE);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(aux_sym__escape_sequence_token1);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(aux_sym__escape_sequence_token1);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(183);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(182);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LBRACE);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S') ADVANCE(194);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(229);
      if (lookahead == 'r') ADVANCE(217);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(118);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(214);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(197);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(225);
      if (lookahead == 'e') ADVANCE(235);
      if (lookahead == 'y') ADVANCE(222);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(226);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(245);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(132);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(220);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(202);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(247);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(192);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(207);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(243);
      if (lookahead == 'o') ADVANCE(196);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(126);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(97);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(124);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(116);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(236);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(230);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(242);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(227);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(114);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(206);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(216);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(198);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(201);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(221);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(122);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(193);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(208);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(251);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(250);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(231);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(223);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(219);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(200);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(203);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(249);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(209);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(128);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(104);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(195);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(188);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(239);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(240);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(106);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(210);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(205);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(238);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(218);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(234);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(135);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(102);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(120);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(185);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(189);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(224);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(187);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(215);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(212);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(244);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(241);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(228);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'v') ADVANCE(211);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(222);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(253);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(1);
      if (lookahead == '$' ||
          lookahead == '\'') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(255);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(256);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(1);
      if (lookahead != 0) ADVANCE(256);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(sym_diagnostic_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(258);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'e', 3,
        'f', 4,
        'i', 5,
        'n', 6,
        'o', 7,
        's', 8,
        't', 9,
        'w', 10,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'r') ADVANCE(11);
      END_STATE();
    case 2:
      if (lookahead == 'o') ADVANCE(12);
      END_STATE();
    case 3:
      if (lookahead == 'x') ADVANCE(13);
      END_STATE();
    case 4:
      if (lookahead == 'a') ADVANCE(14);
      if (lookahead == 'o') ADVANCE(15);
      if (lookahead == 'r') ADVANCE(16);
      END_STATE();
    case 5:
      if (lookahead == 'f') ADVANCE(17);
      if (lookahead == 'n') ADVANCE(18);
      END_STATE();
    case 6:
      if (lookahead == 'u') ADVANCE(19);
      END_STATE();
    case 7:
      if (lookahead == 'b') ADVANCE(20);
      END_STATE();
    case 8:
      if (lookahead == 'e') ADVANCE(21);
      if (lookahead == 't') ADVANCE(22);
      END_STATE();
    case 9:
      if (lookahead == 'r') ADVANCE(23);
      END_STATE();
    case 10:
      if (lookahead == 'i') ADVANCE(24);
      END_STATE();
    case 11:
      if (lookahead == 'r') ADVANCE(25);
      END_STATE();
    case 12:
      if (lookahead == 'o') ADVANCE(26);
      END_STATE();
    case 13:
      if (lookahead == 'i') ADVANCE(27);
      END_STATE();
    case 14:
      if (lookahead == 'l') ADVANCE(28);
      END_STATE();
    case 15:
      if (lookahead == 'r') ADVANCE(29);
      END_STATE();
    case 16:
      if (lookahead == 'o') ADVANCE(30);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 18:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 't') ADVANCE(31);
      END_STATE();
    case 19:
      if (lookahead == 'l') ADVANCE(32);
      END_STATE();
    case 20:
      if (lookahead == 'j') ADVANCE(33);
      END_STATE();
    case 21:
      if (lookahead == 'c') ADVANCE(34);
      END_STATE();
    case 22:
      if (lookahead == 'r') ADVANCE(35);
      END_STATE();
    case 23:
      if (lookahead == 'u') ADVANCE(36);
      END_STATE();
    case 24:
      if (lookahead == 't') ADVANCE(37);
      END_STATE();
    case 25:
      if (lookahead == 'a') ADVANCE(38);
      END_STATE();
    case 26:
      if (lookahead == 'l') ADVANCE(39);
      END_STATE();
    case 27:
      if (lookahead == 's') ADVANCE(40);
      END_STATE();
    case 28:
      if (lookahead == 's') ADVANCE(41);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 30:
      if (lookahead == 'm') ADVANCE(42);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_int);
      END_STATE();
    case 32:
      if (lookahead == 'l') ADVANCE(43);
      END_STATE();
    case 33:
      if (lookahead == 'e') ADVANCE(44);
      END_STATE();
    case 34:
      if (lookahead == 'u') ADVANCE(45);
      END_STATE();
    case 35:
      if (lookahead == 'i') ADVANCE(46);
      END_STATE();
    case 36:
      if (lookahead == 'e') ADVANCE(47);
      END_STATE();
    case 37:
      if (lookahead == 'h') ADVANCE(48);
      END_STATE();
    case 38:
      if (lookahead == 'y') ADVANCE(49);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 40:
      if (lookahead == 't') ADVANCE(50);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(51);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(sym_null);
      END_STATE();
    case 44:
      if (lookahead == 'c') ADVANCE(52);
      END_STATE();
    case 45:
      if (lookahead == 'r') ADVANCE(53);
      END_STATE();
    case 46:
      if (lookahead == 'n') ADVANCE(54);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_array);
      END_STATE();
    case 50:
      if (lookahead == 'i') ADVANCE(55);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 52:
      if (lookahead == 't') ADVANCE(56);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(57);
      END_STATE();
    case 54:
      if (lookahead == 'g') ADVANCE(58);
      END_STATE();
    case 55:
      if (lookahead == 'n') ADVANCE(59);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_object);
      END_STATE();
    case 57:
      if (lookahead == 'O') ADVANCE(60);
      if (lookahead == 'S') ADVANCE(61);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 59:
      if (lookahead == 'g') ADVANCE(62);
      END_STATE();
    case 60:
      if (lookahead == 'b') ADVANCE(63);
      END_STATE();
    case 61:
      if (lookahead == 't') ADVANCE(64);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_existing);
      END_STATE();
    case 63:
      if (lookahead == 'j') ADVANCE(65);
      END_STATE();
    case 64:
      if (lookahead == 'r') ADVANCE(66);
      END_STATE();
    case 65:
      if (lookahead == 'e') ADVANCE(67);
      END_STATE();
    case 66:
      if (lookahead == 'i') ADVANCE(68);
      END_STATE();
    case 67:
      if (lookahead == 'c') ADVANCE(69);
      END_STATE();
    case 68:
      if (lookahead == 'n') ADVANCE(70);
      END_STATE();
    case 69:
      if (lookahead == 't') ADVANCE(71);
      END_STATE();
    case 70:
      if (lookahead == 'g') ADVANCE(72);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_secureObject);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_secureString);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 90},
  [2] = {.lex_state = 2},
  [3] = {.lex_state = 2},
  [4] = {.lex_state = 2},
  [5] = {.lex_state = 2},
  [6] = {.lex_state = 2},
  [7] = {.lex_state = 2},
  [8] = {.lex_state = 2},
  [9] = {.lex_state = 4},
  [10] = {.lex_state = 4},
  [11] = {.lex_state = 4},
  [12] = {.lex_state = 4},
  [13] = {.lex_state = 4},
  [14] = {.lex_state = 4},
  [15] = {.lex_state = 4},
  [16] = {.lex_state = 4},
  [17] = {.lex_state = 4},
  [18] = {.lex_state = 4},
  [19] = {.lex_state = 4},
  [20] = {.lex_state = 4},
  [21] = {.lex_state = 4},
  [22] = {.lex_state = 4},
  [23] = {.lex_state = 4},
  [24] = {.lex_state = 4},
  [25] = {.lex_state = 4},
  [26] = {.lex_state = 4},
  [27] = {.lex_state = 4},
  [28] = {.lex_state = 4},
  [29] = {.lex_state = 4},
  [30] = {.lex_state = 4},
  [31] = {.lex_state = 4},
  [32] = {.lex_state = 4},
  [33] = {.lex_state = 4},
  [34] = {.lex_state = 4},
  [35] = {.lex_state = 4},
  [36] = {.lex_state = 4},
  [37] = {.lex_state = 4},
  [38] = {.lex_state = 4},
  [39] = {.lex_state = 4},
  [40] = {.lex_state = 4},
  [41] = {.lex_state = 4},
  [42] = {.lex_state = 4},
  [43] = {.lex_state = 4},
  [44] = {.lex_state = 4},
  [45] = {.lex_state = 4},
  [46] = {.lex_state = 4},
  [47] = {.lex_state = 4},
  [48] = {.lex_state = 4},
  [49] = {.lex_state = 4},
  [50] = {.lex_state = 4},
  [51] = {.lex_state = 4},
  [52] = {.lex_state = 4},
  [53] = {.lex_state = 4},
  [54] = {.lex_state = 92},
  [55] = {.lex_state = 92},
  [56] = {.lex_state = 4},
  [57] = {.lex_state = 4},
  [58] = {.lex_state = 4},
  [59] = {.lex_state = 4},
  [60] = {.lex_state = 4},
  [61] = {.lex_state = 4},
  [62] = {.lex_state = 4},
  [63] = {.lex_state = 4},
  [64] = {.lex_state = 4},
  [65] = {.lex_state = 4},
  [66] = {.lex_state = 4},
  [67] = {.lex_state = 4},
  [68] = {.lex_state = 4},
  [69] = {.lex_state = 4},
  [70] = {.lex_state = 4},
  [71] = {.lex_state = 4},
  [72] = {.lex_state = 4},
  [73] = {.lex_state = 4},
  [74] = {.lex_state = 4, .external_lex_state = 2},
  [75] = {.lex_state = 4},
  [76] = {.lex_state = 4},
  [77] = {.lex_state = 4},
  [78] = {.lex_state = 4},
  [79] = {.lex_state = 2},
  [80] = {.lex_state = 2},
  [81] = {.lex_state = 2},
  [82] = {.lex_state = 2},
  [83] = {.lex_state = 2},
  [84] = {.lex_state = 2},
  [85] = {.lex_state = 2},
  [86] = {.lex_state = 2},
  [87] = {.lex_state = 2},
  [88] = {.lex_state = 2},
  [89] = {.lex_state = 2},
  [90] = {.lex_state = 2},
  [91] = {.lex_state = 2},
  [92] = {.lex_state = 2},
  [93] = {.lex_state = 2},
  [94] = {.lex_state = 2},
  [95] = {.lex_state = 2},
  [96] = {.lex_state = 2},
  [97] = {.lex_state = 2},
  [98] = {.lex_state = 2},
  [99] = {.lex_state = 2},
  [100] = {.lex_state = 2},
  [101] = {.lex_state = 2},
  [102] = {.lex_state = 2},
  [103] = {.lex_state = 2},
  [104] = {.lex_state = 2},
  [105] = {.lex_state = 2},
  [106] = {.lex_state = 2},
  [107] = {.lex_state = 2},
  [108] = {.lex_state = 2},
  [109] = {.lex_state = 2},
  [110] = {.lex_state = 2},
  [111] = {.lex_state = 4},
  [112] = {.lex_state = 2},
  [113] = {.lex_state = 2},
  [114] = {.lex_state = 2},
  [115] = {.lex_state = 2},
  [116] = {.lex_state = 2},
  [117] = {.lex_state = 2},
  [118] = {.lex_state = 2},
  [119] = {.lex_state = 2},
  [120] = {.lex_state = 4},
  [121] = {.lex_state = 2},
  [122] = {.lex_state = 2},
  [123] = {.lex_state = 2},
  [124] = {.lex_state = 2},
  [125] = {.lex_state = 2},
  [126] = {.lex_state = 2},
  [127] = {.lex_state = 4},
  [128] = {.lex_state = 2},
  [129] = {.lex_state = 2},
  [130] = {.lex_state = 2},
  [131] = {.lex_state = 2},
  [132] = {.lex_state = 2},
  [133] = {.lex_state = 4},
  [134] = {.lex_state = 4},
  [135] = {.lex_state = 2},
  [136] = {.lex_state = 2},
  [137] = {.lex_state = 4},
  [138] = {.lex_state = 4},
  [139] = {.lex_state = 4},
  [140] = {.lex_state = 4},
  [141] = {.lex_state = 2},
  [142] = {.lex_state = 2},
  [143] = {.lex_state = 4},
  [144] = {.lex_state = 4},
  [145] = {.lex_state = 4},
  [146] = {.lex_state = 2},
  [147] = {.lex_state = 4},
  [148] = {.lex_state = 4},
  [149] = {.lex_state = 2},
  [150] = {.lex_state = 2},
  [151] = {.lex_state = 2},
  [152] = {.lex_state = 4},
  [153] = {.lex_state = 4},
  [154] = {.lex_state = 4},
  [155] = {.lex_state = 4},
  [156] = {.lex_state = 4},
  [157] = {.lex_state = 4},
  [158] = {.lex_state = 4},
  [159] = {.lex_state = 4},
  [160] = {.lex_state = 4},
  [161] = {.lex_state = 4},
  [162] = {.lex_state = 4},
  [163] = {.lex_state = 4},
  [164] = {.lex_state = 4},
  [165] = {.lex_state = 4},
  [166] = {.lex_state = 4},
  [167] = {.lex_state = 4},
  [168] = {.lex_state = 4},
  [169] = {.lex_state = 4},
  [170] = {.lex_state = 4},
  [171] = {.lex_state = 4},
  [172] = {.lex_state = 4},
  [173] = {.lex_state = 4},
  [174] = {.lex_state = 4},
  [175] = {.lex_state = 4},
  [176] = {.lex_state = 4},
  [177] = {.lex_state = 4},
  [178] = {.lex_state = 4},
  [179] = {.lex_state = 4},
  [180] = {.lex_state = 3, .external_lex_state = 2},
  [181] = {.lex_state = 3, .external_lex_state = 2},
  [182] = {.lex_state = 4},
  [183] = {.lex_state = 4},
  [184] = {.lex_state = 4},
  [185] = {.lex_state = 4},
  [186] = {.lex_state = 4},
  [187] = {.lex_state = 4},
  [188] = {.lex_state = 4},
  [189] = {.lex_state = 4},
  [190] = {.lex_state = 3, .external_lex_state = 2},
  [191] = {.lex_state = 4},
  [192] = {.lex_state = 4},
  [193] = {.lex_state = 4},
  [194] = {.lex_state = 4},
  [195] = {.lex_state = 4},
  [196] = {.lex_state = 4},
  [197] = {.lex_state = 4},
  [198] = {.lex_state = 4},
  [199] = {.lex_state = 3, .external_lex_state = 2},
  [200] = {.lex_state = 4},
  [201] = {.lex_state = 4},
  [202] = {.lex_state = 4},
  [203] = {.lex_state = 4},
  [204] = {.lex_state = 4},
  [205] = {.lex_state = 4},
  [206] = {.lex_state = 4},
  [207] = {.lex_state = 4},
  [208] = {.lex_state = 4},
  [209] = {.lex_state = 4},
  [210] = {.lex_state = 4},
  [211] = {.lex_state = 4},
  [212] = {.lex_state = 4},
  [213] = {.lex_state = 4},
  [214] = {.lex_state = 4},
  [215] = {.lex_state = 4},
  [216] = {.lex_state = 4},
  [217] = {.lex_state = 4},
  [218] = {.lex_state = 4},
  [219] = {.lex_state = 4},
  [220] = {.lex_state = 4},
  [221] = {.lex_state = 3, .external_lex_state = 2},
  [222] = {.lex_state = 3, .external_lex_state = 2},
  [223] = {.lex_state = 4},
  [224] = {.lex_state = 4},
  [225] = {.lex_state = 2},
  [226] = {.lex_state = 4},
  [227] = {.lex_state = 4},
  [228] = {.lex_state = 4},
  [229] = {.lex_state = 4},
  [230] = {.lex_state = 4},
  [231] = {.lex_state = 4},
  [232] = {.lex_state = 4},
  [233] = {.lex_state = 4},
  [234] = {.lex_state = 4},
  [235] = {.lex_state = 4},
  [236] = {.lex_state = 4},
  [237] = {.lex_state = 4},
  [238] = {.lex_state = 4},
  [239] = {.lex_state = 4},
  [240] = {.lex_state = 4},
  [241] = {.lex_state = 4},
  [242] = {.lex_state = 4},
  [243] = {.lex_state = 4},
  [244] = {.lex_state = 4},
  [245] = {.lex_state = 4},
  [246] = {.lex_state = 4},
  [247] = {.lex_state = 4},
  [248] = {.lex_state = 4},
  [249] = {.lex_state = 4},
  [250] = {.lex_state = 4},
  [251] = {.lex_state = 4},
  [252] = {.lex_state = 4},
  [253] = {.lex_state = 4},
  [254] = {.lex_state = 3, .external_lex_state = 2},
  [255] = {.lex_state = 3, .external_lex_state = 2},
  [256] = {.lex_state = 91},
  [257] = {.lex_state = 3, .external_lex_state = 2},
  [258] = {.lex_state = 3, .external_lex_state = 2},
  [259] = {.lex_state = 3, .external_lex_state = 2},
  [260] = {.lex_state = 3, .external_lex_state = 2},
  [261] = {.lex_state = 3, .external_lex_state = 2},
  [262] = {.lex_state = 3, .external_lex_state = 2},
  [263] = {.lex_state = 3, .external_lex_state = 2},
  [264] = {.lex_state = 3, .external_lex_state = 2},
  [265] = {.lex_state = 3, .external_lex_state = 2},
  [266] = {.lex_state = 3, .external_lex_state = 2},
  [267] = {.lex_state = 3, .external_lex_state = 2},
  [268] = {.lex_state = 3, .external_lex_state = 2},
  [269] = {.lex_state = 91},
  [270] = {.lex_state = 3, .external_lex_state = 2},
  [271] = {.lex_state = 3, .external_lex_state = 2},
  [272] = {.lex_state = 3, .external_lex_state = 2},
  [273] = {.lex_state = 3, .external_lex_state = 2},
  [274] = {.lex_state = 3, .external_lex_state = 2},
  [275] = {.lex_state = 91},
  [276] = {.lex_state = 3, .external_lex_state = 2},
  [277] = {.lex_state = 3, .external_lex_state = 2},
  [278] = {.lex_state = 3, .external_lex_state = 2},
  [279] = {.lex_state = 3, .external_lex_state = 2},
  [280] = {.lex_state = 3, .external_lex_state = 2},
  [281] = {.lex_state = 3, .external_lex_state = 2},
  [282] = {.lex_state = 3, .external_lex_state = 2},
  [283] = {.lex_state = 3, .external_lex_state = 2},
  [284] = {.lex_state = 3, .external_lex_state = 2},
  [285] = {.lex_state = 3, .external_lex_state = 2},
  [286] = {.lex_state = 91},
  [287] = {.lex_state = 3, .external_lex_state = 2},
  [288] = {.lex_state = 3, .external_lex_state = 2},
  [289] = {.lex_state = 90},
  [290] = {.lex_state = 3, .external_lex_state = 2},
  [291] = {.lex_state = 90},
  [292] = {.lex_state = 3, .external_lex_state = 2},
  [293] = {.lex_state = 3, .external_lex_state = 2},
  [294] = {.lex_state = 3, .external_lex_state = 2},
  [295] = {.lex_state = 3, .external_lex_state = 2},
  [296] = {.lex_state = 3, .external_lex_state = 2},
  [297] = {.lex_state = 3, .external_lex_state = 2},
  [298] = {.lex_state = 3, .external_lex_state = 2},
  [299] = {.lex_state = 3, .external_lex_state = 2},
  [300] = {.lex_state = 3, .external_lex_state = 2},
  [301] = {.lex_state = 3, .external_lex_state = 2},
  [302] = {.lex_state = 3, .external_lex_state = 2},
  [303] = {.lex_state = 3, .external_lex_state = 2},
  [304] = {.lex_state = 3, .external_lex_state = 2},
  [305] = {.lex_state = 3, .external_lex_state = 2},
  [306] = {.lex_state = 3, .external_lex_state = 2},
  [307] = {.lex_state = 3, .external_lex_state = 2},
  [308] = {.lex_state = 3, .external_lex_state = 2},
  [309] = {.lex_state = 3, .external_lex_state = 2},
  [310] = {.lex_state = 3, .external_lex_state = 2},
  [311] = {.lex_state = 3, .external_lex_state = 2},
  [312] = {.lex_state = 3, .external_lex_state = 2},
  [313] = {.lex_state = 3, .external_lex_state = 2},
  [314] = {.lex_state = 3, .external_lex_state = 2},
  [315] = {.lex_state = 3, .external_lex_state = 2},
  [316] = {.lex_state = 3, .external_lex_state = 2},
  [317] = {.lex_state = 3, .external_lex_state = 2},
  [318] = {.lex_state = 3, .external_lex_state = 2},
  [319] = {.lex_state = 90},
  [320] = {.lex_state = 90},
  [321] = {.lex_state = 90},
  [322] = {.lex_state = 3, .external_lex_state = 2},
  [323] = {.lex_state = 3, .external_lex_state = 2},
  [324] = {.lex_state = 3, .external_lex_state = 2},
  [325] = {.lex_state = 90},
  [326] = {.lex_state = 3, .external_lex_state = 2},
  [327] = {.lex_state = 90},
  [328] = {.lex_state = 90},
  [329] = {.lex_state = 90},
  [330] = {.lex_state = 90},
  [331] = {.lex_state = 90},
  [332] = {.lex_state = 90},
  [333] = {.lex_state = 90},
  [334] = {.lex_state = 90},
  [335] = {.lex_state = 90},
  [336] = {.lex_state = 90},
  [337] = {.lex_state = 90},
  [338] = {.lex_state = 90},
  [339] = {.lex_state = 90},
  [340] = {.lex_state = 90},
  [341] = {.lex_state = 90},
  [342] = {.lex_state = 90},
  [343] = {.lex_state = 90},
  [344] = {.lex_state = 90},
  [345] = {.lex_state = 90},
  [346] = {.lex_state = 90},
  [347] = {.lex_state = 90},
  [348] = {.lex_state = 90},
  [349] = {.lex_state = 90},
  [350] = {.lex_state = 90},
  [351] = {.lex_state = 90},
  [352] = {.lex_state = 90},
  [353] = {.lex_state = 90},
  [354] = {.lex_state = 90},
  [355] = {.lex_state = 90},
  [356] = {.lex_state = 90},
  [357] = {.lex_state = 90},
  [358] = {.lex_state = 90},
  [359] = {.lex_state = 90},
  [360] = {.lex_state = 90},
  [361] = {.lex_state = 90},
  [362] = {.lex_state = 90},
  [363] = {.lex_state = 90},
  [364] = {.lex_state = 90},
  [365] = {.lex_state = 90},
  [366] = {.lex_state = 90},
  [367] = {.lex_state = 90},
  [368] = {.lex_state = 3, .external_lex_state = 2},
  [369] = {.lex_state = 90},
  [370] = {.lex_state = 90},
  [371] = {.lex_state = 90},
  [372] = {.lex_state = 90},
  [373] = {.lex_state = 90},
  [374] = {.lex_state = 90},
  [375] = {.lex_state = 90},
  [376] = {.lex_state = 90},
  [377] = {.lex_state = 90},
  [378] = {.lex_state = 90},
  [379] = {.lex_state = 90},
  [380] = {.lex_state = 90},
  [381] = {.lex_state = 90},
  [382] = {.lex_state = 90},
  [383] = {.lex_state = 90},
  [384] = {.lex_state = 90},
  [385] = {.lex_state = 90},
  [386] = {.lex_state = 90},
  [387] = {.lex_state = 90},
  [388] = {.lex_state = 90},
  [389] = {.lex_state = 90},
  [390] = {.lex_state = 90},
  [391] = {.lex_state = 90},
  [392] = {.lex_state = 90},
  [393] = {.lex_state = 90},
  [394] = {.lex_state = 90},
  [395] = {.lex_state = 90},
  [396] = {.lex_state = 90},
  [397] = {.lex_state = 90},
  [398] = {.lex_state = 90},
  [399] = {.lex_state = 90},
  [400] = {.lex_state = 90},
  [401] = {.lex_state = 90},
  [402] = {.lex_state = 90},
  [403] = {.lex_state = 90},
  [404] = {.lex_state = 90},
  [405] = {.lex_state = 90},
  [406] = {.lex_state = 90},
  [407] = {.lex_state = 90},
  [408] = {.lex_state = 90},
  [409] = {.lex_state = 90},
  [410] = {.lex_state = 90},
  [411] = {.lex_state = 90},
  [412] = {.lex_state = 90},
  [413] = {.lex_state = 90},
  [414] = {.lex_state = 90},
  [415] = {.lex_state = 90},
  [416] = {.lex_state = 90},
  [417] = {.lex_state = 90},
  [418] = {.lex_state = 4, .external_lex_state = 2},
  [419] = {.lex_state = 4, .external_lex_state = 2},
  [420] = {.lex_state = 4, .external_lex_state = 2},
  [421] = {.lex_state = 4, .external_lex_state = 2},
  [422] = {.lex_state = 4, .external_lex_state = 2},
  [423] = {.lex_state = 4, .external_lex_state = 2},
  [424] = {.lex_state = 4, .external_lex_state = 2},
  [425] = {.lex_state = 4, .external_lex_state = 2},
  [426] = {.lex_state = 4, .external_lex_state = 2},
  [427] = {.lex_state = 4, .external_lex_state = 2},
  [428] = {.lex_state = 4, .external_lex_state = 2},
  [429] = {.lex_state = 4, .external_lex_state = 2},
  [430] = {.lex_state = 4, .external_lex_state = 2},
  [431] = {.lex_state = 4, .external_lex_state = 2},
  [432] = {.lex_state = 4, .external_lex_state = 2},
  [433] = {.lex_state = 4, .external_lex_state = 2},
  [434] = {.lex_state = 4, .external_lex_state = 2},
  [435] = {.lex_state = 4, .external_lex_state = 2},
  [436] = {.lex_state = 4},
  [437] = {.lex_state = 4, .external_lex_state = 2},
  [438] = {.lex_state = 4, .external_lex_state = 2},
  [439] = {.lex_state = 4},
  [440] = {.lex_state = 4, .external_lex_state = 2},
  [441] = {.lex_state = 4, .external_lex_state = 2},
  [442] = {.lex_state = 4, .external_lex_state = 2},
  [443] = {.lex_state = 4, .external_lex_state = 2},
  [444] = {.lex_state = 4, .external_lex_state = 2},
  [445] = {.lex_state = 4, .external_lex_state = 2},
  [446] = {.lex_state = 4, .external_lex_state = 2},
  [447] = {.lex_state = 4, .external_lex_state = 2},
  [448] = {.lex_state = 4, .external_lex_state = 2},
  [449] = {.lex_state = 4, .external_lex_state = 2},
  [450] = {.lex_state = 4, .external_lex_state = 2},
  [451] = {.lex_state = 4, .external_lex_state = 2},
  [452] = {.lex_state = 4, .external_lex_state = 2},
  [453] = {.lex_state = 4, .external_lex_state = 2},
  [454] = {.lex_state = 90},
  [455] = {.lex_state = 4},
  [456] = {.lex_state = 4},
  [457] = {.lex_state = 90},
  [458] = {.lex_state = 4},
  [459] = {.lex_state = 90},
  [460] = {.lex_state = 90},
  [461] = {.lex_state = 90},
  [462] = {.lex_state = 4, .external_lex_state = 2},
  [463] = {.lex_state = 4, .external_lex_state = 2},
  [464] = {.lex_state = 90},
  [465] = {.lex_state = 90},
  [466] = {.lex_state = 4, .external_lex_state = 2},
  [467] = {.lex_state = 90},
  [468] = {.lex_state = 90},
  [469] = {.lex_state = 90},
  [470] = {.lex_state = 90},
  [471] = {.lex_state = 4, .external_lex_state = 2},
  [472] = {.lex_state = 90},
  [473] = {.lex_state = 4, .external_lex_state = 2},
  [474] = {.lex_state = 4, .external_lex_state = 2},
  [475] = {.lex_state = 90},
  [476] = {.lex_state = 4, .external_lex_state = 2},
  [477] = {.lex_state = 90},
  [478] = {.lex_state = 4, .external_lex_state = 2},
  [479] = {.lex_state = 4, .external_lex_state = 2},
  [480] = {.lex_state = 4, .external_lex_state = 2},
  [481] = {.lex_state = 90},
  [482] = {.lex_state = 4, .external_lex_state = 2},
  [483] = {.lex_state = 90},
  [484] = {.lex_state = 4, .external_lex_state = 2},
  [485] = {.lex_state = 90},
  [486] = {.lex_state = 4, .external_lex_state = 2},
  [487] = {.lex_state = 90},
  [488] = {.lex_state = 90},
  [489] = {.lex_state = 90},
  [490] = {.lex_state = 4, .external_lex_state = 2},
  [491] = {.lex_state = 90},
  [492] = {.lex_state = 4, .external_lex_state = 2},
  [493] = {.lex_state = 90},
  [494] = {.lex_state = 90},
  [495] = {.lex_state = 90},
  [496] = {.lex_state = 4, .external_lex_state = 2},
  [497] = {.lex_state = 90},
  [498] = {.lex_state = 90},
  [499] = {.lex_state = 90},
  [500] = {.lex_state = 90},
  [501] = {.lex_state = 90},
  [502] = {.lex_state = 90},
  [503] = {.lex_state = 90},
  [504] = {.lex_state = 4, .external_lex_state = 2},
  [505] = {.lex_state = 90},
  [506] = {.lex_state = 90},
  [507] = {.lex_state = 4, .external_lex_state = 2},
  [508] = {.lex_state = 90},
  [509] = {.lex_state = 90},
  [510] = {.lex_state = 90},
  [511] = {.lex_state = 90},
  [512] = {.lex_state = 90},
  [513] = {.lex_state = 90},
  [514] = {.lex_state = 90},
  [515] = {.lex_state = 90},
  [516] = {.lex_state = 90},
  [517] = {.lex_state = 90},
  [518] = {.lex_state = 90},
  [519] = {.lex_state = 90},
  [520] = {.lex_state = 90},
  [521] = {.lex_state = 90},
  [522] = {.lex_state = 90},
  [523] = {.lex_state = 90},
  [524] = {.lex_state = 90},
  [525] = {.lex_state = 90},
  [526] = {.lex_state = 90},
  [527] = {.lex_state = 90},
  [528] = {.lex_state = 4, .external_lex_state = 2},
  [529] = {.lex_state = 90},
  [530] = {.lex_state = 90},
  [531] = {.lex_state = 4, .external_lex_state = 2},
  [532] = {.lex_state = 4, .external_lex_state = 2},
  [533] = {.lex_state = 4, .external_lex_state = 2},
  [534] = {.lex_state = 4, .external_lex_state = 2},
  [535] = {.lex_state = 90},
  [536] = {.lex_state = 90},
  [537] = {.lex_state = 90},
  [538] = {.lex_state = 90},
  [539] = {.lex_state = 90},
  [540] = {.lex_state = 90},
  [541] = {.lex_state = 90},
  [542] = {.lex_state = 90},
  [543] = {.lex_state = 90},
  [544] = {.lex_state = 90},
  [545] = {.lex_state = 4, .external_lex_state = 2},
  [546] = {.lex_state = 90},
  [547] = {.lex_state = 4, .external_lex_state = 2},
  [548] = {.lex_state = 4, .external_lex_state = 2},
  [549] = {.lex_state = 90},
  [550] = {.lex_state = 4, .external_lex_state = 2},
  [551] = {.lex_state = 4, .external_lex_state = 2},
  [552] = {.lex_state = 90},
  [553] = {.lex_state = 4, .external_lex_state = 2},
  [554] = {.lex_state = 90},
  [555] = {.lex_state = 90},
  [556] = {.lex_state = 4, .external_lex_state = 2},
  [557] = {.lex_state = 90},
  [558] = {.lex_state = 90},
  [559] = {.lex_state = 93},
  [560] = {.lex_state = 93},
  [561] = {.lex_state = 4, .external_lex_state = 2},
  [562] = {.lex_state = 93},
  [563] = {.lex_state = 93},
  [564] = {.lex_state = 4, .external_lex_state = 2},
  [565] = {.lex_state = 90},
  [566] = {.lex_state = 93},
  [567] = {.lex_state = 93},
  [568] = {.lex_state = 4, .external_lex_state = 2},
  [569] = {.lex_state = 93},
  [570] = {.lex_state = 4, .external_lex_state = 2},
  [571] = {.lex_state = 4, .external_lex_state = 2},
  [572] = {.lex_state = 4, .external_lex_state = 2},
  [573] = {.lex_state = 4, .external_lex_state = 2},
  [574] = {.lex_state = 4, .external_lex_state = 2},
  [575] = {.lex_state = 4, .external_lex_state = 2},
  [576] = {.lex_state = 4, .external_lex_state = 2},
  [577] = {.lex_state = 4, .external_lex_state = 2},
  [578] = {.lex_state = 4, .external_lex_state = 2},
  [579] = {.lex_state = 4, .external_lex_state = 2},
  [580] = {.lex_state = 4, .external_lex_state = 2},
  [581] = {.lex_state = 93},
  [582] = {.lex_state = 4, .external_lex_state = 2},
  [583] = {.lex_state = 93},
  [584] = {.lex_state = 4, .external_lex_state = 2},
  [585] = {.lex_state = 4, .external_lex_state = 2},
  [586] = {.lex_state = 4, .external_lex_state = 2},
  [587] = {.lex_state = 93},
  [588] = {.lex_state = 93},
  [589] = {.lex_state = 93},
  [590] = {.lex_state = 93},
  [591] = {.lex_state = 93},
  [592] = {.lex_state = 93},
  [593] = {.lex_state = 93},
  [594] = {.lex_state = 93},
  [595] = {.lex_state = 93},
  [596] = {.lex_state = 93},
  [597] = {.lex_state = 93},
  [598] = {.lex_state = 93},
  [599] = {.lex_state = 93},
  [600] = {.lex_state = 93},
  [601] = {.lex_state = 93},
  [602] = {.lex_state = 93},
  [603] = {.lex_state = 93},
  [604] = {.lex_state = 90},
  [605] = {.lex_state = 90},
  [606] = {.lex_state = 90},
  [607] = {.lex_state = 90},
  [608] = {.lex_state = 94},
  [609] = {.lex_state = 90},
  [610] = {.lex_state = 90},
  [611] = {.lex_state = 90},
  [612] = {.lex_state = 90},
  [613] = {.lex_state = 90},
  [614] = {.lex_state = 90},
  [615] = {.lex_state = 90},
  [616] = {.lex_state = 90},
  [617] = {.lex_state = 90},
  [618] = {.lex_state = 90},
  [619] = {.lex_state = 90},
  [620] = {.lex_state = 90},
  [621] = {.lex_state = 90},
  [622] = {.lex_state = 90},
  [623] = {.lex_state = 90},
  [624] = {.lex_state = 90},
  [625] = {.lex_state = 5},
  [626] = {.lex_state = 5},
  [627] = {.lex_state = 5},
  [628] = {.lex_state = 5},
  [629] = {.lex_state = 5},
  [630] = {.lex_state = 5},
  [631] = {.lex_state = 5},
  [632] = {.lex_state = 5},
  [633] = {.lex_state = 5},
  [634] = {.lex_state = 90},
  [635] = {.lex_state = 5},
  [636] = {.lex_state = 6},
  [637] = {.lex_state = 6},
  [638] = {.lex_state = 6},
  [639] = {.lex_state = 6},
  [640] = {.lex_state = 6},
  [641] = {.lex_state = 90},
  [642] = {.lex_state = 90},
  [643] = {.lex_state = 90},
  [644] = {.lex_state = 90},
  [645] = {.lex_state = 90},
  [646] = {.lex_state = 90},
  [647] = {.lex_state = 90},
  [648] = {.lex_state = 90},
  [649] = {.lex_state = 90},
  [650] = {.lex_state = 90},
  [651] = {.lex_state = 4},
  [652] = {.lex_state = 4},
  [653] = {.lex_state = 90},
  [654] = {.lex_state = 4},
  [655] = {.lex_state = 4},
  [656] = {.lex_state = 90},
  [657] = {.lex_state = 4},
  [658] = {.lex_state = 90},
  [659] = {.lex_state = 4},
  [660] = {.lex_state = 90},
  [661] = {.lex_state = 6},
  [662] = {.lex_state = 6},
  [663] = {.lex_state = 4},
  [664] = {.lex_state = 4},
  [665] = {.lex_state = 4},
  [666] = {.lex_state = 4},
  [667] = {.lex_state = 4},
  [668] = {.lex_state = 4},
  [669] = {.lex_state = 4},
  [670] = {.lex_state = 7},
  [671] = {.lex_state = 4},
  [672] = {.lex_state = 4},
  [673] = {.lex_state = 4},
  [674] = {.lex_state = 4},
  [675] = {.lex_state = 4},
  [676] = {.lex_state = 4},
  [677] = {.lex_state = 4},
  [678] = {.lex_state = 4},
  [679] = {.lex_state = 4},
  [680] = {.lex_state = 6},
  [681] = {.lex_state = 6},
  [682] = {.lex_state = 4},
  [683] = {.lex_state = 90, .external_lex_state = 3},
  [684] = {.lex_state = 4},
  [685] = {.lex_state = 90, .external_lex_state = 3},
  [686] = {.lex_state = 90},
  [687] = {.lex_state = 4},
  [688] = {.lex_state = 90},
  [689] = {.lex_state = 4},
  [690] = {.lex_state = 90, .external_lex_state = 3},
  [691] = {.lex_state = 4},
  [692] = {.lex_state = 90},
  [693] = {.lex_state = 6},
  [694] = {.lex_state = 90},
  [695] = {.lex_state = 90},
  [696] = {.lex_state = 4},
  [697] = {.lex_state = 4},
  [698] = {.lex_state = 90},
  [699] = {.lex_state = 4},
  [700] = {.lex_state = 4},
  [701] = {.lex_state = 90},
  [702] = {.lex_state = 90, .external_lex_state = 3},
  [703] = {.lex_state = 4},
  [704] = {.lex_state = 4},
  [705] = {.lex_state = 90},
  [706] = {.lex_state = 90},
  [707] = {.lex_state = 90},
  [708] = {.lex_state = 7},
  [709] = {.lex_state = 90, .external_lex_state = 3},
  [710] = {.lex_state = 90},
  [711] = {.lex_state = 90, .external_lex_state = 3},
  [712] = {.lex_state = 4},
  [713] = {.lex_state = 4},
  [714] = {.lex_state = 90},
  [715] = {.lex_state = 90},
  [716] = {.lex_state = 4},
  [717] = {.lex_state = 90},
  [718] = {.lex_state = 90},
  [719] = {.lex_state = 6},
  [720] = {.lex_state = 90},
  [721] = {.lex_state = 90},
  [722] = {.lex_state = 90},
  [723] = {.lex_state = 90},
  [724] = {.lex_state = 90},
  [725] = {.lex_state = 4},
  [726] = {.lex_state = 90},
  [727] = {.lex_state = 90},
  [728] = {.lex_state = 90},
  [729] = {.lex_state = 4},
  [730] = {.lex_state = 90},
  [731] = {.lex_state = 6},
  [732] = {.lex_state = 90},
  [733] = {.lex_state = 90},
  [734] = {.lex_state = 90},
  [735] = {.lex_state = 4},
  [736] = {.lex_state = 90},
  [737] = {.lex_state = 90},
  [738] = {.lex_state = 90},
  [739] = {.lex_state = 90},
  [740] = {.lex_state = 90},
  [741] = {.lex_state = 90},
  [742] = {.lex_state = 4},
  [743] = {.lex_state = 90},
  [744] = {.lex_state = 90},
  [745] = {.lex_state = 4},
  [746] = {.lex_state = 6},
  [747] = {.lex_state = 6},
  [748] = {.lex_state = 6},
  [749] = {.lex_state = 6},
  [750] = {.lex_state = 6},
  [751] = {.lex_state = 90},
  [752] = {.lex_state = 90},
  [753] = {.lex_state = 90},
  [754] = {.lex_state = 6},
  [755] = {.lex_state = 6},
  [756] = {.lex_state = 90},
  [757] = {.lex_state = 6},
  [758] = {.lex_state = 6},
  [759] = {.lex_state = 6},
  [760] = {.lex_state = 6},
  [761] = {.lex_state = 90},
  [762] = {.lex_state = 6},
  [763] = {.lex_state = 6},
  [764] = {.lex_state = 6},
  [765] = {.lex_state = 90},
  [766] = {.lex_state = 6},
  [767] = {.lex_state = 6},
  [768] = {.lex_state = 90},
  [769] = {.lex_state = 90},
  [770] = {.lex_state = 6},
  [771] = {.lex_state = 7},
  [772] = {.lex_state = 90},
  [773] = {.lex_state = 90},
  [774] = {.lex_state = 90},
  [775] = {.lex_state = 90},
  [776] = {.lex_state = 90},
  [777] = {.lex_state = 90},
  [778] = {.lex_state = 6},
  [779] = {.lex_state = 6},
  [780] = {.lex_state = 6},
  [781] = {.lex_state = 90},
  [782] = {.lex_state = 90},
  [783] = {.lex_state = 6},
  [784] = {.lex_state = 90},
  [785] = {.lex_state = 90},
  [786] = {.lex_state = 90},
  [787] = {.lex_state = 90},
  [788] = {.lex_state = 90},
  [789] = {.lex_state = 6},
  [790] = {.lex_state = 90},
  [791] = {.lex_state = 90},
  [792] = {.lex_state = 6},
  [793] = {.lex_state = 90},
  [794] = {.lex_state = 6},
  [795] = {.lex_state = 6},
  [796] = {.lex_state = 90},
  [797] = {.lex_state = 6},
  [798] = {.lex_state = 6},
  [799] = {.lex_state = 6},
  [800] = {.lex_state = 6},
  [801] = {.lex_state = 90},
  [802] = {.lex_state = 6},
  [803] = {.lex_state = 90},
  [804] = {.lex_state = 6},
  [805] = {.lex_state = 90},
  [806] = {.lex_state = 90},
  [807] = {.lex_state = 90},
  [808] = {.lex_state = 90},
  [809] = {.lex_state = 90},
  [810] = {.lex_state = 90},
  [811] = {.lex_state = 6},
  [812] = {.lex_state = 6},
  [813] = {.lex_state = 90},
  [814] = {.lex_state = 6},
  [815] = {.lex_state = 6},
  [816] = {.lex_state = 6},
  [817] = {.lex_state = 90},
  [818] = {.lex_state = 90},
  [819] = {.lex_state = 90},
  [820] = {.lex_state = 6},
  [821] = {.lex_state = 90},
  [822] = {.lex_state = 90},
  [823] = {.lex_state = 6},
  [824] = {.lex_state = 6},
  [825] = {.lex_state = 6},
  [826] = {.lex_state = 90},
  [827] = {.lex_state = 6},
  [828] = {.lex_state = 6},
  [829] = {.lex_state = 90},
  [830] = {.lex_state = 6},
  [831] = {.lex_state = 6},
  [832] = {.lex_state = 6},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_provider] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_targetScope] = ACTIONS(1),
    [anon_sym_metadata] = ACTIONS(1),
    [anon_sym_output] = ACTIONS(1),
    [anon_sym_param] = ACTIONS(1),
    [anon_sym_resource] = ACTIONS(1),
    [anon_sym_existing] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_func] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_test] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_DOT_QMARK] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_EQ_TILDE] = ACTIONS(1),
    [anon_sym_BANG_TILDE] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_QMARK_QMARK] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(1),
    [aux_sym__escape_sequence_token1] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [anon_sym_DOLLAR_LBRACE] = ACTIONS(1),
    [anon_sym_array] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_object] = ACTIONS(1),
    [anon_sym_secureObject] = ACTIONS(1),
    [anon_sym_secureString] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(5),
    [sym__external_asterisk] = ACTIONS(1),
    [sym__multiline_string_content] = ACTIONS(1),
  },
  [1] = {
    [sym_infrastructure] = STATE(791),
    [sym_statement] = STATE(417),
    [sym_declaration] = STATE(611),
    [sym_module_declaration] = STATE(615),
    [sym_import_statement] = STATE(611),
    [sym_import_with_statement] = STATE(611),
    [sym_import_functionality] = STATE(611),
    [sym_using_statement] = STATE(611),
    [sym_target_scope_assignment] = STATE(611),
    [sym_metadata_declaration] = STATE(615),
    [sym_output_declaration] = STATE(615),
    [sym_parameter_declaration] = STATE(615),
    [sym_resource_declaration] = STATE(615),
    [sym_type_declaration] = STATE(615),
    [sym_variable_declaration] = STATE(615),
    [sym_user_defined_function] = STATE(615),
    [sym_test_block] = STATE(615),
    [sym_assert_statement] = STATE(615),
    [sym_decorator] = STATE(607),
    [sym_decorators] = STATE(611),
    [aux_sym_infrastructure_repeat1] = STATE(417),
    [aux_sym_decorators_repeat1] = STATE(607),
    [ts_builtin_sym_end] = ACTIONS(7),
    [anon_sym_module] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_provider] = ACTIONS(13),
    [anon_sym_using] = ACTIONS(15),
    [anon_sym_targetScope] = ACTIONS(17),
    [anon_sym_metadata] = ACTIONS(19),
    [anon_sym_output] = ACTIONS(21),
    [anon_sym_param] = ACTIONS(23),
    [anon_sym_resource] = ACTIONS(25),
    [anon_sym_type] = ACTIONS(27),
    [anon_sym_var] = ACTIONS(29),
    [anon_sym_func] = ACTIONS(31),
    [anon_sym_test] = ACTIONS(33),
    [anon_sym_assert] = ACTIONS(35),
    [anon_sym_AT] = ACTIONS(37),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
  [2] = {
    [sym_expression] = STATE(84),
    [sym_primary_expression] = STATE(113),
    [sym_call_expression] = STATE(116),
    [sym_lambda_expression] = STATE(114),
    [sym_arguments] = STATE(124),
    [sym_parenthesized_expression] = STATE(91),
    [sym_decorator] = STATE(436),
    [sym_decorators] = STATE(216),
    [sym_array] = STATE(116),
    [sym_object] = STATE(116),
    [sym__lhs_expression] = STATE(803),
    [sym_assignment_expression] = STATE(114),
    [sym_for_statement] = STATE(116),
    [sym_member_expression] = STATE(92),
    [sym_subscript_expression] = STATE(92),
    [sym_resource_expression] = STATE(92),
    [sym_ternary_expression] = STATE(114),
    [sym_binary_expression] = STATE(114),
    [sym_unary_expression] = STATE(114),
    [sym__literal] = STATE(116),
    [sym_boolean] = STATE(116),
    [sym_string] = STATE(116),
    [sym__string_literal] = STATE(136),
    [sym__multiline_string_literal] = STATE(136),
    [sym_parameterized_type] = STATE(691),
    [aux_sym_decorators_repeat1] = STATE(436),
    [aux_sym_array_repeat1] = STATE(58),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_module] = ACTIONS(41),
    [anon_sym_import] = ACTIONS(41),
    [anon_sym_provider] = ACTIONS(41),
    [anon_sym_LBRACE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(45),
    [anon_sym_STAR] = ACTIONS(47),
    [anon_sym_metadata] = ACTIONS(41),
    [anon_sym_output] = ACTIONS(41),
    [anon_sym_param] = ACTIONS(41),
    [anon_sym_resource] = ACTIONS(49),
    [anon_sym_existing] = ACTIONS(41),
    [anon_sym_type] = ACTIONS(41),
    [anon_sym_var] = ACTIONS(41),
    [anon_sym_BANG] = ACTIONS(51),
    [anon_sym_EQ_GT] = ACTIONS(53),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(61),
    [anon_sym_DOT] = ACTIONS(63),
    [anon_sym_DOT_QMARK] = ACTIONS(65),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(47),
    [anon_sym_PERCENT] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(77),
    [anon_sym_AMP_AMP] = ACTIONS(79),
    [anon_sym_PIPE] = ACTIONS(81),
    [anon_sym_EQ_EQ] = ACTIONS(83),
    [anon_sym_BANG_EQ] = ACTIONS(83),
    [anon_sym_EQ_TILDE] = ACTIONS(83),
    [anon_sym_BANG_TILDE] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(85),
    [anon_sym_GT_EQ] = ACTIONS(87),
    [anon_sym_LT_EQ] = ACTIONS(87),
    [anon_sym_LT] = ACTIONS(85),
    [anon_sym_QMARK_QMARK] = ACTIONS(89),
    [sym_number] = ACTIONS(91),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(97),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(99),
    [anon_sym_array] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_int] = ACTIONS(41),
    [anon_sym_object] = ACTIONS(41),
    [anon_sym_secureObject] = ACTIONS(41),
    [anon_sym_secureString] = ACTIONS(41),
    [anon_sym_string] = ACTIONS(41),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
  [3] = {
    [sym_expression] = STATE(84),
    [sym_primary_expression] = STATE(113),
    [sym_call_expression] = STATE(116),
    [sym_lambda_expression] = STATE(114),
    [sym_arguments] = STATE(124),
    [sym_parenthesized_expression] = STATE(91),
    [sym_decorator] = STATE(436),
    [sym_decorators] = STATE(216),
    [sym_array] = STATE(116),
    [sym_object] = STATE(116),
    [sym__lhs_expression] = STATE(803),
    [sym_assignment_expression] = STATE(114),
    [sym_for_statement] = STATE(116),
    [sym_member_expression] = STATE(92),
    [sym_subscript_expression] = STATE(92),
    [sym_resource_expression] = STATE(92),
    [sym_ternary_expression] = STATE(114),
    [sym_binary_expression] = STATE(114),
    [sym_unary_expression] = STATE(114),
    [sym__literal] = STATE(116),
    [sym_boolean] = STATE(116),
    [sym_string] = STATE(116),
    [sym__string_literal] = STATE(136),
    [sym__multiline_string_literal] = STATE(136),
    [sym_parameterized_type] = STATE(691),
    [aux_sym_decorators_repeat1] = STATE(436),
    [aux_sym_array_repeat1] = STATE(63),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_module] = ACTIONS(41),
    [anon_sym_import] = ACTIONS(41),
    [anon_sym_provider] = ACTIONS(41),
    [anon_sym_LBRACE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(101),
    [anon_sym_STAR] = ACTIONS(47),
    [anon_sym_metadata] = ACTIONS(41),
    [anon_sym_output] = ACTIONS(41),
    [anon_sym_param] = ACTIONS(41),
    [anon_sym_resource] = ACTIONS(49),
    [anon_sym_existing] = ACTIONS(41),
    [anon_sym_type] = ACTIONS(41),
    [anon_sym_var] = ACTIONS(41),
    [anon_sym_BANG] = ACTIONS(51),
    [anon_sym_EQ_GT] = ACTIONS(53),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(103),
    [anon_sym_DOT] = ACTIONS(63),
    [anon_sym_DOT_QMARK] = ACTIONS(65),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(47),
    [anon_sym_PERCENT] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(77),
    [anon_sym_AMP_AMP] = ACTIONS(79),
    [anon_sym_PIPE] = ACTIONS(81),
    [anon_sym_EQ_EQ] = ACTIONS(83),
    [anon_sym_BANG_EQ] = ACTIONS(83),
    [anon_sym_EQ_TILDE] = ACTIONS(83),
    [anon_sym_BANG_TILDE] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(85),
    [anon_sym_GT_EQ] = ACTIONS(87),
    [anon_sym_LT_EQ] = ACTIONS(87),
    [anon_sym_LT] = ACTIONS(85),
    [anon_sym_QMARK_QMARK] = ACTIONS(89),
    [sym_number] = ACTIONS(91),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(97),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(99),
    [anon_sym_array] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_int] = ACTIONS(41),
    [anon_sym_object] = ACTIONS(41),
    [anon_sym_secureObject] = ACTIONS(41),
    [anon_sym_secureString] = ACTIONS(41),
    [anon_sym_string] = ACTIONS(41),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
  [4] = {
    [sym_expression] = STATE(84),
    [sym_primary_expression] = STATE(113),
    [sym_call_expression] = STATE(116),
    [sym_lambda_expression] = STATE(114),
    [sym_arguments] = STATE(124),
    [sym_parenthesized_expression] = STATE(91),
    [sym_decorator] = STATE(436),
    [sym_decorators] = STATE(216),
    [sym_array] = STATE(116),
    [sym_object] = STATE(116),
    [sym__lhs_expression] = STATE(803),
    [sym_assignment_expression] = STATE(114),
    [sym_for_statement] = STATE(116),
    [sym_member_expression] = STATE(92),
    [sym_subscript_expression] = STATE(92),
    [sym_resource_expression] = STATE(92),
    [sym_ternary_expression] = STATE(114),
    [sym_binary_expression] = STATE(114),
    [sym_unary_expression] = STATE(114),
    [sym__literal] = STATE(116),
    [sym_boolean] = STATE(116),
    [sym_string] = STATE(116),
    [sym__string_literal] = STATE(136),
    [sym__multiline_string_literal] = STATE(136),
    [sym_parameterized_type] = STATE(691),
    [aux_sym_decorators_repeat1] = STATE(436),
    [aux_sym_array_repeat1] = STATE(61),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_module] = ACTIONS(41),
    [anon_sym_import] = ACTIONS(41),
    [anon_sym_provider] = ACTIONS(41),
    [anon_sym_LBRACE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(105),
    [anon_sym_STAR] = ACTIONS(47),
    [anon_sym_metadata] = ACTIONS(41),
    [anon_sym_output] = ACTIONS(41),
    [anon_sym_param] = ACTIONS(41),
    [anon_sym_resource] = ACTIONS(49),
    [anon_sym_existing] = ACTIONS(41),
    [anon_sym_type] = ACTIONS(41),
    [anon_sym_var] = ACTIONS(41),
    [anon_sym_BANG] = ACTIONS(51),
    [anon_sym_EQ_GT] = ACTIONS(53),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(107),
    [anon_sym_DOT] = ACTIONS(63),
    [anon_sym_DOT_QMARK] = ACTIONS(65),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(47),
    [anon_sym_PERCENT] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(77),
    [anon_sym_AMP_AMP] = ACTIONS(79),
    [anon_sym_PIPE] = ACTIONS(81),
    [anon_sym_EQ_EQ] = ACTIONS(83),
    [anon_sym_BANG_EQ] = ACTIONS(83),
    [anon_sym_EQ_TILDE] = ACTIONS(83),
    [anon_sym_BANG_TILDE] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(85),
    [anon_sym_GT_EQ] = ACTIONS(87),
    [anon_sym_LT_EQ] = ACTIONS(87),
    [anon_sym_LT] = ACTIONS(85),
    [anon_sym_QMARK_QMARK] = ACTIONS(89),
    [sym_number] = ACTIONS(91),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(97),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(99),
    [anon_sym_array] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_int] = ACTIONS(41),
    [anon_sym_object] = ACTIONS(41),
    [anon_sym_secureObject] = ACTIONS(41),
    [anon_sym_secureString] = ACTIONS(41),
    [anon_sym_string] = ACTIONS(41),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
  [5] = {
    [sym_expression] = STATE(84),
    [sym_primary_expression] = STATE(113),
    [sym_call_expression] = STATE(116),
    [sym_lambda_expression] = STATE(114),
    [sym_arguments] = STATE(124),
    [sym_parenthesized_expression] = STATE(91),
    [sym_decorator] = STATE(436),
    [sym_decorators] = STATE(216),
    [sym_array] = STATE(116),
    [sym_object] = STATE(116),
    [sym__lhs_expression] = STATE(803),
    [sym_assignment_expression] = STATE(114),
    [sym_for_statement] = STATE(116),
    [sym_member_expression] = STATE(92),
    [sym_subscript_expression] = STATE(92),
    [sym_resource_expression] = STATE(92),
    [sym_ternary_expression] = STATE(114),
    [sym_binary_expression] = STATE(114),
    [sym_unary_expression] = STATE(114),
    [sym__literal] = STATE(116),
    [sym_boolean] = STATE(116),
    [sym_string] = STATE(116),
    [sym__string_literal] = STATE(136),
    [sym__multiline_string_literal] = STATE(136),
    [sym_parameterized_type] = STATE(691),
    [aux_sym_decorators_repeat1] = STATE(436),
    [aux_sym_array_repeat1] = STATE(62),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_module] = ACTIONS(41),
    [anon_sym_import] = ACTIONS(41),
    [anon_sym_provider] = ACTIONS(41),
    [anon_sym_LBRACE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(109),
    [anon_sym_STAR] = ACTIONS(47),
    [anon_sym_metadata] = ACTIONS(41),
    [anon_sym_output] = ACTIONS(41),
    [anon_sym_param] = ACTIONS(41),
    [anon_sym_resource] = ACTIONS(49),
    [anon_sym_existing] = ACTIONS(41),
    [anon_sym_type] = ACTIONS(41),
    [anon_sym_var] = ACTIONS(41),
    [anon_sym_BANG] = ACTIONS(51),
    [anon_sym_EQ_GT] = ACTIONS(53),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(111),
    [anon_sym_DOT] = ACTIONS(63),
    [anon_sym_DOT_QMARK] = ACTIONS(65),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(47),
    [anon_sym_PERCENT] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(77),
    [anon_sym_AMP_AMP] = ACTIONS(79),
    [anon_sym_PIPE] = ACTIONS(81),
    [anon_sym_EQ_EQ] = ACTIONS(83),
    [anon_sym_BANG_EQ] = ACTIONS(83),
    [anon_sym_EQ_TILDE] = ACTIONS(83),
    [anon_sym_BANG_TILDE] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(85),
    [anon_sym_GT_EQ] = ACTIONS(87),
    [anon_sym_LT_EQ] = ACTIONS(87),
    [anon_sym_LT] = ACTIONS(85),
    [anon_sym_QMARK_QMARK] = ACTIONS(89),
    [sym_number] = ACTIONS(91),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(97),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(99),
    [anon_sym_array] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_int] = ACTIONS(41),
    [anon_sym_object] = ACTIONS(41),
    [anon_sym_secureObject] = ACTIONS(41),
    [anon_sym_secureString] = ACTIONS(41),
    [anon_sym_string] = ACTIONS(41),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
  [6] = {
    [sym_expression] = STATE(84),
    [sym_primary_expression] = STATE(113),
    [sym_call_expression] = STATE(116),
    [sym_lambda_expression] = STATE(114),
    [sym_arguments] = STATE(124),
    [sym_parenthesized_expression] = STATE(91),
    [sym_decorator] = STATE(436),
    [sym_decorators] = STATE(216),
    [sym_array] = STATE(116),
    [sym_object] = STATE(116),
    [sym__lhs_expression] = STATE(803),
    [sym_assignment_expression] = STATE(114),
    [sym_for_statement] = STATE(116),
    [sym_member_expression] = STATE(92),
    [sym_subscript_expression] = STATE(92),
    [sym_resource_expression] = STATE(92),
    [sym_ternary_expression] = STATE(114),
    [sym_binary_expression] = STATE(114),
    [sym_unary_expression] = STATE(114),
    [sym__literal] = STATE(116),
    [sym_boolean] = STATE(116),
    [sym_string] = STATE(116),
    [sym__string_literal] = STATE(136),
    [sym__multiline_string_literal] = STATE(136),
    [sym_parameterized_type] = STATE(691),
    [aux_sym_decorators_repeat1] = STATE(436),
    [aux_sym_array_repeat1] = STATE(62),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_module] = ACTIONS(41),
    [anon_sym_import] = ACTIONS(41),
    [anon_sym_provider] = ACTIONS(41),
    [anon_sym_LBRACE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(109),
    [anon_sym_STAR] = ACTIONS(47),
    [anon_sym_metadata] = ACTIONS(41),
    [anon_sym_output] = ACTIONS(41),
    [anon_sym_param] = ACTIONS(41),
    [anon_sym_resource] = ACTIONS(49),
    [anon_sym_existing] = ACTIONS(41),
    [anon_sym_type] = ACTIONS(41),
    [anon_sym_var] = ACTIONS(41),
    [anon_sym_BANG] = ACTIONS(51),
    [anon_sym_EQ_GT] = ACTIONS(53),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(113),
    [anon_sym_DOT] = ACTIONS(63),
    [anon_sym_DOT_QMARK] = ACTIONS(65),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(47),
    [anon_sym_PERCENT] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(77),
    [anon_sym_AMP_AMP] = ACTIONS(79),
    [anon_sym_PIPE] = ACTIONS(81),
    [anon_sym_EQ_EQ] = ACTIONS(83),
    [anon_sym_BANG_EQ] = ACTIONS(83),
    [anon_sym_EQ_TILDE] = ACTIONS(83),
    [anon_sym_BANG_TILDE] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(85),
    [anon_sym_GT_EQ] = ACTIONS(87),
    [anon_sym_LT_EQ] = ACTIONS(87),
    [anon_sym_LT] = ACTIONS(85),
    [anon_sym_QMARK_QMARK] = ACTIONS(89),
    [sym_number] = ACTIONS(91),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(97),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(99),
    [anon_sym_array] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_int] = ACTIONS(41),
    [anon_sym_object] = ACTIONS(41),
    [anon_sym_secureObject] = ACTIONS(41),
    [anon_sym_secureString] = ACTIONS(41),
    [anon_sym_string] = ACTIONS(41),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
  [7] = {
    [sym_expression] = STATE(84),
    [sym_primary_expression] = STATE(113),
    [sym_call_expression] = STATE(116),
    [sym_lambda_expression] = STATE(114),
    [sym_arguments] = STATE(124),
    [sym_parenthesized_expression] = STATE(91),
    [sym_decorator] = STATE(436),
    [sym_decorators] = STATE(216),
    [sym_array] = STATE(116),
    [sym_object] = STATE(116),
    [sym__lhs_expression] = STATE(803),
    [sym_assignment_expression] = STATE(114),
    [sym_for_statement] = STATE(116),
    [sym_member_expression] = STATE(92),
    [sym_subscript_expression] = STATE(92),
    [sym_resource_expression] = STATE(92),
    [sym_ternary_expression] = STATE(114),
    [sym_binary_expression] = STATE(114),
    [sym_unary_expression] = STATE(114),
    [sym__literal] = STATE(116),
    [sym_boolean] = STATE(116),
    [sym_string] = STATE(116),
    [sym__string_literal] = STATE(136),
    [sym__multiline_string_literal] = STATE(136),
    [sym_parameterized_type] = STATE(691),
    [aux_sym_decorators_repeat1] = STATE(436),
    [aux_sym_array_repeat1] = STATE(60),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_module] = ACTIONS(41),
    [anon_sym_import] = ACTIONS(41),
    [anon_sym_provider] = ACTIONS(41),
    [anon_sym_LBRACE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(115),
    [anon_sym_STAR] = ACTIONS(47),
    [anon_sym_metadata] = ACTIONS(41),
    [anon_sym_output] = ACTIONS(41),
    [anon_sym_param] = ACTIONS(41),
    [anon_sym_resource] = ACTIONS(49),
    [anon_sym_existing] = ACTIONS(41),
    [anon_sym_type] = ACTIONS(41),
    [anon_sym_var] = ACTIONS(41),
    [anon_sym_BANG] = ACTIONS(51),
    [anon_sym_EQ_GT] = ACTIONS(53),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(117),
    [anon_sym_DOT] = ACTIONS(63),
    [anon_sym_DOT_QMARK] = ACTIONS(65),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(47),
    [anon_sym_PERCENT] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(77),
    [anon_sym_AMP_AMP] = ACTIONS(79),
    [anon_sym_PIPE] = ACTIONS(81),
    [anon_sym_EQ_EQ] = ACTIONS(83),
    [anon_sym_BANG_EQ] = ACTIONS(83),
    [anon_sym_EQ_TILDE] = ACTIONS(83),
    [anon_sym_BANG_TILDE] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(85),
    [anon_sym_GT_EQ] = ACTIONS(87),
    [anon_sym_LT_EQ] = ACTIONS(87),
    [anon_sym_LT] = ACTIONS(85),
    [anon_sym_QMARK_QMARK] = ACTIONS(89),
    [sym_number] = ACTIONS(91),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(97),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(99),
    [anon_sym_array] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_int] = ACTIONS(41),
    [anon_sym_object] = ACTIONS(41),
    [anon_sym_secureObject] = ACTIONS(41),
    [anon_sym_secureString] = ACTIONS(41),
    [anon_sym_string] = ACTIONS(41),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
  [8] = {
    [sym_expression] = STATE(84),
    [sym_primary_expression] = STATE(113),
    [sym_call_expression] = STATE(116),
    [sym_lambda_expression] = STATE(114),
    [sym_arguments] = STATE(124),
    [sym_parenthesized_expression] = STATE(91),
    [sym_decorator] = STATE(436),
    [sym_decorators] = STATE(216),
    [sym_array] = STATE(116),
    [sym_object] = STATE(116),
    [sym__lhs_expression] = STATE(803),
    [sym_assignment_expression] = STATE(114),
    [sym_for_statement] = STATE(116),
    [sym_member_expression] = STATE(92),
    [sym_subscript_expression] = STATE(92),
    [sym_resource_expression] = STATE(92),
    [sym_ternary_expression] = STATE(114),
    [sym_binary_expression] = STATE(114),
    [sym_unary_expression] = STATE(114),
    [sym__literal] = STATE(116),
    [sym_boolean] = STATE(116),
    [sym_string] = STATE(116),
    [sym__string_literal] = STATE(136),
    [sym__multiline_string_literal] = STATE(136),
    [sym_parameterized_type] = STATE(691),
    [aux_sym_decorators_repeat1] = STATE(436),
    [aux_sym_array_repeat1] = STATE(57),
    [sym_identifier] = ACTIONS(39),
    [anon_sym_module] = ACTIONS(41),
    [anon_sym_import] = ACTIONS(41),
    [anon_sym_provider] = ACTIONS(41),
    [anon_sym_LBRACE] = ACTIONS(43),
    [anon_sym_COMMA] = ACTIONS(119),
    [anon_sym_STAR] = ACTIONS(47),
    [anon_sym_metadata] = ACTIONS(41),
    [anon_sym_output] = ACTIONS(41),
    [anon_sym_param] = ACTIONS(41),
    [anon_sym_resource] = ACTIONS(49),
    [anon_sym_existing] = ACTIONS(41),
    [anon_sym_type] = ACTIONS(41),
    [anon_sym_var] = ACTIONS(41),
    [anon_sym_BANG] = ACTIONS(51),
    [anon_sym_EQ_GT] = ACTIONS(53),
    [anon_sym_LPAREN] = ACTIONS(55),
    [anon_sym_AT] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(59),
    [anon_sym_RBRACK] = ACTIONS(121),
    [anon_sym_DOT] = ACTIONS(63),
    [anon_sym_DOT_QMARK] = ACTIONS(65),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_COLON_COLON] = ACTIONS(69),
    [anon_sym_PLUS] = ACTIONS(71),
    [anon_sym_DASH] = ACTIONS(73),
    [anon_sym_SLASH] = ACTIONS(47),
    [anon_sym_PERCENT] = ACTIONS(75),
    [anon_sym_PIPE_PIPE] = ACTIONS(77),
    [anon_sym_AMP_AMP] = ACTIONS(79),
    [anon_sym_PIPE] = ACTIONS(81),
    [anon_sym_EQ_EQ] = ACTIONS(83),
    [anon_sym_BANG_EQ] = ACTIONS(83),
    [anon_sym_EQ_TILDE] = ACTIONS(83),
    [anon_sym_BANG_TILDE] = ACTIONS(83),
    [anon_sym_GT] = ACTIONS(85),
    [anon_sym_GT_EQ] = ACTIONS(87),
    [anon_sym_LT_EQ] = ACTIONS(87),
    [anon_sym_LT] = ACTIONS(85),
    [anon_sym_QMARK_QMARK] = ACTIONS(89),
    [sym_number] = ACTIONS(91),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [sym_null] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(97),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(99),
    [anon_sym_array] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_int] = ACTIONS(41),
    [anon_sym_object] = ACTIONS(41),
    [anon_sym_secureObject] = ACTIONS(41),
    [anon_sym_secureString] = ACTIONS(41),
    [anon_sym_string] = ACTIONS(41),
    [sym_comment] = ACTIONS(3),
    [sym_diagnostic_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 34,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(131), 1,
      anon_sym_BANG,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_RPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(141), 1,
      anon_sym_PIPE,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(454), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(673), 1,
      aux_sym_union_type_repeat1,
    STATE(727), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(671), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [133] = 34,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(131), 1,
      anon_sym_BANG,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(141), 1,
      anon_sym_PIPE,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(155), 1,
      anon_sym_RPAREN,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(457), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(673), 1,
      aux_sym_union_type_repeat1,
    STATE(727), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(671), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [266] = 34,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(131), 1,
      anon_sym_BANG,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(141), 1,
      anon_sym_PIPE,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(155), 1,
      anon_sym_RPAREN,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(457), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(673), 1,
      aux_sym_union_type_repeat1,
    STATE(737), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(671), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [399] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(157), 1,
      sym_identifier,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(161), 1,
      anon_sym_PIPE,
    ACTIONS(163), 1,
      sym_number,
    ACTIONS(165), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(506), 1,
      sym_expression,
    STATE(549), 1,
      sym_member_expression,
    STATE(557), 1,
      sym_boolean,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(667), 1,
      aux_sym_union_type_repeat1,
    STATE(730), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(565), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(677), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(167), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [529] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(169), 1,
      sym_identifier,
    ACTIONS(171), 1,
      anon_sym_BANG,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(380), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(412), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [659] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(169), 1,
      sym_identifier,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(177), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(412), 1,
      sym_member_expression,
    STATE(488), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [789] = 33,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(187), 1,
      anon_sym_BANG,
    ACTIONS(189), 1,
      anon_sym_LPAREN,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(195), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_null,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(190), 1,
      sym_expression,
    STATE(257), 1,
      sym_member_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(299), 1,
      sym_boolean,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(657), 1,
      sym_parameterized_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(266), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(318), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(699), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(297), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(205), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(181), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [919] = 33,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(207), 1,
      sym_identifier,
    ACTIONS(209), 1,
      anon_sym_resource,
    ACTIONS(211), 1,
      anon_sym_BANG,
    ACTIONS(213), 1,
      anon_sym_LPAREN,
    ACTIONS(215), 1,
      sym_number,
    ACTIONS(217), 1,
      sym_null,
    STATE(181), 1,
      sym_expression,
    STATE(264), 1,
      sym_member_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(322), 1,
      sym_boolean,
    STATE(474), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(761), 1,
      sym_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(266), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(324), 2,
      sym_object,
      sym_string,
    STATE(486), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(532), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(297), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(219), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(181), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1049] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(221), 1,
      sym_identifier,
    ACTIONS(223), 1,
      anon_sym_BANG,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(377), 1,
      sym_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(401), 1,
      sym_member_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1179] = 35,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(231), 1,
      anon_sym_BANG,
    ACTIONS(233), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(398), 1,
      sym_expression,
    STATE(592), 1,
      sym_parameterized_type,
    STATE(598), 1,
      sym_array_type,
    STATE(599), 1,
      aux_sym_union_type_repeat1,
    STATE(603), 1,
      sym_nullable_type,
    STATE(609), 1,
      sym_union_type,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(583), 2,
      sym_primitive_type,
      sym_parenthesized_type,
    STATE(697), 2,
      sym__type_not_union,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1313] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(235), 1,
      sym_identifier,
    ACTIONS(237), 1,
      anon_sym_BANG,
    ACTIONS(239), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(404), 1,
      sym_member_expression,
    STATE(493), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(665), 1,
      aux_sym_union_type_repeat1,
    STATE(728), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(663), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1443] = 33,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(207), 1,
      sym_identifier,
    ACTIONS(209), 1,
      anon_sym_resource,
    ACTIONS(211), 1,
      anon_sym_BANG,
    ACTIONS(213), 1,
      anon_sym_LPAREN,
    ACTIONS(215), 1,
      sym_number,
    ACTIONS(217), 1,
      sym_null,
    ACTIONS(241), 1,
      anon_sym_PIPE,
    STATE(199), 1,
      sym_expression,
    STATE(264), 1,
      sym_member_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(322), 1,
      sym_boolean,
    STATE(474), 1,
      sym_parameterized_type,
    STATE(533), 1,
      aux_sym_union_type_repeat1,
    STATE(550), 1,
      sym_union_type,
    STATE(553), 1,
      sym_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(266), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(324), 2,
      sym_object,
      sym_string,
    STATE(486), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(492), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(297), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(219), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(181), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1573] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(157), 1,
      sym_identifier,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      sym_number,
    ACTIONS(165), 1,
      sym_null,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(370), 1,
      sym_expression,
    STATE(549), 1,
      sym_member_expression,
    STATE(557), 1,
      sym_boolean,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(565), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(167), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1703] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(231), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(370), 1,
      sym_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1833] = 33,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(207), 1,
      sym_identifier,
    ACTIONS(209), 1,
      anon_sym_resource,
    ACTIONS(211), 1,
      anon_sym_BANG,
    ACTIONS(213), 1,
      anon_sym_LPAREN,
    ACTIONS(215), 1,
      sym_number,
    ACTIONS(217), 1,
      sym_null,
    STATE(180), 1,
      sym_expression,
    STATE(264), 1,
      sym_member_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(322), 1,
      sym_boolean,
    STATE(474), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(761), 1,
      sym_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(266), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(324), 2,
      sym_object,
      sym_string,
    STATE(486), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(532), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(297), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(219), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(181), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [1963] = 33,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(187), 1,
      anon_sym_BANG,
    ACTIONS(189), 1,
      anon_sym_LPAREN,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(195), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_null,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(180), 1,
      sym_expression,
    STATE(257), 1,
      sym_member_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(299), 1,
      sym_boolean,
    STATE(589), 1,
      sym_union_type,
    STATE(657), 1,
      sym_parameterized_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(266), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(318), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(297), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(205), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(181), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [2093] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(131), 1,
      anon_sym_BANG,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(141), 1,
      anon_sym_PIPE,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(467), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(673), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(679), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [2223] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(235), 1,
      sym_identifier,
    ACTIONS(237), 1,
      anon_sym_BANG,
    ACTIONS(239), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(404), 1,
      sym_member_expression,
    STATE(485), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(665), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(664), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [2353] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(131), 1,
      anon_sym_BANG,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(469), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [2483] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(131), 1,
      anon_sym_BANG,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(370), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [2613] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(169), 1,
      sym_identifier,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(177), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(380), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(412), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [2743] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(235), 1,
      sym_identifier,
    ACTIONS(243), 1,
      anon_sym_BANG,
    ACTIONS(245), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(404), 1,
      sym_member_expression,
    STATE(491), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(595), 1,
      aux_sym_union_type_repeat1,
    STATE(605), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(594), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [2873] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(169), 1,
      sym_identifier,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(177), 1,
      anon_sym_BANG,
    ACTIONS(239), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(412), 1,
      sym_member_expression,
    STATE(485), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(665), 1,
      aux_sym_union_type_repeat1,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(664), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3003] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(247), 1,
      sym_identifier,
    ACTIONS(249), 1,
      anon_sym_BANG,
    ACTIONS(251), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(373), 1,
      sym_member_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(518), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(651), 1,
      aux_sym_union_type_repeat1,
    STATE(717), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(652), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3133] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(253), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(519), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3263] = 35,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(187), 1,
      anon_sym_BANG,
    ACTIONS(189), 1,
      anon_sym_LPAREN,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(195), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_null,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(209), 1,
      anon_sym_resource,
    ACTIONS(241), 1,
      anon_sym_PIPE,
    ACTIONS(255), 1,
      sym_identifier,
    STATE(221), 1,
      sym_expression,
    STATE(257), 1,
      sym_member_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(299), 1,
      sym_boolean,
    STATE(462), 1,
      sym_parameterized_type,
    STATE(533), 1,
      aux_sym_union_type_repeat1,
    STATE(548), 1,
      sym_nullable_type,
    STATE(564), 1,
      sym_union_type,
    STATE(672), 1,
      sym_parenthesized_type,
    STATE(761), 1,
      sym_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(266), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(318), 2,
      sym_object,
      sym_string,
    STATE(484), 2,
      sym_primitive_type,
      sym_array_type,
    STATE(700), 2,
      sym__type_not_union,
      sym_negated_type,
    STATE(297), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(219), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(181), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3397] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(247), 1,
      sym_identifier,
    ACTIONS(257), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(370), 1,
      sym_expression,
    STATE(373), 1,
      sym_member_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3527] = 35,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(187), 1,
      anon_sym_BANG,
    ACTIONS(189), 1,
      anon_sym_LPAREN,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(195), 1,
      sym_number,
    ACTIONS(199), 1,
      sym_null,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(209), 1,
      anon_sym_resource,
    ACTIONS(241), 1,
      anon_sym_PIPE,
    ACTIONS(255), 1,
      sym_identifier,
    STATE(222), 1,
      sym_expression,
    STATE(257), 1,
      sym_member_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(299), 1,
      sym_boolean,
    STATE(463), 1,
      sym_parameterized_type,
    STATE(533), 1,
      aux_sym_union_type_repeat1,
    STATE(547), 1,
      sym_nullable_type,
    STATE(561), 1,
      sym_union_type,
    STATE(672), 1,
      sym_parenthesized_type,
    STATE(761), 1,
      sym_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(266), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(318), 2,
      sym_object,
      sym_string,
    STATE(478), 2,
      sym_primitive_type,
      sym_array_type,
    STATE(700), 2,
      sym__type_not_union,
      sym_negated_type,
    STATE(297), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(219), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(181), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3661] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(261), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(472), 1,
      sym_expression,
    STATE(477), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3791] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(231), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(369), 1,
      sym_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(699), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [3921] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(247), 1,
      sym_identifier,
    ACTIONS(257), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(373), 1,
      sym_member_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(399), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4051] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(157), 1,
      sym_identifier,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(161), 1,
      anon_sym_PIPE,
    ACTIONS(163), 1,
      sym_number,
    ACTIONS(165), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(535), 1,
      sym_expression,
    STATE(549), 1,
      sym_member_expression,
    STATE(557), 1,
      sym_boolean,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(667), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(565), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(666), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(167), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4181] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(157), 1,
      sym_identifier,
    ACTIONS(159), 1,
      anon_sym_BANG,
    ACTIONS(163), 1,
      sym_number,
    ACTIONS(165), 1,
      sym_null,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(521), 1,
      sym_expression,
    STATE(549), 1,
      sym_member_expression,
    STATE(557), 1,
      sym_boolean,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(565), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(167), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4311] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(233), 1,
      anon_sym_PIPE,
    ACTIONS(247), 1,
      sym_identifier,
    ACTIONS(257), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(373), 1,
      sym_member_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(394), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(599), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(602), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4441] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(261), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(469), 1,
      sym_expression,
    STATE(477), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4571] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(247), 1,
      sym_identifier,
    ACTIONS(249), 1,
      anon_sym_BANG,
    ACTIONS(251), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(373), 1,
      sym_member_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(475), 1,
      sym_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(651), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(659), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4701] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(221), 1,
      sym_identifier,
    ACTIONS(223), 1,
      anon_sym_BANG,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(369), 1,
      sym_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(401), 1,
      sym_member_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(699), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4831] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(225), 1,
      sym_number,
    ACTIONS(227), 1,
      sym_null,
    ACTIONS(251), 1,
      anon_sym_PIPE,
    ACTIONS(259), 1,
      sym_identifier,
    ACTIONS(261), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(381), 1,
      sym_boolean,
    STATE(475), 1,
      sym_expression,
    STATE(477), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(651), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(374), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(659), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(229), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [4961] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(263), 1,
      sym_identifier,
    ACTIONS(265), 1,
      anon_sym_BANG,
    ACTIONS(267), 1,
      sym_number,
    ACTIONS(269), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(369), 1,
      sym_expression,
    STATE(487), 1,
      sym_member_expression,
    STATE(525), 1,
      sym_boolean,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(530), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(699), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(271), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [5091] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(169), 1,
      sym_identifier,
    ACTIONS(171), 1,
      anon_sym_BANG,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(376), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(412), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [5221] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(253), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(369), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(699), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [5351] = 33,
    ACTIONS(123), 1,
      sym_identifier,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(253), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(370), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(385), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [5481] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(169), 1,
      sym_identifier,
    ACTIONS(171), 1,
      anon_sym_BANG,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(245), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(371), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(412), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(595), 1,
      aux_sym_union_type_repeat1,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(384), 2,
      sym_object,
      sym_string,
    STATE(407), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(596), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [5611] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(143), 1,
      sym_number,
    ACTIONS(147), 1,
      sym_null,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(235), 1,
      sym_identifier,
    ACTIONS(243), 1,
      anon_sym_BANG,
    ACTIONS(245), 1,
      anon_sym_PIPE,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(371), 1,
      sym_expression,
    STATE(382), 1,
      sym_boolean,
    STATE(404), 1,
      sym_member_expression,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(588), 1,
      sym_type,
    STATE(589), 1,
      sym_union_type,
    STATE(595), 1,
      aux_sym_union_type_repeat1,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(378), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(596), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(153), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [5741] = 33,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(263), 1,
      sym_identifier,
    ACTIONS(265), 1,
      anon_sym_BANG,
    ACTIONS(267), 1,
      sym_number,
    ACTIONS(269), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(370), 1,
      sym_expression,
    STATE(487), 1,
      sym_member_expression,
    STATE(525), 1,
      sym_boolean,
    STATE(559), 1,
      sym_parameterized_type,
    STATE(589), 1,
      sym_union_type,
    STATE(689), 1,
      aux_sym_union_type_repeat1,
    STATE(751), 1,
      sym_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 2,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(530), 2,
      sym_object,
      sym_string,
    STATE(583), 3,
      sym_primitive_type,
      sym_array_type,
      sym_parenthesized_type,
    STATE(587), 3,
      sym__type_not_union,
      sym_nullable_type,
      sym_negated_type,
    STATE(364), 4,
      sym_call_expression,
      sym_array,
      sym_for_statement,
      sym__literal,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    ACTIONS(271), 7,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
    ACTIONS(125), 9,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
  [5871] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(509), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    ACTIONS(273), 4,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_PIPE,
    ACTIONS(277), 5,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [5984] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(511), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    ACTIONS(273), 4,
      ts_builtin_sym_end,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_PIPE,
    ACTIONS(277), 5,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6097] = 29,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(293), 1,
      anon_sym_RBRACK,
    ACTIONS(295), 1,
      anon_sym_for,
    ACTIONS(297), 1,
      anon_sym_QMARK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(5), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(224), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6216] = 29,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_COMMA,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(61), 1,
      anon_sym_RBRACK,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(59), 1,
      aux_sym_array_repeat1,
    STATE(84), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(216), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6335] = 29,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(301), 1,
      anon_sym_COMMA,
    ACTIONS(303), 1,
      anon_sym_RBRACK,
    STATE(59), 1,
      aux_sym_array_repeat1,
    STATE(84), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(216), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6454] = 29,
    ACTIONS(305), 1,
      sym_identifier,
    ACTIONS(311), 1,
      anon_sym_LBRACE,
    ACTIONS(314), 1,
      anon_sym_COMMA,
    ACTIONS(317), 1,
      anon_sym_resource,
    ACTIONS(320), 1,
      anon_sym_BANG,
    ACTIONS(323), 1,
      anon_sym_LPAREN,
    ACTIONS(326), 1,
      anon_sym_AT,
    ACTIONS(329), 1,
      anon_sym_LBRACK,
    ACTIONS(332), 1,
      anon_sym_RBRACK,
    ACTIONS(334), 1,
      anon_sym_DASH,
    ACTIONS(337), 1,
      sym_number,
    ACTIONS(343), 1,
      sym_null,
    ACTIONS(346), 1,
      anon_sym_SQUOTE,
    ACTIONS(349), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(59), 1,
      aux_sym_array_repeat1,
    STATE(84), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(216), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(340), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(308), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6573] = 29,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(352), 1,
      anon_sym_COMMA,
    ACTIONS(354), 1,
      anon_sym_RBRACK,
    STATE(59), 1,
      aux_sym_array_repeat1,
    STATE(84), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(216), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6692] = 29,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(356), 1,
      anon_sym_COMMA,
    ACTIONS(358), 1,
      anon_sym_RBRACK,
    STATE(59), 1,
      aux_sym_array_repeat1,
    STATE(84), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(216), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6811] = 29,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(115), 1,
      anon_sym_COMMA,
    ACTIONS(117), 1,
      anon_sym_RBRACK,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(59), 1,
      aux_sym_array_repeat1,
    STATE(84), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(216), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [6930] = 29,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(105), 1,
      anon_sym_COMMA,
    ACTIONS(107), 1,
      anon_sym_RBRACK,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(59), 1,
      aux_sym_array_repeat1,
    STATE(84), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(216), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7049] = 28,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(293), 1,
      anon_sym_RBRACK,
    ACTIONS(295), 1,
      anon_sym_for,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(6), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(224), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7165] = 28,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(360), 1,
      anon_sym_RBRACK,
    ACTIONS(362), 1,
      anon_sym_for,
    STATE(3), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(211), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7281] = 28,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(364), 1,
      anon_sym_RBRACK,
    ACTIONS(366), 1,
      anon_sym_for,
    STATE(8), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(233), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7397] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(61), 1,
      anon_sym_RBRACK,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7510] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(303), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7623] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(368), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7736] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(107), 1,
      anon_sym_RBRACK,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7849] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(358), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [7962] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(277), 1,
      anon_sym_EQ,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(509), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    ACTIONS(273), 4,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_RPAREN,
      anon_sym_PIPE,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8071] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(354), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8184] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(520), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    ACTIONS(273), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_PIPE,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8291] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(370), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8404] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(117), 1,
      anon_sym_RBRACK,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8517] = 27,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(372), 1,
      anon_sym_RBRACK,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8630] = 26,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(189), 1,
      sym_decorators,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(436), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8740] = 18,
    ACTIONS(53), 1,
      anon_sym_EQ_GT,
    ACTIONS(67), 1,
      anon_sym_QMARK,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(77), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(89), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(376), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(374), 24,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8833] = 23,
    ACTIONS(53), 1,
      anon_sym_EQ_GT,
    ACTIONS(63), 1,
      anon_sym_DOT,
    ACTIONS(65), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(67), 1,
      anon_sym_QMARK,
    ACTIONS(69), 1,
      anon_sym_COLON_COLON,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(77), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(89), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    ACTIONS(386), 1,
      anon_sym_BANG,
    ACTIONS(388), 1,
      anon_sym_LBRACK,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(384), 6,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(382), 22,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8936] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(392), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(390), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [8999] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(396), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(394), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9062] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(400), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(398), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9125] = 21,
    ACTIONS(53), 1,
      anon_sym_EQ_GT,
    ACTIONS(63), 1,
      anon_sym_DOT,
    ACTIONS(65), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(67), 1,
      anon_sym_QMARK,
    ACTIONS(69), 1,
      anon_sym_COLON_COLON,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(77), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(89), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(404), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(402), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9224] = 21,
    ACTIONS(53), 1,
      anon_sym_EQ_GT,
    ACTIONS(63), 1,
      anon_sym_DOT,
    ACTIONS(65), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(67), 1,
      anon_sym_QMARK,
    ACTIONS(69), 1,
      anon_sym_COLON_COLON,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(77), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(89), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(408), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(406), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9323] = 4,
    ACTIONS(413), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(415), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(410), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9388] = 4,
    ACTIONS(394), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(420), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(418), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9453] = 4,
    ACTIONS(425), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(427), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(422), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9518] = 5,
    ACTIONS(434), 1,
      anon_sym_LT,
    STATE(563), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(432), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(430), 30,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9585] = 5,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 30,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9652] = 4,
    ACTIONS(445), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9717] = 4,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9782] = 21,
    ACTIONS(53), 1,
      anon_sym_EQ_GT,
    ACTIONS(63), 1,
      anon_sym_DOT,
    ACTIONS(65), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(67), 1,
      anon_sym_QMARK,
    ACTIONS(69), 1,
      anon_sym_COLON_COLON,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(77), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(89), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(332), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(447), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9881] = 4,
    ACTIONS(452), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(454), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(449), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [9946] = 5,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(459), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(457), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10013] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(461), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(452), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10076] = 5,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(459), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(457), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10143] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(463), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(413), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10206] = 5,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(467), 21,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10273] = 18,
    ACTIONS(53), 1,
      anon_sym_EQ_GT,
    ACTIONS(67), 1,
      anon_sym_QMARK,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(77), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(89), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(471), 9,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(469), 24,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10366] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(475), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(473), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10429] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(479), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(477), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10492] = 7,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(467), 20,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 29,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10563] = 14,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 12,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 25,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10648] = 13,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 25,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10731] = 12,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10812] = 11,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(467), 17,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10891] = 9,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(467), 19,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 28,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [10966] = 15,
    ACTIONS(71), 1,
      anon_sym_PLUS,
    ACTIONS(75), 1,
      anon_sym_PERCENT,
    ACTIONS(77), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(79), 1,
      anon_sym_AMP_AMP,
    ACTIONS(81), 1,
      anon_sym_PIPE,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_DASH,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(47), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(87), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(83), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 11,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 25,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11053] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(481), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(425), 32,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11116] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(522), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(801), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11222] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(487), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(485), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11284] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(491), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(489), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11346] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(491), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(489), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11408] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(495), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(493), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11470] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11532] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(499), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(497), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11594] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(503), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(501), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11656] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(507), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(505), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11718] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(505), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(813), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11824] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(511), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(509), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11886] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(515), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(513), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [11948] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(519), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(517), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12010] = 4,
    ACTIONS(525), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(523), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(521), 30,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12074] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(529), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(527), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12136] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(533), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(531), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12198] = 25,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    ACTIONS(535), 1,
      anon_sym_DOT,
    ACTIONS(537), 1,
      anon_sym_DOT_QMARK,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(95), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12304] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(541), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(539), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12366] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(545), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(543), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12428] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(549), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(547), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12490] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(420), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(418), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12552] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(553), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(551), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12614] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(512), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(784), 1,
      sym_if_statement,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12720] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(514), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(821), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12826] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(557), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(555), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12888] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(561), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(559), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [12950] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(511), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(273), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13054] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(500), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(806), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13160] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(501), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(808), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13266] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(502), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(810), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13372] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(432), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(430), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13434] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(565), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(563), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13496] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(515), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(768), 1,
      sym_if_statement,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13602] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(516), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(772), 1,
      sym_if_statement,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13708] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(517), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(776), 1,
      sym_if_statement,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13814] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(569), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(567), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13876] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(523), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(807), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [13982] = 25,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(483), 1,
      anon_sym_if,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(524), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    STATE(818), 1,
      sym_if_statement,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14088] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(573), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(571), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14150] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(577), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(575), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14212] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(581), 22,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(579), 31,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14274] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(583), 1,
      anon_sym_RPAREN,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(460), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14377] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(585), 1,
      anon_sym_QMARK,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(510), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14480] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(135), 1,
      anon_sym_RPAREN,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(459), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14583] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(297), 1,
      anon_sym_QMARK,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(497), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14686] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(587), 1,
      anon_sym_RPAREN,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(465), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14789] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(589), 1,
      anon_sym_RPAREN,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(461), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14892] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(591), 1,
      anon_sym_QMARK,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(508), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [14995] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(593), 1,
      anon_sym_RPAREN,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(468), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15098] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(595), 1,
      anon_sym_RPAREN,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(470), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15201] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(155), 1,
      anon_sym_RPAREN,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(464), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15304] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(537), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15404] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(103), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15504] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(104), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15604] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(397), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15704] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(105), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15804] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(279), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [15904] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(254), 1,
      sym_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16004] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(287), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16104] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(271), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16204] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(272), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16304] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(273), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16404] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(274), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16504] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(276), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16604] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(278), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16704] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(280), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16804] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(106), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [16904] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(282), 1,
      sym_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17004] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(107), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17104] = 12,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    STATE(303), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 12,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17182] = 22,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(629), 1,
      anon_sym_BANG,
    ACTIONS(631), 1,
      anon_sym_EQ_GT,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(637), 1,
      anon_sym_QMARK,
    ACTIONS(639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(641), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(645), 1,
      anon_sym_PIPE,
    ACTIONS(648), 1,
      anon_sym_QMARK_QMARK,
    STATE(303), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(627), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(625), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17280] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(108), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17380] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(368), 1,
      sym_call_expression,
    STATE(552), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 6,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17482] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(320), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17582] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(109), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17682] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(495), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17782] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(80), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17882] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(329), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [17982] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(85), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18082] = 6,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    STATE(303), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(459), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(457), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18148] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(334), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18248] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(338), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18348] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(343), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18448] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(367), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18548] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(332), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18648] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(333), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18748] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(356), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18848] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(336), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [18948] = 6,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    STATE(303), 1,
      sym_arguments,
    STATE(504), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(459), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(457), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19014] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(415), 1,
      sym_call_expression,
    STATE(555), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 6,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19116] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(529), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19216] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(406), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19316] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(409), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19416] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(413), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19516] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(396), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19616] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(410), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19716] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(489), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19816] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(503), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [19916] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(95), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20016] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(411), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20116] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(4), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20216] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(291), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20316] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(79), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20416] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(341), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20516] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(97), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20616] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(93), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20716] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(320), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20816] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(509), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [20916] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(527), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21016] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(402), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21116] = 23,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(629), 1,
      anon_sym_BANG,
    ACTIONS(631), 1,
      anon_sym_EQ_GT,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(637), 1,
      anon_sym_QMARK,
    ACTIONS(639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(641), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(648), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(654), 1,
      anon_sym_LBRACK,
    ACTIONS(656), 1,
      anon_sym_PIPE,
    STATE(303), 1,
      sym_arguments,
    STATE(504), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(652), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(650), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21216] = 23,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(629), 1,
      anon_sym_BANG,
    ACTIONS(631), 1,
      anon_sym_EQ_GT,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(637), 1,
      anon_sym_QMARK,
    ACTIONS(639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(641), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(648), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(654), 1,
      anon_sym_LBRACK,
    ACTIONS(656), 1,
      anon_sym_PIPE,
    STATE(303), 1,
      sym_arguments,
    STATE(504), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(660), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(658), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21316] = 23,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(185), 1,
      anon_sym_resource,
    ACTIONS(191), 1,
      anon_sym_LBRACK,
    ACTIONS(193), 1,
      anon_sym_DASH,
    ACTIONS(201), 1,
      anon_sym_SQUOTE,
    ACTIONS(203), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(603), 1,
      anon_sym_BANG,
    ACTIONS(605), 1,
      anon_sym_LPAREN,
    ACTIONS(607), 1,
      sym_number,
    ACTIONS(609), 1,
      sym_null,
    STATE(258), 1,
      sym_expression,
    STATE(265), 1,
      sym_parenthesized_expression,
    STATE(295), 1,
      sym_primary_expression,
    STATE(703), 1,
      sym_parameterized_type,
    STATE(785), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(197), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(292), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(266), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(296), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(297), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(181), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21416] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(7), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21516] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(664), 4,
      anon_sym_LBRACE,
      anon_sym_AT,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 9,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 16,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(662), 22,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21580] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(498), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21680] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(494), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21780] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(499), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21880] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(291), 1,
      sym_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [21980] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(388), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22080] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(386), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22180] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(389), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22280] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(2), 1,
      sym_expression,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22380] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(387), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22480] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(511), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22580] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(513), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22680] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(390), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22780] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(391), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22880] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(392), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [22980] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(520), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23080] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(393), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23180] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(173), 1,
      anon_sym_DASH,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    ACTIONS(597), 1,
      sym_identifier,
    ACTIONS(599), 1,
      anon_sym_BANG,
    STATE(358), 1,
      sym_primary_expression,
    STATE(395), 1,
      sym_expression,
    STATE(403), 1,
      sym_parenthesized_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(822), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(407), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23280] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(99), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23380] = 23,
    ACTIONS(39), 1,
      sym_identifier,
    ACTIONS(43), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_resource,
    ACTIONS(91), 1,
      sym_number,
    ACTIONS(95), 1,
      sym_null,
    ACTIONS(97), 1,
      anon_sym_SQUOTE,
    ACTIONS(99), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(287), 1,
      anon_sym_BANG,
    ACTIONS(289), 1,
      anon_sym_LPAREN,
    ACTIONS(291), 1,
      anon_sym_LBRACK,
    ACTIONS(299), 1,
      anon_sym_DASH,
    STATE(91), 1,
      sym_parenthesized_expression,
    STATE(100), 1,
      sym_expression,
    STATE(113), 1,
      sym_primary_expression,
    STATE(691), 1,
      sym_parameterized_type,
    STATE(803), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(93), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(136), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(92), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(114), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(116), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(41), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23480] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(536), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23580] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(538), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23680] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(539), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23780] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(540), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23880] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(541), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [23980] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(542), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24080] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(543), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24180] = 23,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(544), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 7,
      sym_call_expression,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24280] = 24,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(129), 1,
      anon_sym_resource,
    ACTIONS(137), 1,
      anon_sym_LBRACK,
    ACTIONS(139), 1,
      anon_sym_DASH,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(279), 1,
      anon_sym_BANG,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    ACTIONS(283), 1,
      sym_number,
    ACTIONS(285), 1,
      sym_null,
    STATE(225), 1,
      sym_call_expression,
    STATE(358), 1,
      sym_primary_expression,
    STATE(363), 1,
      sym_parenthesized_expression,
    STATE(546), 1,
      sym_expression,
    STATE(716), 1,
      sym_parameterized_type,
    STATE(793), 1,
      sym__lhs_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(145), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(365), 3,
      sym_member_expression,
      sym_subscript_expression,
      sym_resource_expression,
    STATE(362), 5,
      sym_lambda_expression,
      sym_assignment_expression,
      sym_ternary_expression,
      sym_binary_expression,
      sym_unary_expression,
    STATE(364), 6,
      sym_array,
      sym_object,
      sym_for_statement,
      sym__literal,
      sym_boolean,
      sym_string,
    ACTIONS(125), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24382] = 17,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(631), 1,
      anon_sym_EQ_GT,
    ACTIONS(641), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(648), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(666), 1,
      anon_sym_QMARK,
    ACTIONS(668), 1,
      anon_sym_PIPE,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(471), 8,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(469), 21,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24469] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 25,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24536] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(501), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(503), 40,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_with,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [24595] = 6,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24660] = 5,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(459), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(457), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24723] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(461), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(452), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24782] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(400), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(398), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24841] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 25,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24908] = 5,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [24971] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 6,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(670), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(440), 16,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(676), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25038] = 6,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 7,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 16,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(676), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25103] = 4,
    ACTIONS(679), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25164] = 4,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25225] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(392), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(390), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25284] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(475), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(473), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25343] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(531), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(533), 40,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_with,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [25402] = 5,
    ACTIONS(434), 1,
      anon_sym_LT,
    STATE(563), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(432), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(430), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25465] = 13,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(668), 1,
      anon_sym_PIPE,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 11,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 22,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25544] = 12,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(668), 1,
      anon_sym_PIPE,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 12,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 22,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25621] = 11,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 12,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25696] = 10,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(467), 16,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25769] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(559), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(561), 40,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_with,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [25828] = 8,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(467), 18,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 25,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25897] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(463), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(413), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [25956] = 14,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(641), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(668), 1,
      anon_sym_PIPE,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 10,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 22,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26037] = 5,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(467), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26100] = 22,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(631), 1,
      anon_sym_EQ_GT,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(639), 1,
      anon_sym_COLON_COLON,
    ACTIONS(641), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(648), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(654), 1,
      anon_sym_LBRACK,
    ACTIONS(666), 1,
      anon_sym_QMARK,
    ACTIONS(668), 1,
      anon_sym_PIPE,
    ACTIONS(681), 1,
      anon_sym_BANG,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(384), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(382), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26197] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(396), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(394), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26256] = 17,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    ACTIONS(631), 1,
      anon_sym_EQ_GT,
    ACTIONS(641), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(643), 1,
      anon_sym_AMP_AMP,
    ACTIONS(648), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(666), 1,
      anon_sym_QMARK,
    ACTIONS(668), 1,
      anon_sym_PIPE,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(621), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(623), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(619), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(376), 8,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(374), 21,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26343] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(479), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(477), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26402] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(481), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(425), 28,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26461] = 5,
    ACTIONS(683), 1,
      anon_sym_LT,
    STATE(473), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(432), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(430), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26524] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(527), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(529), 40,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_with,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [26583] = 7,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(617), 1,
      anon_sym_PERCENT,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(467), 20,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(465), 25,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26650] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(549), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(547), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26708] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(413), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(463), 39,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [26766] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(541), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(539), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26824] = 5,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(465), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(467), 37,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [26886] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(561), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(559), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [26944] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(432), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(430), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27002] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(573), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(571), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27060] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(491), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(489), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27118] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(491), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(489), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27176] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27234] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(503), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(501), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27292] = 5,
    ACTIONS(691), 1,
      anon_sym_LBRACK,
    ACTIONS(693), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(689), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(687), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27354] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(430), 5,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(697), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(432), 16,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(695), 22,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27416] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(511), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(509), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27474] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(519), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(517), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27532] = 4,
    ACTIONS(699), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(523), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(521), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27592] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(515), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(513), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27650] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(533), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(531), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27708] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(545), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(543), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27766] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(420), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(418), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27824] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(565), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(563), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27882] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(577), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(575), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27940] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(553), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(551), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [27998] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(581), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(579), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28056] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(507), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(505), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28114] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(557), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(555), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28172] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(569), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(567), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28230] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(487), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(485), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28288] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(495), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(493), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28346] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(499), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(497), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28404] = 5,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(440), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 26,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28466] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(425), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(481), 39,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [28524] = 5,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 37,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [28586] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(452), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(461), 39,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [28644] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(687), 7,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(689), 16,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(693), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28706] = 5,
    ACTIONS(697), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(695), 3,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(432), 21,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(430), 24,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DOT,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28768] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 7,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 16,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(676), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_PIPE,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28830] = 5,
    ACTIONS(434), 1,
      anon_sym_LT,
    STATE(563), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(430), 9,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(432), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [28892] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(529), 22,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(527), 27,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [28950] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(493), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(495), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29007] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(430), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(432), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29064] = 7,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(465), 8,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(467), 35,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29129] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(418), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(420), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29186] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(543), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(545), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29243] = 8,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(465), 8,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(467), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29310] = 14,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(465), 5,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
    ACTIONS(467), 25,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_QMARK_QMARK,
  [29389] = 13,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(465), 5,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
    ACTIONS(467), 26,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [29466] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(563), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(565), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29523] = 22,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(382), 2,
      anon_sym_as,
      anon_sym_COLON,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(384), 20,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_RBRACK,
  [29618] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(575), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(577), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29675] = 12,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(465), 5,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
    ACTIONS(467), 27,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
  [29750] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(509), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(511), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29807] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(551), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(553), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [29864] = 17,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(469), 4,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(471), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
  [29949] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(517), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(519), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30006] = 11,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(465), 6,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(467), 27,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
  [30079] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(513), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(515), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30136] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(390), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(392), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30193] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(539), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(541), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30250] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(473), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(475), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30307] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(394), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(396), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30364] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(579), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(581), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30421] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(477), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(479), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30478] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(505), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(507), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30535] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(571), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(573), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30592] = 5,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 8,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30653] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(547), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(549), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30710] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(398), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(400), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30767] = 17,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(374), 4,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(376), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
  [30852] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(555), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(557), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30909] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(489), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(491), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [30966] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(567), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(569), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31023] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(485), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(487), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31080] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(497), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(499), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31137] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(489), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(491), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31194] = 4,
    ACTIONS(735), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 9,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31253] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 10,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31310] = 4,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 9,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31369] = 4,
    ACTIONS(737), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(521), 9,
      anon_sym_EQ,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(523), 38,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31428] = 10,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 6,
      anon_sym_as,
      anon_sym_BANG,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(467), 31,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_QMARK_QMARK,
  [31499] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(664), 3,
      sym__external_asterisk,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(436), 8,
      anon_sym_STAR,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(662), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [31559] = 6,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 8,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 35,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31620] = 12,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 4,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 25,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
  [31692] = 6,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(593), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 8,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31751] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(430), 4,
      anon_sym_DOT,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(695), 4,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(432), 18,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(697), 18,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
  [31808] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(670), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [31869] = 5,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(436), 7,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [31926] = 8,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(436), 5,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(670), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [31989] = 22,
    ACTIONS(625), 1,
      anon_sym_EQ,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(743), 1,
      anon_sym_EQ_GT,
    ACTIONS(745), 1,
      anon_sym_QMARK,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(751), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(755), 1,
      anon_sym_PIPE,
    ACTIONS(764), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(627), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [32080] = 12,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(465), 5,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(467), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
  [32151] = 7,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(693), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(691), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
    ACTIONS(440), 18,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [32212] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(695), 3,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(697), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(430), 5,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(432), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [32269] = 14,
    ACTIONS(625), 1,
      anon_sym_EQ,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 4,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 7,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
    ACTIONS(627), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [32344] = 5,
    ACTIONS(693), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(687), 7,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(689), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [32401] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(693), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(687), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(689), 18,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(691), 18,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
  [32458] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(436), 5,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 34,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [32519] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(676), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(691), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(670), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [32578] = 6,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 34,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [32637] = 7,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(465), 7,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(467), 31,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [32697] = 12,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(766), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 4,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
  [32767] = 17,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_EQ_GT,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(751), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(764), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(766), 1,
      anon_sym_PIPE,
    ACTIONS(768), 1,
      anon_sym_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(469), 3,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(471), 19,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
  [32847] = 13,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(766), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 4,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 22,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [32919] = 11,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(465), 5,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(467), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
  [32987] = 10,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 5,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(467), 27,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_QMARK_QMARK,
  [33053] = 8,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(465), 7,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(467), 29,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [33115] = 14,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(751), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(766), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 4,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_QMARK_QMARK,
  [33189] = 6,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(600), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 7,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [33247] = 22,
    ACTIONS(382), 1,
      anon_sym_EQ,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(743), 1,
      anon_sym_EQ_GT,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(751), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(764), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(766), 1,
      anon_sym_PIPE,
    ACTIONS(768), 1,
      anon_sym_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(384), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [33337] = 22,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(772), 1,
      anon_sym_as,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(770), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [33427] = 17,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_EQ_GT,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(751), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(764), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(766), 1,
      anon_sym_PIPE,
    ACTIONS(768), 1,
      anon_sym_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(374), 3,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(376), 19,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
  [33507] = 22,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(776), 1,
      anon_sym_QMARK,
    ACTIONS(778), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(600), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(774), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [33597] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(776), 1,
      anon_sym_QMARK,
    ACTIONS(780), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(627), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [33685] = 4,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 7,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 34,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [33738] = 5,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 7,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [33793] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(783), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [33880] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 8,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 34,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [33931] = 7,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(693), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(691), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [33990] = 6,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(676), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(436), 5,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(670), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [34047] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(785), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [34134] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 8,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 34,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [34185] = 6,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 6,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 33,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_STAR,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [34242] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(787), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [34329] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(789), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [34416] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(791), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [34503] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(676), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
    ACTIONS(670), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [34558] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(795), 1,
      anon_sym_BANG,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(793), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [34645] = 8,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(693), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 5,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(691), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [34706] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 7,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(664), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
    ACTIONS(440), 18,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [34758] = 21,
    ACTIONS(797), 1,
      ts_builtin_sym_end,
    ACTIONS(799), 1,
      anon_sym_module,
    ACTIONS(802), 1,
      anon_sym_import,
    ACTIONS(805), 1,
      anon_sym_provider,
    ACTIONS(808), 1,
      anon_sym_using,
    ACTIONS(811), 1,
      anon_sym_targetScope,
    ACTIONS(814), 1,
      anon_sym_metadata,
    ACTIONS(817), 1,
      anon_sym_output,
    ACTIONS(820), 1,
      anon_sym_param,
    ACTIONS(823), 1,
      anon_sym_resource,
    ACTIONS(826), 1,
      anon_sym_type,
    ACTIONS(829), 1,
      anon_sym_var,
    ACTIONS(832), 1,
      anon_sym_func,
    ACTIONS(835), 1,
      anon_sym_test,
    ACTIONS(838), 1,
      anon_sym_assert,
    ACTIONS(841), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(416), 2,
      sym_statement,
      aux_sym_infrastructure_repeat1,
    STATE(607), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(611), 7,
      sym_declaration,
      sym_import_statement,
      sym_import_with_statement,
      sym_import_functionality,
      sym_using_statement,
      sym_target_scope_assignment,
      sym_decorators,
    STATE(615), 10,
      sym_module_declaration,
      sym_metadata_declaration,
      sym_output_declaration,
      sym_parameter_declaration,
      sym_resource_declaration,
      sym_type_declaration,
      sym_variable_declaration,
      sym_user_defined_function,
      sym_test_block,
      sym_assert_statement,
  [34840] = 21,
    ACTIONS(9), 1,
      anon_sym_module,
    ACTIONS(11), 1,
      anon_sym_import,
    ACTIONS(13), 1,
      anon_sym_provider,
    ACTIONS(15), 1,
      anon_sym_using,
    ACTIONS(17), 1,
      anon_sym_targetScope,
    ACTIONS(19), 1,
      anon_sym_metadata,
    ACTIONS(21), 1,
      anon_sym_output,
    ACTIONS(23), 1,
      anon_sym_param,
    ACTIONS(25), 1,
      anon_sym_resource,
    ACTIONS(27), 1,
      anon_sym_type,
    ACTIONS(29), 1,
      anon_sym_var,
    ACTIONS(31), 1,
      anon_sym_func,
    ACTIONS(33), 1,
      anon_sym_test,
    ACTIONS(35), 1,
      anon_sym_assert,
    ACTIONS(37), 1,
      anon_sym_AT,
    ACTIONS(844), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(416), 2,
      sym_statement,
      aux_sym_infrastructure_repeat1,
    STATE(607), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(611), 7,
      sym_declaration,
      sym_import_statement,
      sym_import_with_statement,
      sym_import_functionality,
      sym_using_statement,
      sym_target_scope_assignment,
      sym_decorators,
    STATE(615), 10,
      sym_module_declaration,
      sym_metadata_declaration,
      sym_output_declaration,
      sym_parameter_declaration,
      sym_resource_declaration,
      sym_type_declaration,
      sym_variable_declaration,
      sym_user_defined_function,
      sym_test_block,
      sym_assert_statement,
  [34922] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(850), 1,
      anon_sym_COMMA,
    ACTIONS(852), 1,
      anon_sym_RBRACE,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(427), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [34991] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(860), 1,
      anon_sym_COMMA,
    ACTIONS(862), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(421), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35060] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(864), 1,
      anon_sym_COMMA,
    ACTIONS(866), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(423), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35129] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(864), 1,
      anon_sym_COMMA,
    ACTIONS(866), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35198] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(868), 1,
      anon_sym_COMMA,
    ACTIONS(870), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(432), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35267] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(872), 1,
      anon_sym_COMMA,
    ACTIONS(874), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35336] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(876), 1,
      anon_sym_COMMA,
    ACTIONS(878), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(433), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35405] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(876), 1,
      anon_sym_COMMA,
    ACTIONS(878), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35474] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(880), 1,
      anon_sym_COMMA,
    ACTIONS(882), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(425), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35543] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(884), 1,
      anon_sym_COMMA,
    ACTIONS(886), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35612] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(888), 1,
      anon_sym_COMMA,
    ACTIONS(890), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35681] = 16,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(898), 1,
      anon_sym_COMMA,
    ACTIONS(901), 1,
      anon_sym_RBRACE,
    ACTIONS(903), 1,
      anon_sym_resource,
    ACTIONS(906), 1,
      anon_sym_AT,
    ACTIONS(909), 1,
      anon_sym_SQUOTE,
    ACTIONS(912), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(915), 1,
      sym__external_asterisk,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(895), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35750] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(888), 1,
      anon_sym_COMMA,
    ACTIONS(890), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(431), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35819] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(918), 1,
      anon_sym_COMMA,
    ACTIONS(920), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35888] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(850), 1,
      anon_sym_COMMA,
    ACTIONS(852), 1,
      anon_sym_RBRACE,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [35957] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(922), 1,
      anon_sym_COMMA,
    ACTIONS(924), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(429), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36026] = 16,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(926), 1,
      anon_sym_COMMA,
    ACTIONS(928), 1,
      anon_sym_RBRACE,
    STATE(490), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(428), 2,
      sym_object_property,
      aux_sym_object_repeat1,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36095] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(874), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36160] = 5,
    ACTIONS(57), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(439), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    ACTIONS(932), 6,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(930), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DASH,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36205] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(886), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36270] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(934), 1,
      anon_sym_RBRACE,
    STATE(426), 1,
      sym_object_property,
    STATE(531), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36335] = 5,
    ACTIONS(940), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(439), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    ACTIONS(938), 6,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(936), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DASH,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36380] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(943), 1,
      anon_sym_RBRACE,
    STATE(422), 1,
      sym_object_property,
    STATE(507), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36445] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(878), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36510] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(924), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36575] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(945), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36640] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(947), 1,
      anon_sym_RBRACE,
    STATE(419), 1,
      sym_object_property,
    STATE(534), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36705] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(866), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36770] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(949), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36835] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(951), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36900] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(852), 1,
      anon_sym_RBRACE,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [36965] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(890), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37030] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(920), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37095] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(953), 1,
      anon_sym_RBRACE,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37160] = 15,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    ACTIONS(955), 1,
      anon_sym_RBRACE,
    STATE(434), 1,
      sym_object_property,
    STATE(528), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37225] = 14,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(496), 1,
      sym_decorators,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(573), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37287] = 24,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(959), 1,
      anon_sym_RPAREN,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(963), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(675), 1,
      aux_sym_union_type_repeat1,
    STATE(695), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [37368] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(967), 7,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(965), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DASH,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37407] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(971), 7,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(969), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DASH,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37446] = 24,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(963), 1,
      anon_sym_PIPE,
    ACTIONS(973), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(675), 1,
      aux_sym_union_type_repeat1,
    STATE(686), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [37527] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(977), 7,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      sym_number,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(975), 23,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DASH,
      anon_sym_true,
      anon_sym_false,
      sym_null,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37566] = 23,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(959), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(695), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [37644] = 23,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(979), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(706), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [37722] = 23,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(981), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(705), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [37800] = 7,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(983), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(652), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(650), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37846] = 7,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(983), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(660), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(658), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [37892] = 23,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(973), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(686), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [37970] = 23,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(985), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(698), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [38048] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(989), 9,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(987), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DOT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38086] = 6,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(675), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 7,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 19,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [38130] = 23,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(991), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(694), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [38208] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(993), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(627), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [38282] = 23,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(996), 1,
      anon_sym_RPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(714), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [38360] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1000), 9,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(998), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DOT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38398] = 13,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(465), 4,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
    ACTIONS(467), 7,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK_QMARK,
  [38456] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1004), 9,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1002), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DOT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38494] = 6,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(983), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 7,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(693), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38538] = 6,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(654), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 7,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 19,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [38582] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1008), 9,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1006), 20,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_DOT,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38620] = 6,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [38663] = 6,
    ACTIONS(1010), 1,
      anon_sym_BANG,
    ACTIONS(1012), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(660), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(658), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38706] = 5,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(273), 7,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(277), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38747] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1020), 9,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1018), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38784] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 5,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 19,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [38829] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1024), 9,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_BANG,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1022), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38866] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
    ACTIONS(436), 5,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [38911] = 6,
    ACTIONS(1010), 1,
      anon_sym_BANG,
    ACTIONS(1012), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(652), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(650), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [38954] = 6,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(674), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 8,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [38997] = 5,
    ACTIONS(1010), 1,
      anon_sym_BANG,
    ACTIONS(1012), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 7,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(693), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [39038] = 6,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 19,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [39081] = 22,
    ACTIONS(625), 1,
      anon_sym_EQ,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(743), 1,
      anon_sym_EQ_GT,
    ACTIONS(749), 1,
      anon_sym_SLASH,
    ACTIONS(751), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(753), 1,
      anon_sym_AMP_AMP,
    ACTIONS(755), 1,
      anon_sym_PIPE,
    ACTIONS(764), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1026), 1,
      anon_sym_QMARK,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(739), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(747), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(760), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(762), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(758), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39156] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1028), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39229] = 11,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(574), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [39281] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(776), 1,
      anon_sym_QMARK,
    ACTIONS(1030), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(593), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39353] = 5,
    ACTIONS(1036), 1,
      anon_sym_PIPE,
    STATE(504), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1032), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [39393] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(1039), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(674), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39465] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1041), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39537] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1043), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39609] = 11,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(572), 1,
      sym_resource_declaration,
    STATE(579), 1,
      sym_object_property,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [39661] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1045), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39733] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1047), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39805] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1049), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39877] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1051), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [39949] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1053), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40021] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1055), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40093] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1057), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40165] = 5,
    ACTIONS(241), 1,
      anon_sym_PIPE,
    STATE(545), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1061), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1059), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [40205] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1063), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40277] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(1065), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(668), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40349] = 11,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(418), 1,
      sym_object_property,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [40401] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1067), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40473] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1069), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40545] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1071), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40617] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1073), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40689] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1075), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40761] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1077), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40833] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1079), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40905] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1081), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [40977] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1083), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41049] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1085), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41121] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(1087), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(654), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41193] = 21,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(1089), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41265] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1092), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41337] = 20,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(741), 1,
      anon_sym_BANG,
    ACTIONS(961), 1,
      anon_sym_QMARK,
    ACTIONS(1089), 1,
      anon_sym_PIPE,
    STATE(366), 1,
      sym_arguments,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41407] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1094), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41479] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1096), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41551] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1098), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41623] = 5,
    ACTIONS(691), 1,
      anon_sym_LBRACK,
    ACTIONS(693), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(687), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(689), 19,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [41663] = 5,
    ACTIONS(697), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(695), 3,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(430), 4,
      anon_sym_DOT,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(432), 19,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [41703] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1100), 1,
      anon_sym_RBRACK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41775] = 11,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(430), 1,
      sym_object_property,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [41827] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1102), 1,
      anon_sym_RBRACE,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [41899] = 5,
    ACTIONS(670), 1,
      anon_sym_LBRACK,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 19,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [41939] = 11,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(424), 1,
      sym_object_property,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [41991] = 4,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 7,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(625), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [42029] = 5,
    ACTIONS(241), 1,
      anon_sym_PIPE,
    STATE(545), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1106), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1104), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [42069] = 11,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(846), 1,
      sym_identifier,
    ACTIONS(854), 1,
      anon_sym_resource,
    ACTIONS(858), 1,
      sym__external_asterisk,
    STATE(420), 1,
      sym_object_property,
    STATE(572), 1,
      sym_resource_declaration,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
    STATE(786), 2,
      sym_string,
      sym_compatible_identifier,
    ACTIONS(848), 16,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [42121] = 6,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    STATE(366), 1,
      sym_arguments,
    STATE(668), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(457), 7,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(459), 17,
      anon_sym_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [42163] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1108), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42235] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1110), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42307] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1112), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42379] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1114), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42451] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1116), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42523] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1118), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42595] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1120), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42667] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1122), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42739] = 21,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(1124), 1,
      anon_sym_COLON,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42811] = 5,
    ACTIONS(1126), 1,
      anon_sym_PIPE,
    STATE(545), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(625), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [42851] = 20,
    ACTIONS(378), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(124), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [42920] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(660), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(658), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [42957] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(652), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(650), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [42994] = 6,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 16,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [43035] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 7,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1032), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43070] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(273), 7,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(277), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43105] = 20,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(303), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [43174] = 4,
    ACTIONS(1133), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1131), 6,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1129), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43211] = 7,
    ACTIONS(438), 1,
      anon_sym_EQ,
    ACTIONS(442), 1,
      anon_sym_DOT,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
    ACTIONS(436), 5,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 16,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [43254] = 20,
    ACTIONS(685), 1,
      anon_sym_LPAREN,
    ACTIONS(703), 1,
      anon_sym_SLASH,
    ACTIONS(707), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(711), 1,
      anon_sym_PIPE,
    ACTIONS(719), 1,
      anon_sym_BANG,
    ACTIONS(721), 1,
      anon_sym_EQ_GT,
    ACTIONS(723), 1,
      anon_sym_LBRACK,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(729), 1,
      anon_sym_QMARK,
    ACTIONS(731), 1,
      anon_sym_COLON_COLON,
    ACTIONS(733), 1,
      anon_sym_QMARK_QMARK,
    STATE(366), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(701), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(705), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(715), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(713), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
  [43323] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(273), 7,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(277), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43358] = 5,
    ACTIONS(693), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
    ACTIONS(687), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(689), 16,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [43396] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(697), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
    ACTIONS(695), 3,
      anon_sym_BANG,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(430), 4,
      anon_sym_DOT,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(432), 16,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [43434] = 6,
    ACTIONS(693), 1,
      anon_sym_EQ,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(1135), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [43474] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1006), 2,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(1008), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
  [43508] = 4,
    ACTIONS(1034), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(660), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(658), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43544] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(998), 2,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(1000), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
  [43578] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1002), 2,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(1004), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
  [43612] = 4,
    ACTIONS(1034), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(652), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(650), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43648] = 5,
    ACTIONS(676), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(670), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
    ACTIONS(436), 6,
      anon_sym_BANG,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_SLASH,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(440), 16,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DOT_QMARK,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK_QMARK,
  [43686] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(987), 2,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(989), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_DOT_QMARK,
      anon_sym_PIPE,
  [43720] = 5,
    ACTIONS(277), 1,
      anon_sym_EQ,
    ACTIONS(1137), 1,
      anon_sym_DOT,
    ACTIONS(1139), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(273), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [43757] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(557), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(555), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43790] = 3,
    ACTIONS(1018), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1020), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE,
  [43823] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1143), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1141), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43856] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(577), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(575), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43889] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1147), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1145), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43922] = 5,
    ACTIONS(856), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(932), 2,
      sym__external_asterisk,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(582), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    ACTIONS(930), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43959] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(901), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1149), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [43992] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(487), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(485), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44025] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1153), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1151), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44058] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(495), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(493), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44091] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(499), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(497), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44124] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1157), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1155), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44157] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(581), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(579), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44190] = 3,
    ACTIONS(1022), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1024), 23,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_BANG,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_PIPE,
  [44223] = 5,
    ACTIONS(1159), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(938), 2,
      sym__external_asterisk,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(582), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    ACTIONS(936), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44260] = 5,
    ACTIONS(693), 1,
      anon_sym_EQ,
    ACTIONS(1162), 1,
      anon_sym_BANG,
    ACTIONS(1164), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [44297] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1168), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1166), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44330] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(511), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(509), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44363] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(545), 5,
      sym__external_asterisk,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(543), 19,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_existing,
      anon_sym_type,
      anon_sym_var,
      anon_sym_SQUOTE,
      sym_identifier,
      anon_sym_array,
      anon_sym_bool,
      anon_sym_int,
      anon_sym_object,
      anon_sym_secureObject,
      anon_sym_secureString,
      anon_sym_string,
  [44396] = 4,
    ACTIONS(625), 1,
      anon_sym_EQ,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [44430] = 4,
    ACTIONS(1129), 1,
      anon_sym_EQ,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1131), 20,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_PIPE,
  [44463] = 3,
    ACTIONS(1032), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [44494] = 3,
    ACTIONS(277), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(273), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [44525] = 3,
    ACTIONS(277), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(273), 21,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_COMMA,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_EQ_GT,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_RPAREN,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [44556] = 6,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(1135), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(774), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [44592] = 4,
    ACTIONS(245), 1,
      anon_sym_PIPE,
    STATE(597), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1061), 18,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44623] = 4,
    ACTIONS(245), 1,
      anon_sym_PIPE,
    STATE(593), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 18,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44654] = 4,
    ACTIONS(245), 1,
      anon_sym_PIPE,
    STATE(597), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1106), 18,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44685] = 4,
    ACTIONS(1172), 1,
      anon_sym_PIPE,
    STATE(593), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 18,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44716] = 4,
    ACTIONS(1175), 1,
      anon_sym_PIPE,
    STATE(597), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 18,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_EQ,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44747] = 5,
    ACTIONS(1162), 1,
      anon_sym_BANG,
    ACTIONS(1164), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(774), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [44780] = 4,
    ACTIONS(233), 1,
      anon_sym_PIPE,
    STATE(601), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1106), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44810] = 4,
    ACTIONS(233), 1,
      anon_sym_PIPE,
    STATE(601), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1061), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44840] = 4,
    ACTIONS(1178), 1,
      anon_sym_PIPE,
    STATE(601), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44870] = 4,
    ACTIONS(1181), 1,
      anon_sym_PIPE,
    STATE(600), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_LBRACK,
  [44900] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
    ACTIONS(774), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [44927] = 4,
    ACTIONS(1184), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(604), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    ACTIONS(938), 15,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
  [44956] = 4,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(1189), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1187), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [44985] = 4,
    ACTIONS(1137), 1,
      anon_sym_DOT,
    ACTIONS(1139), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1191), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45014] = 4,
    ACTIONS(37), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(604), 2,
      sym_decorator,
      aux_sym_decorators_repeat1,
    ACTIONS(932), 15,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
  [45043] = 4,
    ACTIONS(1195), 1,
      anon_sym_as,
    ACTIONS(1197), 1,
      anon_sym_with,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1193), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45072] = 3,
    ACTIONS(1034), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(774), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45098] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1143), 17,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
      anon_sym_RBRACK,
  [45122] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1199), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45145] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1201), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45168] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1153), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45191] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1203), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45214] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1205), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45237] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1207), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45260] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1209), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45283] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1211), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45306] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1168), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45329] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1213), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45352] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1215), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45375] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1217), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45398] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1219), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45421] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1221), 16,
      ts_builtin_sym_end,
      anon_sym_module,
      anon_sym_import,
      anon_sym_provider,
      anon_sym_using,
      anon_sym_targetScope,
      anon_sym_metadata,
      anon_sym_output,
      anon_sym_param,
      anon_sym_resource,
      anon_sym_type,
      anon_sym_var,
      anon_sym_func,
      anon_sym_test,
      anon_sym_assert,
      anon_sym_AT,
  [45444] = 5,
    ACTIONS(1223), 1,
      anon_sym_SQUOTE,
    ACTIONS(1228), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(625), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1225), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45467] = 5,
    ACTIONS(1231), 1,
      anon_sym_SQUOTE,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(631), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1233), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45490] = 5,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1237), 1,
      anon_sym_SQUOTE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(629), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1239), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45513] = 5,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_SQUOTE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(630), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1243), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45536] = 5,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1245), 1,
      anon_sym_SQUOTE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(625), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1247), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45559] = 5,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1249), 1,
      anon_sym_SQUOTE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(625), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1247), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45582] = 5,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1251), 1,
      anon_sym_SQUOTE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(625), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1247), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45605] = 5,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1253), 1,
      anon_sym_SQUOTE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(633), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1255), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45628] = 5,
    ACTIONS(1235), 1,
      anon_sym_DOLLAR_LBRACE,
    ACTIONS(1257), 1,
      anon_sym_SQUOTE,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(625), 3,
      sym__escape_sequence,
      sym_interpolation,
      aux_sym__string_literal_repeat1,
    ACTIONS(1247), 5,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
  [45651] = 7,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1259), 1,
      anon_sym_LBRACE,
    ACTIONS(1261), 1,
      anon_sym_STAR,
    STATE(608), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45675] = 2,
    ACTIONS(5), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1263), 7,
      anon_sym_SQUOTE,
      anon_sym_DOLLAR,
      anon_sym_POUND,
      sym_string_content,
      aux_sym__escape_sequence_token1,
      sym_escape_sequence,
      anon_sym_DOLLAR_LBRACE,
  [45689] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(1265), 1,
      anon_sym_LBRACK,
    ACTIONS(1267), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(619), 3,
      sym_object,
      sym_if_statement,
      sym_for_statement,
  [45708] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(1265), 1,
      anon_sym_LBRACK,
    ACTIONS(1267), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(621), 3,
      sym_object,
      sym_if_statement,
      sym_for_statement,
  [45727] = 5,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    ACTIONS(1265), 1,
      anon_sym_LBRACK,
    ACTIONS(1267), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(613), 3,
      sym_object,
      sym_if_statement,
      sym_for_statement,
  [45746] = 5,
    ACTIONS(1269), 1,
      anon_sym_LBRACE,
    ACTIONS(1271), 1,
      anon_sym_LBRACK,
    ACTIONS(1273), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(576), 3,
      sym_object,
      sym_if_statement,
      sym_for_statement,
  [45765] = 5,
    ACTIONS(1269), 1,
      anon_sym_LBRACE,
    ACTIONS(1271), 1,
      anon_sym_LBRACK,
    ACTIONS(1273), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(584), 3,
      sym_object,
      sym_if_statement,
      sym_for_statement,
  [45784] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(620), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45802] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(731), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45820] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(617), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45838] = 5,
    ACTIONS(1275), 1,
      anon_sym_SQUOTE,
    ACTIONS(1277), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(704), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(742), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45856] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(614), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45874] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(624), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45892] = 5,
    ACTIONS(1275), 1,
      anon_sym_SQUOTE,
    ACTIONS(1277), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(735), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(742), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45910] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(746), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45928] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(612), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45946] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(782), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [45964] = 4,
    ACTIONS(251), 1,
      anon_sym_PIPE,
    STATE(655), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1106), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [45980] = 4,
    ACTIONS(251), 1,
      anon_sym_PIPE,
    STATE(654), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [45996] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(608), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [46014] = 4,
    ACTIONS(251), 1,
      anon_sym_PIPE,
    STATE(655), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1061), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46030] = 4,
    ACTIONS(1279), 1,
      anon_sym_PIPE,
    STATE(655), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46046] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(752), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [46064] = 5,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(983), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [46082] = 5,
    ACTIONS(1275), 1,
      anon_sym_SQUOTE,
    ACTIONS(1277), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(687), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(742), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [46100] = 4,
    ACTIONS(1282), 1,
      anon_sym_PIPE,
    STATE(654), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46116] = 5,
    ACTIONS(149), 1,
      anon_sym_SQUOTE,
    ACTIONS(151), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(622), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    STATE(275), 2,
      sym__string_literal,
      sym__multiline_string_literal,
  [46134] = 5,
    ACTIONS(1285), 1,
      sym_identifier,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1289), 1,
      anon_sym_in,
    STATE(824), 1,
      sym_for_loop_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46151] = 5,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      sym_identifier,
    ACTIONS(1293), 1,
      anon_sym_in,
    STATE(828), 1,
      sym_for_loop_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46168] = 4,
    ACTIONS(239), 1,
      anon_sym_PIPE,
    STATE(674), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 2,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [46183] = 4,
    ACTIONS(1295), 1,
      anon_sym_PIPE,
    STATE(674), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 2,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [46198] = 4,
    ACTIONS(239), 1,
      anon_sym_PIPE,
    STATE(678), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1106), 2,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [46213] = 4,
    ACTIONS(1298), 1,
      anon_sym_PIPE,
    STATE(668), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
  [46228] = 4,
    ACTIONS(161), 1,
      anon_sym_PIPE,
    STATE(669), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1106), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
  [46243] = 4,
    ACTIONS(161), 1,
      anon_sym_PIPE,
    STATE(669), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1061), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
  [46258] = 4,
    ACTIONS(1301), 1,
      anon_sym_PIPE,
    STATE(669), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
  [46273] = 5,
    ACTIONS(1304), 1,
      anon_sym_as,
    ACTIONS(1306), 1,
      anon_sym_COMMA,
    ACTIONS(1308), 1,
      anon_sym_RBRACE,
    STATE(715), 1,
      aux_sym_import_functionality_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46290] = 4,
    ACTIONS(141), 1,
      anon_sym_PIPE,
    STATE(675), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46305] = 4,
    ACTIONS(1010), 1,
      anon_sym_BANG,
    ACTIONS(1012), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(691), 2,
      anon_sym_LBRACK,
      anon_sym_PIPE,
  [46320] = 4,
    ACTIONS(141), 1,
      anon_sym_PIPE,
    STATE(676), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1106), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46335] = 4,
    ACTIONS(239), 1,
      anon_sym_PIPE,
    STATE(678), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1061), 2,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [46350] = 4,
    ACTIONS(141), 1,
      anon_sym_PIPE,
    STATE(676), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1061), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46365] = 4,
    ACTIONS(1310), 1,
      anon_sym_PIPE,
    STATE(676), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46380] = 4,
    ACTIONS(161), 1,
      anon_sym_PIPE,
    STATE(668), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 2,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
  [46395] = 4,
    ACTIONS(1313), 1,
      anon_sym_PIPE,
    STATE(678), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(627), 2,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [46410] = 4,
    ACTIONS(1316), 1,
      anon_sym_PIPE,
    STATE(675), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1034), 2,
      anon_sym_RPAREN,
      anon_sym_LBRACK,
  [46425] = 5,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1319), 1,
      sym_identifier,
    ACTIONS(1321), 1,
      anon_sym_in,
    STATE(783), 1,
      sym_for_loop_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46442] = 5,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1323), 1,
      sym_identifier,
    ACTIONS(1325), 1,
      anon_sym_in,
    STATE(831), 1,
      sym_for_loop_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46459] = 4,
    ACTIONS(1327), 1,
      anon_sym_COMMA,
    ACTIONS(1330), 1,
      anon_sym_GT,
    STATE(682), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46473] = 4,
    ACTIONS(1332), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1334), 1,
      sym__multiline_string_content,
    STATE(683), 1,
      aux_sym_multiline_string_content_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46487] = 4,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(1337), 1,
      anon_sym_PIPE,
    STATE(684), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46501] = 4,
    ACTIONS(1340), 1,
      sym__multiline_string_content,
    STATE(711), 1,
      aux_sym_multiline_string_content_repeat1,
    STATE(790), 1,
      sym_multiline_string_content,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46515] = 4,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(1342), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46529] = 4,
    ACTIONS(1344), 1,
      anon_sym_COMMA,
    ACTIONS(1346), 1,
      anon_sym_GT,
    STATE(696), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46543] = 4,
    ACTIONS(1306), 1,
      anon_sym_COMMA,
    ACTIONS(1348), 1,
      anon_sym_RBRACE,
    STATE(710), 1,
      aux_sym_import_functionality_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46557] = 4,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(1106), 1,
      anon_sym_LBRACK,
    STATE(684), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46571] = 4,
    ACTIONS(1340), 1,
      sym__multiline_string_content,
    STATE(711), 1,
      aux_sym_multiline_string_content_repeat1,
    STATE(826), 1,
      sym_multiline_string_content,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46585] = 4,
    ACTIONS(63), 1,
      anon_sym_DOT,
    ACTIONS(65), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(1350), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46599] = 4,
    ACTIONS(1352), 1,
      anon_sym_COMMA,
    ACTIONS(1355), 1,
      anon_sym_RPAREN,
    STATE(692), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46613] = 4,
    ACTIONS(1357), 1,
      sym_identifier,
    ACTIONS(1359), 1,
      anon_sym_COLON,
    ACTIONS(1361), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46627] = 4,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(1363), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46641] = 4,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(1365), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46655] = 4,
    ACTIONS(1344), 1,
      anon_sym_COMMA,
    ACTIONS(1367), 1,
      anon_sym_GT,
    STATE(682), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46669] = 4,
    ACTIONS(233), 1,
      anon_sym_PIPE,
    ACTIONS(1034), 1,
      anon_sym_LBRACK,
    STATE(600), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46683] = 4,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(1369), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46697] = 4,
    ACTIONS(1034), 1,
      anon_sym_LBRACK,
    ACTIONS(1371), 1,
      anon_sym_PIPE,
    STATE(712), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46711] = 4,
    ACTIONS(241), 1,
      anon_sym_PIPE,
    ACTIONS(1034), 1,
      anon_sym_LBRACK,
    STATE(504), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46725] = 4,
    ACTIONS(1374), 1,
      anon_sym_COMMA,
    ACTIONS(1376), 1,
      anon_sym_RPAREN,
    STATE(718), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46739] = 4,
    ACTIONS(1340), 1,
      sym__multiline_string_content,
    STATE(711), 1,
      aux_sym_multiline_string_content_repeat1,
    STATE(777), 1,
      sym_multiline_string_content,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46753] = 4,
    ACTIONS(633), 1,
      anon_sym_DOT,
    ACTIONS(635), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(983), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46767] = 4,
    ACTIONS(1344), 1,
      anon_sym_COMMA,
    ACTIONS(1378), 1,
      anon_sym_GT,
    STATE(713), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46781] = 4,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(1380), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46795] = 4,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(1382), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46809] = 4,
    ACTIONS(1306), 1,
      anon_sym_COMMA,
    ACTIONS(1384), 1,
      anon_sym_RBRACE,
    STATE(688), 1,
      aux_sym_import_functionality_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46823] = 3,
    ACTIONS(1386), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1388), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [46835] = 4,
    ACTIONS(1340), 1,
      sym__multiline_string_content,
    STATE(711), 1,
      aux_sym_multiline_string_content_repeat1,
    STATE(787), 1,
      sym_multiline_string_content,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46849] = 4,
    ACTIONS(1388), 1,
      anon_sym_RBRACE,
    ACTIONS(1390), 1,
      anon_sym_COMMA,
    STATE(710), 1,
      aux_sym_import_functionality_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46863] = 4,
    ACTIONS(1393), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1395), 1,
      sym__multiline_string_content,
    STATE(683), 1,
      aux_sym_multiline_string_content_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46877] = 4,
    ACTIONS(175), 1,
      anon_sym_PIPE,
    ACTIONS(1061), 1,
      anon_sym_LBRACK,
    STATE(684), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46891] = 4,
    ACTIONS(1344), 1,
      anon_sym_COMMA,
    ACTIONS(1397), 1,
      anon_sym_GT,
    STATE(682), 1,
      aux_sym_type_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46905] = 4,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(1399), 1,
      anon_sym_RPAREN,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46919] = 4,
    ACTIONS(1306), 1,
      anon_sym_COMMA,
    ACTIONS(1401), 1,
      anon_sym_RBRACE,
    STATE(710), 1,
      aux_sym_import_functionality_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46933] = 4,
    ACTIONS(725), 1,
      anon_sym_DOT,
    ACTIONS(727), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(1135), 1,
      anon_sym_BANG,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46947] = 3,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1403), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [46959] = 4,
    ACTIONS(1374), 1,
      anon_sym_COMMA,
    ACTIONS(1405), 1,
      anon_sym_RPAREN,
    STATE(692), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46973] = 4,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_RPAREN,
    STATE(701), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [46987] = 4,
    ACTIONS(1028), 1,
      anon_sym_RPAREN,
    ACTIONS(1411), 1,
      anon_sym_COMMA,
    STATE(720), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47001] = 3,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    STATE(623), 1,
      sym_object,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47012] = 3,
    ACTIONS(1414), 1,
      anon_sym_LT,
    STATE(560), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47023] = 3,
    ACTIONS(127), 1,
      anon_sym_LBRACE,
    STATE(610), 1,
      sym_object,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47034] = 3,
    ACTIONS(1359), 1,
      anon_sym_COLON,
    ACTIONS(1361), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47045] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(529), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [47054] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1355), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [47063] = 3,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(1416), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47074] = 3,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(1418), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47085] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(533), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [47094] = 3,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(1420), 1,
      anon_sym_EQ_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47105] = 3,
    ACTIONS(1422), 1,
      anon_sym_EQ,
    ACTIONS(1424), 1,
      anon_sym_existing,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47116] = 3,
    ACTIONS(1426), 1,
      anon_sym_COLON,
    ACTIONS(1428), 1,
      anon_sym_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47127] = 3,
    ACTIONS(535), 1,
      anon_sym_DOT,
    ACTIONS(537), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47138] = 3,
    ACTIONS(1430), 1,
      anon_sym_LPAREN,
    STATE(12), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47149] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1330), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [47158] = 3,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    STATE(743), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47169] = 3,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(1432), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47180] = 3,
    ACTIONS(281), 1,
      anon_sym_LPAREN,
    STATE(723), 1,
      sym_parenthesized_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47191] = 3,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47202] = 3,
    ACTIONS(1137), 1,
      anon_sym_DOT,
    ACTIONS(1139), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47213] = 3,
    ACTIONS(1434), 1,
      anon_sym_LT,
    STATE(476), 1,
      sym_type_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47224] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(561), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [47233] = 3,
    ACTIONS(1269), 1,
      anon_sym_LBRACE,
    STATE(570), 1,
      sym_object,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47244] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(1436), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [47253] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
    ACTIONS(503), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [47262] = 3,
    ACTIONS(1438), 1,
      anon_sym_EQ,
    ACTIONS(1440), 1,
      anon_sym_existing,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47273] = 3,
    ACTIONS(1407), 1,
      sym_identifier,
    STATE(726), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47284] = 2,
    ACTIONS(1442), 1,
      anon_sym_for,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47292] = 2,
    ACTIONS(1444), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47300] = 2,
    ACTIONS(1446), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47308] = 2,
    ACTIONS(1170), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47316] = 2,
    ACTIONS(1448), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47324] = 2,
    ACTIONS(1450), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47332] = 2,
    ACTIONS(1452), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47340] = 2,
    ACTIONS(1454), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47348] = 2,
    ACTIONS(1456), 1,
      anon_sym_resource,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47356] = 2,
    ACTIONS(1458), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47364] = 2,
    ACTIONS(1460), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47372] = 2,
    ACTIONS(1308), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47380] = 2,
    ACTIONS(1462), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47388] = 2,
    ACTIONS(1133), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47396] = 2,
    ACTIONS(1464), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47404] = 2,
    ACTIONS(1466), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47412] = 2,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47420] = 2,
    ACTIONS(1470), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47428] = 2,
    ACTIONS(1472), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47436] = 2,
    ACTIONS(1474), 1,
      anon_sym_from,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47444] = 2,
    ACTIONS(1081), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47452] = 2,
    ACTIONS(1476), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47460] = 2,
    ACTIONS(1478), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47468] = 2,
    ACTIONS(1480), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47476] = 2,
    ACTIONS(1083), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47484] = 2,
    ACTIONS(1482), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47492] = 2,
    ACTIONS(1484), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47500] = 2,
    ACTIONS(1486), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47508] = 2,
    ACTIONS(1085), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47516] = 2,
    ACTIONS(1488), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47524] = 2,
    ACTIONS(1490), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47532] = 2,
    ACTIONS(1492), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47540] = 2,
    ACTIONS(1494), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47548] = 2,
    ACTIONS(1496), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47556] = 2,
    ACTIONS(1498), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47564] = 2,
    ACTIONS(1500), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47572] = 2,
    ACTIONS(1075), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47580] = 2,
    ACTIONS(1502), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47588] = 2,
    ACTIONS(1426), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47596] = 2,
    ACTIONS(1504), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47604] = 2,
    ACTIONS(1506), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47612] = 2,
    ACTIONS(1508), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47620] = 2,
    ACTIONS(1510), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47628] = 2,
    ACTIONS(1512), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47636] = 2,
    ACTIONS(1514), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47644] = 2,
    ACTIONS(1516), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47652] = 2,
    ACTIONS(1518), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47660] = 2,
    ACTIONS(1520), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47668] = 2,
    ACTIONS(1522), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47676] = 2,
    ACTIONS(1524), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47684] = 2,
    ACTIONS(1526), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47692] = 2,
    ACTIONS(1528), 1,
      anon_sym_from,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47700] = 2,
    ACTIONS(1530), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47708] = 2,
    ACTIONS(1094), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47716] = 2,
    ACTIONS(1532), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47724] = 2,
    ACTIONS(1534), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47732] = 2,
    ACTIONS(1536), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47740] = 2,
    ACTIONS(1538), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47748] = 2,
    ACTIONS(1051), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47756] = 2,
    ACTIONS(1096), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47764] = 2,
    ACTIONS(1053), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47772] = 2,
    ACTIONS(1540), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47780] = 2,
    ACTIONS(1055), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47788] = 2,
    ACTIONS(1542), 1,
      anon_sym_from,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47796] = 2,
    ACTIONS(1544), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47804] = 2,
    ACTIONS(1063), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47812] = 2,
    ACTIONS(1546), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47820] = 2,
    ACTIONS(1548), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47828] = 2,
    ACTIONS(1550), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47836] = 2,
    ACTIONS(1552), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47844] = 2,
    ACTIONS(1098), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47852] = 2,
    ACTIONS(1554), 1,
      anon_sym_resource,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47860] = 2,
    ACTIONS(1556), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47868] = 2,
    ACTIONS(1079), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47876] = 2,
    ACTIONS(1558), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47884] = 2,
    ACTIONS(1560), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47892] = 2,
    ACTIONS(1562), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47900] = 2,
    ACTIONS(1564), 1,
      anon_sym_for,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47908] = 2,
    ACTIONS(1566), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47916] = 2,
    ACTIONS(1568), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47924] = 2,
    ACTIONS(1570), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47932] = 2,
    ACTIONS(1572), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47940] = 2,
    ACTIONS(1574), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47948] = 2,
    ACTIONS(1576), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
  [47956] = 2,
    ACTIONS(1578), 1,
      anon_sym_from,
    ACTIONS(3), 2,
      sym_comment,
      sym_diagnostic_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(9)] = 0,
  [SMALL_STATE(10)] = 133,
  [SMALL_STATE(11)] = 266,
  [SMALL_STATE(12)] = 399,
  [SMALL_STATE(13)] = 529,
  [SMALL_STATE(14)] = 659,
  [SMALL_STATE(15)] = 789,
  [SMALL_STATE(16)] = 919,
  [SMALL_STATE(17)] = 1049,
  [SMALL_STATE(18)] = 1179,
  [SMALL_STATE(19)] = 1313,
  [SMALL_STATE(20)] = 1443,
  [SMALL_STATE(21)] = 1573,
  [SMALL_STATE(22)] = 1703,
  [SMALL_STATE(23)] = 1833,
  [SMALL_STATE(24)] = 1963,
  [SMALL_STATE(25)] = 2093,
  [SMALL_STATE(26)] = 2223,
  [SMALL_STATE(27)] = 2353,
  [SMALL_STATE(28)] = 2483,
  [SMALL_STATE(29)] = 2613,
  [SMALL_STATE(30)] = 2743,
  [SMALL_STATE(31)] = 2873,
  [SMALL_STATE(32)] = 3003,
  [SMALL_STATE(33)] = 3133,
  [SMALL_STATE(34)] = 3263,
  [SMALL_STATE(35)] = 3397,
  [SMALL_STATE(36)] = 3527,
  [SMALL_STATE(37)] = 3661,
  [SMALL_STATE(38)] = 3791,
  [SMALL_STATE(39)] = 3921,
  [SMALL_STATE(40)] = 4051,
  [SMALL_STATE(41)] = 4181,
  [SMALL_STATE(42)] = 4311,
  [SMALL_STATE(43)] = 4441,
  [SMALL_STATE(44)] = 4571,
  [SMALL_STATE(45)] = 4701,
  [SMALL_STATE(46)] = 4831,
  [SMALL_STATE(47)] = 4961,
  [SMALL_STATE(48)] = 5091,
  [SMALL_STATE(49)] = 5221,
  [SMALL_STATE(50)] = 5351,
  [SMALL_STATE(51)] = 5481,
  [SMALL_STATE(52)] = 5611,
  [SMALL_STATE(53)] = 5741,
  [SMALL_STATE(54)] = 5871,
  [SMALL_STATE(55)] = 5984,
  [SMALL_STATE(56)] = 6097,
  [SMALL_STATE(57)] = 6216,
  [SMALL_STATE(58)] = 6335,
  [SMALL_STATE(59)] = 6454,
  [SMALL_STATE(60)] = 6573,
  [SMALL_STATE(61)] = 6692,
  [SMALL_STATE(62)] = 6811,
  [SMALL_STATE(63)] = 6930,
  [SMALL_STATE(64)] = 7049,
  [SMALL_STATE(65)] = 7165,
  [SMALL_STATE(66)] = 7281,
  [SMALL_STATE(67)] = 7397,
  [SMALL_STATE(68)] = 7510,
  [SMALL_STATE(69)] = 7623,
  [SMALL_STATE(70)] = 7736,
  [SMALL_STATE(71)] = 7849,
  [SMALL_STATE(72)] = 7962,
  [SMALL_STATE(73)] = 8071,
  [SMALL_STATE(74)] = 8184,
  [SMALL_STATE(75)] = 8291,
  [SMALL_STATE(76)] = 8404,
  [SMALL_STATE(77)] = 8517,
  [SMALL_STATE(78)] = 8630,
  [SMALL_STATE(79)] = 8740,
  [SMALL_STATE(80)] = 8833,
  [SMALL_STATE(81)] = 8936,
  [SMALL_STATE(82)] = 8999,
  [SMALL_STATE(83)] = 9062,
  [SMALL_STATE(84)] = 9125,
  [SMALL_STATE(85)] = 9224,
  [SMALL_STATE(86)] = 9323,
  [SMALL_STATE(87)] = 9388,
  [SMALL_STATE(88)] = 9453,
  [SMALL_STATE(89)] = 9518,
  [SMALL_STATE(90)] = 9585,
  [SMALL_STATE(91)] = 9652,
  [SMALL_STATE(92)] = 9717,
  [SMALL_STATE(93)] = 9782,
  [SMALL_STATE(94)] = 9881,
  [SMALL_STATE(95)] = 9946,
  [SMALL_STATE(96)] = 10013,
  [SMALL_STATE(97)] = 10076,
  [SMALL_STATE(98)] = 10143,
  [SMALL_STATE(99)] = 10206,
  [SMALL_STATE(100)] = 10273,
  [SMALL_STATE(101)] = 10366,
  [SMALL_STATE(102)] = 10429,
  [SMALL_STATE(103)] = 10492,
  [SMALL_STATE(104)] = 10563,
  [SMALL_STATE(105)] = 10648,
  [SMALL_STATE(106)] = 10731,
  [SMALL_STATE(107)] = 10812,
  [SMALL_STATE(108)] = 10891,
  [SMALL_STATE(109)] = 10966,
  [SMALL_STATE(110)] = 11053,
  [SMALL_STATE(111)] = 11116,
  [SMALL_STATE(112)] = 11222,
  [SMALL_STATE(113)] = 11284,
  [SMALL_STATE(114)] = 11346,
  [SMALL_STATE(115)] = 11408,
  [SMALL_STATE(116)] = 11470,
  [SMALL_STATE(117)] = 11532,
  [SMALL_STATE(118)] = 11594,
  [SMALL_STATE(119)] = 11656,
  [SMALL_STATE(120)] = 11718,
  [SMALL_STATE(121)] = 11824,
  [SMALL_STATE(122)] = 11886,
  [SMALL_STATE(123)] = 11948,
  [SMALL_STATE(124)] = 12010,
  [SMALL_STATE(125)] = 12074,
  [SMALL_STATE(126)] = 12136,
  [SMALL_STATE(127)] = 12198,
  [SMALL_STATE(128)] = 12304,
  [SMALL_STATE(129)] = 12366,
  [SMALL_STATE(130)] = 12428,
  [SMALL_STATE(131)] = 12490,
  [SMALL_STATE(132)] = 12552,
  [SMALL_STATE(133)] = 12614,
  [SMALL_STATE(134)] = 12720,
  [SMALL_STATE(135)] = 12826,
  [SMALL_STATE(136)] = 12888,
  [SMALL_STATE(137)] = 12950,
  [SMALL_STATE(138)] = 13054,
  [SMALL_STATE(139)] = 13160,
  [SMALL_STATE(140)] = 13266,
  [SMALL_STATE(141)] = 13372,
  [SMALL_STATE(142)] = 13434,
  [SMALL_STATE(143)] = 13496,
  [SMALL_STATE(144)] = 13602,
  [SMALL_STATE(145)] = 13708,
  [SMALL_STATE(146)] = 13814,
  [SMALL_STATE(147)] = 13876,
  [SMALL_STATE(148)] = 13982,
  [SMALL_STATE(149)] = 14088,
  [SMALL_STATE(150)] = 14150,
  [SMALL_STATE(151)] = 14212,
  [SMALL_STATE(152)] = 14274,
  [SMALL_STATE(153)] = 14377,
  [SMALL_STATE(154)] = 14480,
  [SMALL_STATE(155)] = 14583,
  [SMALL_STATE(156)] = 14686,
  [SMALL_STATE(157)] = 14789,
  [SMALL_STATE(158)] = 14892,
  [SMALL_STATE(159)] = 14995,
  [SMALL_STATE(160)] = 15098,
  [SMALL_STATE(161)] = 15201,
  [SMALL_STATE(162)] = 15304,
  [SMALL_STATE(163)] = 15404,
  [SMALL_STATE(164)] = 15504,
  [SMALL_STATE(165)] = 15604,
  [SMALL_STATE(166)] = 15704,
  [SMALL_STATE(167)] = 15804,
  [SMALL_STATE(168)] = 15904,
  [SMALL_STATE(169)] = 16004,
  [SMALL_STATE(170)] = 16104,
  [SMALL_STATE(171)] = 16204,
  [SMALL_STATE(172)] = 16304,
  [SMALL_STATE(173)] = 16404,
  [SMALL_STATE(174)] = 16504,
  [SMALL_STATE(175)] = 16604,
  [SMALL_STATE(176)] = 16704,
  [SMALL_STATE(177)] = 16804,
  [SMALL_STATE(178)] = 16904,
  [SMALL_STATE(179)] = 17004,
  [SMALL_STATE(180)] = 17104,
  [SMALL_STATE(181)] = 17182,
  [SMALL_STATE(182)] = 17280,
  [SMALL_STATE(183)] = 17380,
  [SMALL_STATE(184)] = 17482,
  [SMALL_STATE(185)] = 17582,
  [SMALL_STATE(186)] = 17682,
  [SMALL_STATE(187)] = 17782,
  [SMALL_STATE(188)] = 17882,
  [SMALL_STATE(189)] = 17982,
  [SMALL_STATE(190)] = 18082,
  [SMALL_STATE(191)] = 18148,
  [SMALL_STATE(192)] = 18248,
  [SMALL_STATE(193)] = 18348,
  [SMALL_STATE(194)] = 18448,
  [SMALL_STATE(195)] = 18548,
  [SMALL_STATE(196)] = 18648,
  [SMALL_STATE(197)] = 18748,
  [SMALL_STATE(198)] = 18848,
  [SMALL_STATE(199)] = 18948,
  [SMALL_STATE(200)] = 19014,
  [SMALL_STATE(201)] = 19116,
  [SMALL_STATE(202)] = 19216,
  [SMALL_STATE(203)] = 19316,
  [SMALL_STATE(204)] = 19416,
  [SMALL_STATE(205)] = 19516,
  [SMALL_STATE(206)] = 19616,
  [SMALL_STATE(207)] = 19716,
  [SMALL_STATE(208)] = 19816,
  [SMALL_STATE(209)] = 19916,
  [SMALL_STATE(210)] = 20016,
  [SMALL_STATE(211)] = 20116,
  [SMALL_STATE(212)] = 20216,
  [SMALL_STATE(213)] = 20316,
  [SMALL_STATE(214)] = 20416,
  [SMALL_STATE(215)] = 20516,
  [SMALL_STATE(216)] = 20616,
  [SMALL_STATE(217)] = 20716,
  [SMALL_STATE(218)] = 20816,
  [SMALL_STATE(219)] = 20916,
  [SMALL_STATE(220)] = 21016,
  [SMALL_STATE(221)] = 21116,
  [SMALL_STATE(222)] = 21216,
  [SMALL_STATE(223)] = 21316,
  [SMALL_STATE(224)] = 21416,
  [SMALL_STATE(225)] = 21516,
  [SMALL_STATE(226)] = 21580,
  [SMALL_STATE(227)] = 21680,
  [SMALL_STATE(228)] = 21780,
  [SMALL_STATE(229)] = 21880,
  [SMALL_STATE(230)] = 21980,
  [SMALL_STATE(231)] = 22080,
  [SMALL_STATE(232)] = 22180,
  [SMALL_STATE(233)] = 22280,
  [SMALL_STATE(234)] = 22380,
  [SMALL_STATE(235)] = 22480,
  [SMALL_STATE(236)] = 22580,
  [SMALL_STATE(237)] = 22680,
  [SMALL_STATE(238)] = 22780,
  [SMALL_STATE(239)] = 22880,
  [SMALL_STATE(240)] = 22980,
  [SMALL_STATE(241)] = 23080,
  [SMALL_STATE(242)] = 23180,
  [SMALL_STATE(243)] = 23280,
  [SMALL_STATE(244)] = 23380,
  [SMALL_STATE(245)] = 23480,
  [SMALL_STATE(246)] = 23580,
  [SMALL_STATE(247)] = 23680,
  [SMALL_STATE(248)] = 23780,
  [SMALL_STATE(249)] = 23880,
  [SMALL_STATE(250)] = 23980,
  [SMALL_STATE(251)] = 24080,
  [SMALL_STATE(252)] = 24180,
  [SMALL_STATE(253)] = 24280,
  [SMALL_STATE(254)] = 24382,
  [SMALL_STATE(255)] = 24469,
  [SMALL_STATE(256)] = 24536,
  [SMALL_STATE(257)] = 24595,
  [SMALL_STATE(258)] = 24660,
  [SMALL_STATE(259)] = 24723,
  [SMALL_STATE(260)] = 24782,
  [SMALL_STATE(261)] = 24841,
  [SMALL_STATE(262)] = 24908,
  [SMALL_STATE(263)] = 24971,
  [SMALL_STATE(264)] = 25038,
  [SMALL_STATE(265)] = 25103,
  [SMALL_STATE(266)] = 25164,
  [SMALL_STATE(267)] = 25225,
  [SMALL_STATE(268)] = 25284,
  [SMALL_STATE(269)] = 25343,
  [SMALL_STATE(270)] = 25402,
  [SMALL_STATE(271)] = 25465,
  [SMALL_STATE(272)] = 25544,
  [SMALL_STATE(273)] = 25621,
  [SMALL_STATE(274)] = 25696,
  [SMALL_STATE(275)] = 25769,
  [SMALL_STATE(276)] = 25828,
  [SMALL_STATE(277)] = 25897,
  [SMALL_STATE(278)] = 25956,
  [SMALL_STATE(279)] = 26037,
  [SMALL_STATE(280)] = 26100,
  [SMALL_STATE(281)] = 26197,
  [SMALL_STATE(282)] = 26256,
  [SMALL_STATE(283)] = 26343,
  [SMALL_STATE(284)] = 26402,
  [SMALL_STATE(285)] = 26461,
  [SMALL_STATE(286)] = 26524,
  [SMALL_STATE(287)] = 26583,
  [SMALL_STATE(288)] = 26650,
  [SMALL_STATE(289)] = 26708,
  [SMALL_STATE(290)] = 26766,
  [SMALL_STATE(291)] = 26824,
  [SMALL_STATE(292)] = 26886,
  [SMALL_STATE(293)] = 26944,
  [SMALL_STATE(294)] = 27002,
  [SMALL_STATE(295)] = 27060,
  [SMALL_STATE(296)] = 27118,
  [SMALL_STATE(297)] = 27176,
  [SMALL_STATE(298)] = 27234,
  [SMALL_STATE(299)] = 27292,
  [SMALL_STATE(300)] = 27354,
  [SMALL_STATE(301)] = 27416,
  [SMALL_STATE(302)] = 27474,
  [SMALL_STATE(303)] = 27532,
  [SMALL_STATE(304)] = 27592,
  [SMALL_STATE(305)] = 27650,
  [SMALL_STATE(306)] = 27708,
  [SMALL_STATE(307)] = 27766,
  [SMALL_STATE(308)] = 27824,
  [SMALL_STATE(309)] = 27882,
  [SMALL_STATE(310)] = 27940,
  [SMALL_STATE(311)] = 27998,
  [SMALL_STATE(312)] = 28056,
  [SMALL_STATE(313)] = 28114,
  [SMALL_STATE(314)] = 28172,
  [SMALL_STATE(315)] = 28230,
  [SMALL_STATE(316)] = 28288,
  [SMALL_STATE(317)] = 28346,
  [SMALL_STATE(318)] = 28404,
  [SMALL_STATE(319)] = 28466,
  [SMALL_STATE(320)] = 28524,
  [SMALL_STATE(321)] = 28586,
  [SMALL_STATE(322)] = 28644,
  [SMALL_STATE(323)] = 28706,
  [SMALL_STATE(324)] = 28768,
  [SMALL_STATE(325)] = 28830,
  [SMALL_STATE(326)] = 28892,
  [SMALL_STATE(327)] = 28950,
  [SMALL_STATE(328)] = 29007,
  [SMALL_STATE(329)] = 29064,
  [SMALL_STATE(330)] = 29129,
  [SMALL_STATE(331)] = 29186,
  [SMALL_STATE(332)] = 29243,
  [SMALL_STATE(333)] = 29310,
  [SMALL_STATE(334)] = 29389,
  [SMALL_STATE(335)] = 29466,
  [SMALL_STATE(336)] = 29523,
  [SMALL_STATE(337)] = 29618,
  [SMALL_STATE(338)] = 29675,
  [SMALL_STATE(339)] = 29750,
  [SMALL_STATE(340)] = 29807,
  [SMALL_STATE(341)] = 29864,
  [SMALL_STATE(342)] = 29949,
  [SMALL_STATE(343)] = 30006,
  [SMALL_STATE(344)] = 30079,
  [SMALL_STATE(345)] = 30136,
  [SMALL_STATE(346)] = 30193,
  [SMALL_STATE(347)] = 30250,
  [SMALL_STATE(348)] = 30307,
  [SMALL_STATE(349)] = 30364,
  [SMALL_STATE(350)] = 30421,
  [SMALL_STATE(351)] = 30478,
  [SMALL_STATE(352)] = 30535,
  [SMALL_STATE(353)] = 30592,
  [SMALL_STATE(354)] = 30653,
  [SMALL_STATE(355)] = 30710,
  [SMALL_STATE(356)] = 30767,
  [SMALL_STATE(357)] = 30852,
  [SMALL_STATE(358)] = 30909,
  [SMALL_STATE(359)] = 30966,
  [SMALL_STATE(360)] = 31023,
  [SMALL_STATE(361)] = 31080,
  [SMALL_STATE(362)] = 31137,
  [SMALL_STATE(363)] = 31194,
  [SMALL_STATE(364)] = 31253,
  [SMALL_STATE(365)] = 31310,
  [SMALL_STATE(366)] = 31369,
  [SMALL_STATE(367)] = 31428,
  [SMALL_STATE(368)] = 31499,
  [SMALL_STATE(369)] = 31559,
  [SMALL_STATE(370)] = 31620,
  [SMALL_STATE(371)] = 31692,
  [SMALL_STATE(372)] = 31751,
  [SMALL_STATE(373)] = 31808,
  [SMALL_STATE(374)] = 31869,
  [SMALL_STATE(375)] = 31926,
  [SMALL_STATE(376)] = 31989,
  [SMALL_STATE(377)] = 32080,
  [SMALL_STATE(378)] = 32151,
  [SMALL_STATE(379)] = 32212,
  [SMALL_STATE(380)] = 32269,
  [SMALL_STATE(381)] = 32344,
  [SMALL_STATE(382)] = 32401,
  [SMALL_STATE(383)] = 32458,
  [SMALL_STATE(384)] = 32519,
  [SMALL_STATE(385)] = 32578,
  [SMALL_STATE(386)] = 32637,
  [SMALL_STATE(387)] = 32697,
  [SMALL_STATE(388)] = 32767,
  [SMALL_STATE(389)] = 32847,
  [SMALL_STATE(390)] = 32919,
  [SMALL_STATE(391)] = 32987,
  [SMALL_STATE(392)] = 33053,
  [SMALL_STATE(393)] = 33115,
  [SMALL_STATE(394)] = 33189,
  [SMALL_STATE(395)] = 33247,
  [SMALL_STATE(396)] = 33337,
  [SMALL_STATE(397)] = 33427,
  [SMALL_STATE(398)] = 33507,
  [SMALL_STATE(399)] = 33597,
  [SMALL_STATE(400)] = 33685,
  [SMALL_STATE(401)] = 33738,
  [SMALL_STATE(402)] = 33793,
  [SMALL_STATE(403)] = 33880,
  [SMALL_STATE(404)] = 33931,
  [SMALL_STATE(405)] = 33990,
  [SMALL_STATE(406)] = 34047,
  [SMALL_STATE(407)] = 34134,
  [SMALL_STATE(408)] = 34185,
  [SMALL_STATE(409)] = 34242,
  [SMALL_STATE(410)] = 34329,
  [SMALL_STATE(411)] = 34416,
  [SMALL_STATE(412)] = 34503,
  [SMALL_STATE(413)] = 34558,
  [SMALL_STATE(414)] = 34645,
  [SMALL_STATE(415)] = 34706,
  [SMALL_STATE(416)] = 34758,
  [SMALL_STATE(417)] = 34840,
  [SMALL_STATE(418)] = 34922,
  [SMALL_STATE(419)] = 34991,
  [SMALL_STATE(420)] = 35060,
  [SMALL_STATE(421)] = 35129,
  [SMALL_STATE(422)] = 35198,
  [SMALL_STATE(423)] = 35267,
  [SMALL_STATE(424)] = 35336,
  [SMALL_STATE(425)] = 35405,
  [SMALL_STATE(426)] = 35474,
  [SMALL_STATE(427)] = 35543,
  [SMALL_STATE(428)] = 35612,
  [SMALL_STATE(429)] = 35681,
  [SMALL_STATE(430)] = 35750,
  [SMALL_STATE(431)] = 35819,
  [SMALL_STATE(432)] = 35888,
  [SMALL_STATE(433)] = 35957,
  [SMALL_STATE(434)] = 36026,
  [SMALL_STATE(435)] = 36095,
  [SMALL_STATE(436)] = 36160,
  [SMALL_STATE(437)] = 36205,
  [SMALL_STATE(438)] = 36270,
  [SMALL_STATE(439)] = 36335,
  [SMALL_STATE(440)] = 36380,
  [SMALL_STATE(441)] = 36445,
  [SMALL_STATE(442)] = 36510,
  [SMALL_STATE(443)] = 36575,
  [SMALL_STATE(444)] = 36640,
  [SMALL_STATE(445)] = 36705,
  [SMALL_STATE(446)] = 36770,
  [SMALL_STATE(447)] = 36835,
  [SMALL_STATE(448)] = 36900,
  [SMALL_STATE(449)] = 36965,
  [SMALL_STATE(450)] = 37030,
  [SMALL_STATE(451)] = 37095,
  [SMALL_STATE(452)] = 37160,
  [SMALL_STATE(453)] = 37225,
  [SMALL_STATE(454)] = 37287,
  [SMALL_STATE(455)] = 37368,
  [SMALL_STATE(456)] = 37407,
  [SMALL_STATE(457)] = 37446,
  [SMALL_STATE(458)] = 37527,
  [SMALL_STATE(459)] = 37566,
  [SMALL_STATE(460)] = 37644,
  [SMALL_STATE(461)] = 37722,
  [SMALL_STATE(462)] = 37800,
  [SMALL_STATE(463)] = 37846,
  [SMALL_STATE(464)] = 37892,
  [SMALL_STATE(465)] = 37970,
  [SMALL_STATE(466)] = 38048,
  [SMALL_STATE(467)] = 38086,
  [SMALL_STATE(468)] = 38130,
  [SMALL_STATE(469)] = 38208,
  [SMALL_STATE(470)] = 38282,
  [SMALL_STATE(471)] = 38360,
  [SMALL_STATE(472)] = 38398,
  [SMALL_STATE(473)] = 38456,
  [SMALL_STATE(474)] = 38494,
  [SMALL_STATE(475)] = 38538,
  [SMALL_STATE(476)] = 38582,
  [SMALL_STATE(477)] = 38620,
  [SMALL_STATE(478)] = 38663,
  [SMALL_STATE(479)] = 38706,
  [SMALL_STATE(480)] = 38747,
  [SMALL_STATE(481)] = 38784,
  [SMALL_STATE(482)] = 38829,
  [SMALL_STATE(483)] = 38866,
  [SMALL_STATE(484)] = 38911,
  [SMALL_STATE(485)] = 38954,
  [SMALL_STATE(486)] = 38997,
  [SMALL_STATE(487)] = 39038,
  [SMALL_STATE(488)] = 39081,
  [SMALL_STATE(489)] = 39156,
  [SMALL_STATE(490)] = 39229,
  [SMALL_STATE(491)] = 39281,
  [SMALL_STATE(492)] = 39353,
  [SMALL_STATE(493)] = 39393,
  [SMALL_STATE(494)] = 39465,
  [SMALL_STATE(495)] = 39537,
  [SMALL_STATE(496)] = 39609,
  [SMALL_STATE(497)] = 39661,
  [SMALL_STATE(498)] = 39733,
  [SMALL_STATE(499)] = 39805,
  [SMALL_STATE(500)] = 39877,
  [SMALL_STATE(501)] = 39949,
  [SMALL_STATE(502)] = 40021,
  [SMALL_STATE(503)] = 40093,
  [SMALL_STATE(504)] = 40165,
  [SMALL_STATE(505)] = 40205,
  [SMALL_STATE(506)] = 40277,
  [SMALL_STATE(507)] = 40349,
  [SMALL_STATE(508)] = 40401,
  [SMALL_STATE(509)] = 40473,
  [SMALL_STATE(510)] = 40545,
  [SMALL_STATE(511)] = 40617,
  [SMALL_STATE(512)] = 40689,
  [SMALL_STATE(513)] = 40761,
  [SMALL_STATE(514)] = 40833,
  [SMALL_STATE(515)] = 40905,
  [SMALL_STATE(516)] = 40977,
  [SMALL_STATE(517)] = 41049,
  [SMALL_STATE(518)] = 41121,
  [SMALL_STATE(519)] = 41193,
  [SMALL_STATE(520)] = 41265,
  [SMALL_STATE(521)] = 41337,
  [SMALL_STATE(522)] = 41407,
  [SMALL_STATE(523)] = 41479,
  [SMALL_STATE(524)] = 41551,
  [SMALL_STATE(525)] = 41623,
  [SMALL_STATE(526)] = 41663,
  [SMALL_STATE(527)] = 41703,
  [SMALL_STATE(528)] = 41775,
  [SMALL_STATE(529)] = 41827,
  [SMALL_STATE(530)] = 41899,
  [SMALL_STATE(531)] = 41939,
  [SMALL_STATE(532)] = 41991,
  [SMALL_STATE(533)] = 42029,
  [SMALL_STATE(534)] = 42069,
  [SMALL_STATE(535)] = 42121,
  [SMALL_STATE(536)] = 42163,
  [SMALL_STATE(537)] = 42235,
  [SMALL_STATE(538)] = 42307,
  [SMALL_STATE(539)] = 42379,
  [SMALL_STATE(540)] = 42451,
  [SMALL_STATE(541)] = 42523,
  [SMALL_STATE(542)] = 42595,
  [SMALL_STATE(543)] = 42667,
  [SMALL_STATE(544)] = 42739,
  [SMALL_STATE(545)] = 42811,
  [SMALL_STATE(546)] = 42851,
  [SMALL_STATE(547)] = 42920,
  [SMALL_STATE(548)] = 42957,
  [SMALL_STATE(549)] = 42994,
  [SMALL_STATE(550)] = 43035,
  [SMALL_STATE(551)] = 43070,
  [SMALL_STATE(552)] = 43105,
  [SMALL_STATE(553)] = 43174,
  [SMALL_STATE(554)] = 43211,
  [SMALL_STATE(555)] = 43254,
  [SMALL_STATE(556)] = 43323,
  [SMALL_STATE(557)] = 43358,
  [SMALL_STATE(558)] = 43396,
  [SMALL_STATE(559)] = 43434,
  [SMALL_STATE(560)] = 43474,
  [SMALL_STATE(561)] = 43508,
  [SMALL_STATE(562)] = 43544,
  [SMALL_STATE(563)] = 43578,
  [SMALL_STATE(564)] = 43612,
  [SMALL_STATE(565)] = 43648,
  [SMALL_STATE(566)] = 43686,
  [SMALL_STATE(567)] = 43720,
  [SMALL_STATE(568)] = 43757,
  [SMALL_STATE(569)] = 43790,
  [SMALL_STATE(570)] = 43823,
  [SMALL_STATE(571)] = 43856,
  [SMALL_STATE(572)] = 43889,
  [SMALL_STATE(573)] = 43922,
  [SMALL_STATE(574)] = 43959,
  [SMALL_STATE(575)] = 43992,
  [SMALL_STATE(576)] = 44025,
  [SMALL_STATE(577)] = 44058,
  [SMALL_STATE(578)] = 44091,
  [SMALL_STATE(579)] = 44124,
  [SMALL_STATE(580)] = 44157,
  [SMALL_STATE(581)] = 44190,
  [SMALL_STATE(582)] = 44223,
  [SMALL_STATE(583)] = 44260,
  [SMALL_STATE(584)] = 44297,
  [SMALL_STATE(585)] = 44330,
  [SMALL_STATE(586)] = 44363,
  [SMALL_STATE(587)] = 44396,
  [SMALL_STATE(588)] = 44430,
  [SMALL_STATE(589)] = 44463,
  [SMALL_STATE(590)] = 44494,
  [SMALL_STATE(591)] = 44525,
  [SMALL_STATE(592)] = 44556,
  [SMALL_STATE(593)] = 44592,
  [SMALL_STATE(594)] = 44623,
  [SMALL_STATE(595)] = 44654,
  [SMALL_STATE(596)] = 44685,
  [SMALL_STATE(597)] = 44716,
  [SMALL_STATE(598)] = 44747,
  [SMALL_STATE(599)] = 44780,
  [SMALL_STATE(600)] = 44810,
  [SMALL_STATE(601)] = 44840,
  [SMALL_STATE(602)] = 44870,
  [SMALL_STATE(603)] = 44900,
  [SMALL_STATE(604)] = 44927,
  [SMALL_STATE(605)] = 44956,
  [SMALL_STATE(606)] = 44985,
  [SMALL_STATE(607)] = 45014,
  [SMALL_STATE(608)] = 45043,
  [SMALL_STATE(609)] = 45072,
  [SMALL_STATE(610)] = 45098,
  [SMALL_STATE(611)] = 45122,
  [SMALL_STATE(612)] = 45145,
  [SMALL_STATE(613)] = 45168,
  [SMALL_STATE(614)] = 45191,
  [SMALL_STATE(615)] = 45214,
  [SMALL_STATE(616)] = 45237,
  [SMALL_STATE(617)] = 45260,
  [SMALL_STATE(618)] = 45283,
  [SMALL_STATE(619)] = 45306,
  [SMALL_STATE(620)] = 45329,
  [SMALL_STATE(621)] = 45352,
  [SMALL_STATE(622)] = 45375,
  [SMALL_STATE(623)] = 45398,
  [SMALL_STATE(624)] = 45421,
  [SMALL_STATE(625)] = 45444,
  [SMALL_STATE(626)] = 45467,
  [SMALL_STATE(627)] = 45490,
  [SMALL_STATE(628)] = 45513,
  [SMALL_STATE(629)] = 45536,
  [SMALL_STATE(630)] = 45559,
  [SMALL_STATE(631)] = 45582,
  [SMALL_STATE(632)] = 45605,
  [SMALL_STATE(633)] = 45628,
  [SMALL_STATE(634)] = 45651,
  [SMALL_STATE(635)] = 45675,
  [SMALL_STATE(636)] = 45689,
  [SMALL_STATE(637)] = 45708,
  [SMALL_STATE(638)] = 45727,
  [SMALL_STATE(639)] = 45746,
  [SMALL_STATE(640)] = 45765,
  [SMALL_STATE(641)] = 45784,
  [SMALL_STATE(642)] = 45802,
  [SMALL_STATE(643)] = 45820,
  [SMALL_STATE(644)] = 45838,
  [SMALL_STATE(645)] = 45856,
  [SMALL_STATE(646)] = 45874,
  [SMALL_STATE(647)] = 45892,
  [SMALL_STATE(648)] = 45910,
  [SMALL_STATE(649)] = 45928,
  [SMALL_STATE(650)] = 45946,
  [SMALL_STATE(651)] = 45964,
  [SMALL_STATE(652)] = 45980,
  [SMALL_STATE(653)] = 45996,
  [SMALL_STATE(654)] = 46014,
  [SMALL_STATE(655)] = 46030,
  [SMALL_STATE(656)] = 46046,
  [SMALL_STATE(657)] = 46064,
  [SMALL_STATE(658)] = 46082,
  [SMALL_STATE(659)] = 46100,
  [SMALL_STATE(660)] = 46116,
  [SMALL_STATE(661)] = 46134,
  [SMALL_STATE(662)] = 46151,
  [SMALL_STATE(663)] = 46168,
  [SMALL_STATE(664)] = 46183,
  [SMALL_STATE(665)] = 46198,
  [SMALL_STATE(666)] = 46213,
  [SMALL_STATE(667)] = 46228,
  [SMALL_STATE(668)] = 46243,
  [SMALL_STATE(669)] = 46258,
  [SMALL_STATE(670)] = 46273,
  [SMALL_STATE(671)] = 46290,
  [SMALL_STATE(672)] = 46305,
  [SMALL_STATE(673)] = 46320,
  [SMALL_STATE(674)] = 46335,
  [SMALL_STATE(675)] = 46350,
  [SMALL_STATE(676)] = 46365,
  [SMALL_STATE(677)] = 46380,
  [SMALL_STATE(678)] = 46395,
  [SMALL_STATE(679)] = 46410,
  [SMALL_STATE(680)] = 46425,
  [SMALL_STATE(681)] = 46442,
  [SMALL_STATE(682)] = 46459,
  [SMALL_STATE(683)] = 46473,
  [SMALL_STATE(684)] = 46487,
  [SMALL_STATE(685)] = 46501,
  [SMALL_STATE(686)] = 46515,
  [SMALL_STATE(687)] = 46529,
  [SMALL_STATE(688)] = 46543,
  [SMALL_STATE(689)] = 46557,
  [SMALL_STATE(690)] = 46571,
  [SMALL_STATE(691)] = 46585,
  [SMALL_STATE(692)] = 46599,
  [SMALL_STATE(693)] = 46613,
  [SMALL_STATE(694)] = 46627,
  [SMALL_STATE(695)] = 46641,
  [SMALL_STATE(696)] = 46655,
  [SMALL_STATE(697)] = 46669,
  [SMALL_STATE(698)] = 46683,
  [SMALL_STATE(699)] = 46697,
  [SMALL_STATE(700)] = 46711,
  [SMALL_STATE(701)] = 46725,
  [SMALL_STATE(702)] = 46739,
  [SMALL_STATE(703)] = 46753,
  [SMALL_STATE(704)] = 46767,
  [SMALL_STATE(705)] = 46781,
  [SMALL_STATE(706)] = 46795,
  [SMALL_STATE(707)] = 46809,
  [SMALL_STATE(708)] = 46823,
  [SMALL_STATE(709)] = 46835,
  [SMALL_STATE(710)] = 46849,
  [SMALL_STATE(711)] = 46863,
  [SMALL_STATE(712)] = 46877,
  [SMALL_STATE(713)] = 46891,
  [SMALL_STATE(714)] = 46905,
  [SMALL_STATE(715)] = 46919,
  [SMALL_STATE(716)] = 46933,
  [SMALL_STATE(717)] = 46947,
  [SMALL_STATE(718)] = 46959,
  [SMALL_STATE(719)] = 46973,
  [SMALL_STATE(720)] = 46987,
  [SMALL_STATE(721)] = 47001,
  [SMALL_STATE(722)] = 47012,
  [SMALL_STATE(723)] = 47023,
  [SMALL_STATE(724)] = 47034,
  [SMALL_STATE(725)] = 47045,
  [SMALL_STATE(726)] = 47054,
  [SMALL_STATE(727)] = 47063,
  [SMALL_STATE(728)] = 47074,
  [SMALL_STATE(729)] = 47085,
  [SMALL_STATE(730)] = 47094,
  [SMALL_STATE(731)] = 47105,
  [SMALL_STATE(732)] = 47116,
  [SMALL_STATE(733)] = 47127,
  [SMALL_STATE(734)] = 47138,
  [SMALL_STATE(735)] = 47149,
  [SMALL_STATE(736)] = 47158,
  [SMALL_STATE(737)] = 47169,
  [SMALL_STATE(738)] = 47180,
  [SMALL_STATE(739)] = 47191,
  [SMALL_STATE(740)] = 47202,
  [SMALL_STATE(741)] = 47213,
  [SMALL_STATE(742)] = 47224,
  [SMALL_STATE(743)] = 47233,
  [SMALL_STATE(744)] = 47244,
  [SMALL_STATE(745)] = 47253,
  [SMALL_STATE(746)] = 47262,
  [SMALL_STATE(747)] = 47273,
  [SMALL_STATE(748)] = 47284,
  [SMALL_STATE(749)] = 47292,
  [SMALL_STATE(750)] = 47300,
  [SMALL_STATE(751)] = 47308,
  [SMALL_STATE(752)] = 47316,
  [SMALL_STATE(753)] = 47324,
  [SMALL_STATE(754)] = 47332,
  [SMALL_STATE(755)] = 47340,
  [SMALL_STATE(756)] = 47348,
  [SMALL_STATE(757)] = 47356,
  [SMALL_STATE(758)] = 47364,
  [SMALL_STATE(759)] = 47372,
  [SMALL_STATE(760)] = 47380,
  [SMALL_STATE(761)] = 47388,
  [SMALL_STATE(762)] = 47396,
  [SMALL_STATE(763)] = 47404,
  [SMALL_STATE(764)] = 47412,
  [SMALL_STATE(765)] = 47420,
  [SMALL_STATE(766)] = 47428,
  [SMALL_STATE(767)] = 47436,
  [SMALL_STATE(768)] = 47444,
  [SMALL_STATE(769)] = 47452,
  [SMALL_STATE(770)] = 47460,
  [SMALL_STATE(771)] = 47468,
  [SMALL_STATE(772)] = 47476,
  [SMALL_STATE(773)] = 47484,
  [SMALL_STATE(774)] = 47492,
  [SMALL_STATE(775)] = 47500,
  [SMALL_STATE(776)] = 47508,
  [SMALL_STATE(777)] = 47516,
  [SMALL_STATE(778)] = 47524,
  [SMALL_STATE(779)] = 47532,
  [SMALL_STATE(780)] = 47540,
  [SMALL_STATE(781)] = 47548,
  [SMALL_STATE(782)] = 47556,
  [SMALL_STATE(783)] = 47564,
  [SMALL_STATE(784)] = 47572,
  [SMALL_STATE(785)] = 47580,
  [SMALL_STATE(786)] = 47588,
  [SMALL_STATE(787)] = 47596,
  [SMALL_STATE(788)] = 47604,
  [SMALL_STATE(789)] = 47612,
  [SMALL_STATE(790)] = 47620,
  [SMALL_STATE(791)] = 47628,
  [SMALL_STATE(792)] = 47636,
  [SMALL_STATE(793)] = 47644,
  [SMALL_STATE(794)] = 47652,
  [SMALL_STATE(795)] = 47660,
  [SMALL_STATE(796)] = 47668,
  [SMALL_STATE(797)] = 47676,
  [SMALL_STATE(798)] = 47684,
  [SMALL_STATE(799)] = 47692,
  [SMALL_STATE(800)] = 47700,
  [SMALL_STATE(801)] = 47708,
  [SMALL_STATE(802)] = 47716,
  [SMALL_STATE(803)] = 47724,
  [SMALL_STATE(804)] = 47732,
  [SMALL_STATE(805)] = 47740,
  [SMALL_STATE(806)] = 47748,
  [SMALL_STATE(807)] = 47756,
  [SMALL_STATE(808)] = 47764,
  [SMALL_STATE(809)] = 47772,
  [SMALL_STATE(810)] = 47780,
  [SMALL_STATE(811)] = 47788,
  [SMALL_STATE(812)] = 47796,
  [SMALL_STATE(813)] = 47804,
  [SMALL_STATE(814)] = 47812,
  [SMALL_STATE(815)] = 47820,
  [SMALL_STATE(816)] = 47828,
  [SMALL_STATE(817)] = 47836,
  [SMALL_STATE(818)] = 47844,
  [SMALL_STATE(819)] = 47852,
  [SMALL_STATE(820)] = 47860,
  [SMALL_STATE(821)] = 47868,
  [SMALL_STATE(822)] = 47876,
  [SMALL_STATE(823)] = 47884,
  [SMALL_STATE(824)] = 47892,
  [SMALL_STATE(825)] = 47900,
  [SMALL_STATE(826)] = 47908,
  [SMALL_STATE(827)] = 47916,
  [SMALL_STATE(828)] = 47924,
  [SMALL_STATE(829)] = 47932,
  [SMALL_STATE(830)] = 47940,
  [SMALL_STATE(831)] = 47948,
  [SMALL_STATE(832)] = 47956,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infrastructure, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(405),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(263),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(285),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(414),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(483),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(525),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nullable_type, 2, 0, 0),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_nullable_type, 2, 0, 0),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(90),
  [308] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(141),
  [311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(452),
  [314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(78),
  [317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(89),
  [320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(209),
  [323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(157),
  [326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(253),
  [329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(64),
  [332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0),
  [334] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(209),
  [337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [340] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(149),
  [343] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(116),
  [346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(627),
  [349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(690),
  [352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(662),
  [368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ternary_expression, 5, 0, 14),
  [376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ternary_expression, 5, 0, 14),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 9),
  [384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 9),
  [386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 4, 0, 10),
  [392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 4, 0, 10),
  [394] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 4, 0, 11),
  [396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 4, 0, 11),
  [398] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 5, 0, 13),
  [400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 5, 0, 13),
  [402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 1, 0, 0),
  [404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 1, 0, 0),
  [406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 3, 0, 0),
  [408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 3, 0, 0),
  [410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0), REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0), REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 3, 0, 0),
  [420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3, 0, 0),
  [422] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0), REDUCE(sym_parenthesized_expression, 4, 0, 0),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 4, 0, 0),
  [427] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0), REDUCE(sym_parenthesized_expression, 4, 0, 0),
  [430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 1),
  [432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 1),
  [434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0),
  [438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__lhs_expression, 1, 0, 0),
  [440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0),
  [442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), SHIFT(819),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0),
  [449] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0), REDUCE(sym_parenthesized_expression, 2, 0, 0),
  [452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 2, 0, 0),
  [454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0), REDUCE(sym_parenthesized_expression, 2, 0, 0),
  [457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 2),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 2),
  [461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 2, 0, 0),
  [463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 5),
  [467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 5),
  [469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 3, 0, 0),
  [471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, 0, 0),
  [473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 6),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 6),
  [477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_resource_expression, 3, 0, 7),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource_expression, 3, 0, 7),
  [481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 4, 0, 0),
  [483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 16),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 16),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 17),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 17),
  [497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 18),
  [499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 18),
  [501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal, 2, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal, 2, 0, 0),
  [505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 5, 0, 0),
  [507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 5, 0, 0),
  [509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 2, 0, 0),
  [511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 2, 0, 0),
  [513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0),
  [515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0),
  [517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 2, 0, 0),
  [519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 2, 0, 0),
  [521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 3),
  [523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 3),
  [525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal, 3, 0, 0),
  [529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal, 3, 0, 0),
  [531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__multiline_string_literal, 3, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__multiline_string_literal, 3, 0, 0),
  [535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 3, 0, 0),
  [545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3, 0, 0),
  [547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0),
  [549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 4, 0, 0),
  [553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 6, 0, 0),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 6, 0, 0),
  [559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 0),
  [561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 0),
  [563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 8),
  [565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 8),
  [567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 6, 0, 0),
  [569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 6, 0, 0),
  [571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 4, 0, 0),
  [577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 4, 0, 0),
  [579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 5, 0, 0),
  [581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 5, 0, 0),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0),
  [627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(479),
  [631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [645] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT(24),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_property, 3, 0, 0),
  [652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_property, 3, 0, 0),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_property, 3, 0, 1),
  [660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_property, 3, 0, 1),
  [662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator, 2, 0, 0),
  [664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 2, 0, 0),
  [666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [670] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__type_not_union, 1, 0, 0),
  [673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), SHIFT(756),
  [676] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, 0, 0), REDUCE(sym__type_not_union, 1, 0, 0),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0),
  [689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0),
  [691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_not_union, 1, 0, 0),
  [693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_not_union, 1, 0, 0),
  [695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primitive_type, 1, 0, 0),
  [697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primitive_type, 1, 0, 0),
  [699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(198),
  [737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(335),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT(17),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_with_statement, 4, 0, 0),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 4, 0, 0),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT(22),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_defined_function, 6, 0, 12),
  [785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_declaration, 5, 0, 0),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 0),
  [789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_statement, 4, 0, 4),
  [791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metadata_declaration, 4, 0, 0),
  [793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0),
  [799] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(758),
  [802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(634),
  [805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(653),
  [808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(645),
  [811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(796),
  [814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(763),
  [817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(804),
  [820] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(812),
  [823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(815),
  [826] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(778),
  [829] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(794),
  [832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(802),
  [835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(760),
  [838] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(762),
  [841] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_infrastructure_repeat1, 2, 0, 0), SHIFT_REPEAT(200),
  [844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_infrastructure, 1, 0, 0),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(732),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(732),
  [895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(724),
  [898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(453),
  [901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0),
  [903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(693),
  [906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(183),
  [909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(626),
  [912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(786),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorators, 1, 0, 0),
  [932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorators, 1, 0, 0),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_decorators_repeat1, 2, 0, 0),
  [938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_decorators_repeat1, 2, 0, 0),
  [940] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_decorators_repeat1, 2, 0, 0), SHIFT_REPEAT(253),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(72),
  [963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [965] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 4, 0, 0),
  [967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4, 0, 0),
  [969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 3, 0, 0),
  [971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 0),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 2, 0, 0),
  [977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT(53),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [1000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [1002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameterized_type, 2, 0, 0),
  [1004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameterized_type, 2, 0, 0),
  [1006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameterized_type, 4, 0, 0),
  [1008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameterized_type, 4, 0, 0),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [1018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 3, 0, 0),
  [1020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 0),
  [1022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [1024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [1026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(137),
  [1028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0),
  [1030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [1032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [1034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [1036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(16),
  [1039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [1041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [1043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(134),
  [1045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [1059] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 2, 0, 0),
  [1061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 2, 0, 0),
  [1063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [1067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [1071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [1075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [1089] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT(50),
  [1092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [1104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 1, 0, 0),
  [1106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 1, 0, 0),
  [1108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [1110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [1116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [1120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(147),
  [1124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(148),
  [1126] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(16),
  [1129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_negated_type, 2, 0, 0),
  [1131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_negated_type, 2, 0, 0),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [1137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [1141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 0),
  [1143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, 0, 0),
  [1145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_property, 1, 0, 0),
  [1147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_property, 1, 0, 0),
  [1149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0),
  [1151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_resource_declaration, 6, 0, 0),
  [1153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource_declaration, 6, 0, 0),
  [1155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_object_repeat1, 3, 0, 0),
  [1157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 3, 0, 0),
  [1159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_decorators_repeat1, 2, 0, 0), SHIFT_REPEAT(183),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [1166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_resource_declaration, 5, 0, 0),
  [1168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource_declaration, 5, 0, 0),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [1172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(48),
  [1175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(48),
  [1178] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(39),
  [1181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(39),
  [1184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_decorators_repeat1, 2, 0, 0), SHIFT_REPEAT(200),
  [1187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 0),
  [1189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 5, 0, 0),
  [1193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 2, 0, 0),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [1201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_functionality, 8, 0, 0),
  [1203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_statement, 2, 0, 0),
  [1205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 0),
  [1207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_with_statement, 6, 0, 0),
  [1209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_functionality, 9, 0, 0),
  [1211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 4, 0, 0),
  [1213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_functionality, 6, 0, 0),
  [1215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_declaration, 5, 0, 0),
  [1217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_target_scope_assignment, 3, 0, 0),
  [1219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_test_block, 5, 0, 0),
  [1221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_functionality, 7, 0, 0),
  [1223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_literal_repeat1, 2, 0, 0),
  [1225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(625),
  [1228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(201),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [1239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(629),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(633),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [1263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 3, 0, 0),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [1275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [1282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(43),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [1291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [1293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [1295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(14),
  [1298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(41),
  [1301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(41),
  [1304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [1310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(27),
  [1313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(14),
  [1316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(27),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [1323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [1327] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(647),
  [1330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0),
  [1332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multiline_string_content_repeat1, 2, 0, 0),
  [1334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multiline_string_content_repeat1, 2, 0, 0), SHIFT_REPEAT(683),
  [1337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(33),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [1352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(747),
  [1355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(33),
  [1374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [1376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [1380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [1382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [1388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_functionality_repeat1, 2, 0, 0),
  [1390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_functionality_repeat1, 2, 0, 0), SHIFT_REPEAT(800),
  [1393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multiline_string_content, 1, 0, 0),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [1403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 0),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(207),
  [1414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [1426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [1430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [1436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_functionality_repeat1, 4, 0, 0),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [1444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [1450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compatible_identifier, 2, 0, 1),
  [1452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [1456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [1464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [1466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [1468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [1490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [1492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [1496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [1498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [1500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [1502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compatible_identifier, 2, 0, 0),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1512] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [1520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [1522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [1526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [1528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [1530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [1532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [1534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [1540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [1542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [1550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [1556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_loop_parameters, 5, 0, 15),
  [1558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [1568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__external_asterisk = 0,
  ts_external_token__multiline_string_content = 1,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__external_asterisk] = sym__external_asterisk,
  [ts_external_token__multiline_string_content] = sym__multiline_string_content,
};

static const bool ts_external_scanner_states[4][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__external_asterisk] = true,
    [ts_external_token__multiline_string_content] = true,
  },
  [2] = {
    [ts_external_token__external_asterisk] = true,
  },
  [3] = {
    [ts_external_token__multiline_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_bicep_external_scanner_create(void);
void tree_sitter_bicep_external_scanner_destroy(void *);
bool tree_sitter_bicep_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_bicep_external_scanner_serialize(void *, char *);
void tree_sitter_bicep_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_bicep(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_bicep_external_scanner_create,
      tree_sitter_bicep_external_scanner_destroy,
      tree_sitter_bicep_external_scanner_scan,
      tree_sitter_bicep_external_scanner_serialize,
      tree_sitter_bicep_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
